import reflex as rx

class Si1001Tracklists(rx.Component):
    library = "react-icons/si"
    tag = "Si1001Tracklists"


class Si1Password(rx.Component):
    library = "react-icons/si"
    tag = "Si1Password"


class Si3M(rx.Component):
    library = "react-icons/si"
    tag = "Si3M"


class Si42(rx.Component):
    library = "react-icons/si"
    tag = "Si42"


class Si4Chan(rx.Component):
    library = "react-icons/si"
    tag = "Si4Chan"


class Si4D(rx.Component):
    library = "react-icons/si"
    tag = "Si4D"


class Si500Px(rx.Component):
    library = "react-icons/si"
    tag = "Si500Px"


class SiAbbott(rx.Component):
    library = "react-icons/si"
    tag = "SiAbbott"


class SiAbbrobotstudio(rx.Component):
    library = "react-icons/si"
    tag = "SiAbbrobotstudio"


class SiAbbvie(rx.Component):
    library = "react-icons/si"
    tag = "SiAbbvie"


class SiAbletonlive(rx.Component):
    library = "react-icons/si"
    tag = "SiAbletonlive"


class SiAboutdotme(rx.Component):
    library = "react-icons/si"
    tag = "SiAboutdotme"


class SiAbstract(rx.Component):
    library = "react-icons/si"
    tag = "SiAbstract"


class SiAcademia(rx.Component):
    library = "react-icons/si"
    tag = "SiAcademia"


class SiAccenture(rx.Component):
    library = "react-icons/si"
    tag = "SiAccenture"


class SiAcclaim(rx.Component):
    library = "react-icons/si"
    tag = "SiAcclaim"


class SiAccusoft(rx.Component):
    library = "react-icons/si"
    tag = "SiAccusoft"


class SiAcer(rx.Component):
    library = "react-icons/si"
    tag = "SiAcer"


class SiAcm(rx.Component):
    library = "react-icons/si"
    tag = "SiAcm"


class SiActigraph(rx.Component):
    library = "react-icons/si"
    tag = "SiActigraph"


class SiActivision(rx.Component):
    library = "react-icons/si"
    tag = "SiActivision"


class SiAdafruit(rx.Component):
    library = "react-icons/si"
    tag = "SiAdafruit"


class SiAdblock(rx.Component):
    library = "react-icons/si"
    tag = "SiAdblock"


class SiAdblockplus(rx.Component):
    library = "react-icons/si"
    tag = "SiAdblockplus"


class SiAddthis(rx.Component):
    library = "react-icons/si"
    tag = "SiAddthis"


class SiAdguard(rx.Component):
    library = "react-icons/si"
    tag = "SiAdguard"


class SiAdidas(rx.Component):
    library = "react-icons/si"
    tag = "SiAdidas"


class SiAdminer(rx.Component):
    library = "react-icons/si"
    tag = "SiAdminer"


class SiAdobe(rx.Component):
    library = "react-icons/si"
    tag = "SiAdobe"


class SiAdobeacrobatreader(rx.Component):
    library = "react-icons/si"
    tag = "SiAdobeacrobatreader"


class SiAdobeaftereffects(rx.Component):
    library = "react-icons/si"
    tag = "SiAdobeaftereffects"


class SiAdobeaudition(rx.Component):
    library = "react-icons/si"
    tag = "SiAdobeaudition"


class SiAdobecreativecloud(rx.Component):
    library = "react-icons/si"
    tag = "SiAdobecreativecloud"


class SiAdobedreamweaver(rx.Component):
    library = "react-icons/si"
    tag = "SiAdobedreamweaver"


class SiAdobefonts(rx.Component):
    library = "react-icons/si"
    tag = "SiAdobefonts"


class SiAdobeillustrator(rx.Component):
    library = "react-icons/si"
    tag = "SiAdobeillustrator"


class SiAdobeindesign(rx.Component):
    library = "react-icons/si"
    tag = "SiAdobeindesign"


class SiAdobelightroom(rx.Component):
    library = "react-icons/si"
    tag = "SiAdobelightroom"


class SiAdobelightroomclassic(rx.Component):
    library = "react-icons/si"
    tag = "SiAdobelightroomclassic"


class SiAdobephotoshop(rx.Component):
    library = "react-icons/si"
    tag = "SiAdobephotoshop"


class SiAdobepremierepro(rx.Component):
    library = "react-icons/si"
    tag = "SiAdobepremierepro"


class SiAdobexd(rx.Component):
    library = "react-icons/si"
    tag = "SiAdobexd"


class SiAdonisjs(rx.Component):
    library = "react-icons/si"
    tag = "SiAdonisjs"


class SiAdp(rx.Component):
    library = "react-icons/si"
    tag = "SiAdp"


class SiAdyen(rx.Component):
    library = "react-icons/si"
    tag = "SiAdyen"


class SiAerlingus(rx.Component):
    library = "react-icons/si"
    tag = "SiAerlingus"


class SiAeroflot(rx.Component):
    library = "react-icons/si"
    tag = "SiAeroflot"


class SiAeromexico(rx.Component):
    library = "react-icons/si"
    tag = "SiAeromexico"


class SiAerospike(rx.Component):
    library = "react-icons/si"
    tag = "SiAerospike"


class SiAew(rx.Component):
    library = "react-icons/si"
    tag = "SiAew"


class SiAffine(rx.Component):
    library = "react-icons/si"
    tag = "SiAffine"


class SiAffinity(rx.Component):
    library = "react-icons/si"
    tag = "SiAffinity"


class SiAffinitydesigner(rx.Component):
    library = "react-icons/si"
    tag = "SiAffinitydesigner"


class SiAffinityphoto(rx.Component):
    library = "react-icons/si"
    tag = "SiAffinityphoto"


class SiAffinitypublisher(rx.Component):
    library = "react-icons/si"
    tag = "SiAffinitypublisher"


class SiAframe(rx.Component):
    library = "react-icons/si"
    tag = "SiAframe"


class SiAgora(rx.Component):
    library = "react-icons/si"
    tag = "SiAgora"


class SiAib(rx.Component):
    library = "react-icons/si"
    tag = "SiAib"


class SiAidungeon(rx.Component):
    library = "react-icons/si"
    tag = "SiAidungeon"


class SiAiohttp(rx.Component):
    library = "react-icons/si"
    tag = "SiAiohttp"


class SiAiqfome(rx.Component):
    library = "react-icons/si"
    tag = "SiAiqfome"


class SiAirasia(rx.Component):
    library = "react-icons/si"
    tag = "SiAirasia"


class SiAirbnb(rx.Component):
    library = "react-icons/si"
    tag = "SiAirbnb"


class SiAirbus(rx.Component):
    library = "react-icons/si"
    tag = "SiAirbus"


class SiAirbyte(rx.Component):
    library = "react-icons/si"
    tag = "SiAirbyte"


class SiAircall(rx.Component):
    library = "react-icons/si"
    tag = "SiAircall"


class SiAircanada(rx.Component):
    library = "react-icons/si"
    tag = "SiAircanada"


class SiAirchina(rx.Component):
    library = "react-icons/si"
    tag = "SiAirchina"


class SiAirfrance(rx.Component):
    library = "react-icons/si"
    tag = "SiAirfrance"


class SiAirplayaudio(rx.Component):
    library = "react-icons/si"
    tag = "SiAirplayaudio"


class SiAirplayvideo(rx.Component):
    library = "react-icons/si"
    tag = "SiAirplayvideo"


class SiAirtable(rx.Component):
    library = "react-icons/si"
    tag = "SiAirtable"


class SiAjv(rx.Component):
    library = "react-icons/si"
    tag = "SiAjv"


class SiAkamai(rx.Component):
    library = "react-icons/si"
    tag = "SiAkamai"


class SiAlacritty(rx.Component):
    library = "react-icons/si"
    tag = "SiAlacritty"


class SiAlbertheijn(rx.Component):
    library = "react-icons/si"
    tag = "SiAlbertheijn"


class SiAlchemy(rx.Component):
    library = "react-icons/si"
    tag = "SiAlchemy"


class SiAldinord(rx.Component):
    library = "react-icons/si"
    tag = "SiAldinord"


class SiAldisud(rx.Component):
    library = "react-icons/si"
    tag = "SiAldisud"


class SiAlfaromeo(rx.Component):
    library = "react-icons/si"
    tag = "SiAlfaromeo"


class SiAlfred(rx.Component):
    library = "react-icons/si"
    tag = "SiAlfred"


class SiAlgolia(rx.Component):
    library = "react-icons/si"
    tag = "SiAlgolia"


class SiAlgorand(rx.Component):
    library = "react-icons/si"
    tag = "SiAlgorand"


class SiAlibabacloud(rx.Component):
    library = "react-icons/si"
    tag = "SiAlibabacloud"


class SiAlibabadotcom(rx.Component):
    library = "react-icons/si"
    tag = "SiAlibabadotcom"


class SiAliexpress(rx.Component):
    library = "react-icons/si"
    tag = "SiAliexpress"


class SiAlipay(rx.Component):
    library = "react-icons/si"
    tag = "SiAlipay"


class SiAllegro(rx.Component):
    library = "react-icons/si"
    tag = "SiAllegro"


class SiAlliedmodders(rx.Component):
    library = "react-icons/si"
    tag = "SiAlliedmodders"


class SiAllocine(rx.Component):
    library = "react-icons/si"
    tag = "SiAllocine"


class SiAlltrails(rx.Component):
    library = "react-icons/si"
    tag = "SiAlltrails"


class SiAlpinedotjs(rx.Component):
    library = "react-icons/si"
    tag = "SiAlpinedotjs"


class SiAlpinelinux(rx.Component):
    library = "react-icons/si"
    tag = "SiAlpinelinux"


class SiAltiumdesigner(rx.Component):
    library = "react-icons/si"
    tag = "SiAltiumdesigner"


class SiAlwaysdata(rx.Component):
    library = "react-icons/si"
    tag = "SiAlwaysdata"


class SiAmazon(rx.Component):
    library = "react-icons/si"
    tag = "SiAmazon"


class SiAmazonalexa(rx.Component):
    library = "react-icons/si"
    tag = "SiAmazonalexa"


class SiAmazonapigateway(rx.Component):
    library = "react-icons/si"
    tag = "SiAmazonapigateway"


class SiAmazonaws(rx.Component):
    library = "react-icons/si"
    tag = "SiAmazonaws"


class SiAmazoncloudwatch(rx.Component):
    library = "react-icons/si"
    tag = "SiAmazoncloudwatch"


class SiAmazondynamodb(rx.Component):
    library = "react-icons/si"
    tag = "SiAmazondynamodb"


class SiAmazonec2(rx.Component):
    library = "react-icons/si"
    tag = "SiAmazonec2"


class SiAmazonecs(rx.Component):
    library = "react-icons/si"
    tag = "SiAmazonecs"


class SiAmazoneks(rx.Component):
    library = "react-icons/si"
    tag = "SiAmazoneks"


class SiAmazonfiretv(rx.Component):
    library = "react-icons/si"
    tag = "SiAmazonfiretv"


class SiAmazongames(rx.Component):
    library = "react-icons/si"
    tag = "SiAmazongames"


class SiAmazonlumberyard(rx.Component):
    library = "react-icons/si"
    tag = "SiAmazonlumberyard"


class SiAmazonpay(rx.Component):
    library = "react-icons/si"
    tag = "SiAmazonpay"


class SiAmazonprime(rx.Component):
    library = "react-icons/si"
    tag = "SiAmazonprime"


class SiAmazonrds(rx.Component):
    library = "react-icons/si"
    tag = "SiAmazonrds"


class SiAmazons3(rx.Component):
    library = "react-icons/si"
    tag = "SiAmazons3"


class SiAmazonsqs(rx.Component):
    library = "react-icons/si"
    tag = "SiAmazonsqs"


class SiAmd(rx.Component):
    library = "react-icons/si"
    tag = "SiAmd"


class SiAmeba(rx.Component):
    library = "react-icons/si"
    tag = "SiAmeba"


class SiAmericanairlines(rx.Component):
    library = "react-icons/si"
    tag = "SiAmericanairlines"


class SiAmericanexpress(rx.Component):
    library = "react-icons/si"
    tag = "SiAmericanexpress"


class SiAmg(rx.Component):
    library = "react-icons/si"
    tag = "SiAmg"


class SiAmp(rx.Component):
    library = "react-icons/si"
    tag = "SiAmp"


class SiAmul(rx.Component):
    library = "react-icons/si"
    tag = "SiAmul"


class SiAna(rx.Component):
    library = "react-icons/si"
    tag = "SiAna"


class SiAnaconda(rx.Component):
    library = "react-icons/si"
    tag = "SiAnaconda"


class SiAnalogue(rx.Component):
    library = "react-icons/si"
    tag = "SiAnalogue"


class SiAnchor(rx.Component):
    library = "react-icons/si"
    tag = "SiAnchor"


class SiAndela(rx.Component):
    library = "react-icons/si"
    tag = "SiAndela"


class SiAndroid(rx.Component):
    library = "react-icons/si"
    tag = "SiAndroid"


class SiAndroidauto(rx.Component):
    library = "react-icons/si"
    tag = "SiAndroidauto"


class SiAndroidstudio(rx.Component):
    library = "react-icons/si"
    tag = "SiAndroidstudio"


class SiAngellist(rx.Component):
    library = "react-icons/si"
    tag = "SiAngellist"


class SiAngular(rx.Component):
    library = "react-icons/si"
    tag = "SiAngular"


class SiAngularjs(rx.Component):
    library = "react-icons/si"
    tag = "SiAngularjs"


class SiAngularuniversal(rx.Component):
    library = "react-icons/si"
    tag = "SiAngularuniversal"


class SiAnilist(rx.Component):
    library = "react-icons/si"
    tag = "SiAnilist"


class SiAnsible(rx.Component):
    library = "react-icons/si"
    tag = "SiAnsible"


class SiAnswer(rx.Component):
    library = "react-icons/si"
    tag = "SiAnswer"


class SiAnsys(rx.Component):
    library = "react-icons/si"
    tag = "SiAnsys"


class SiAnta(rx.Component):
    library = "react-icons/si"
    tag = "SiAnta"


class SiAntdesign(rx.Component):
    library = "react-icons/si"
    tag = "SiAntdesign"


class SiAntena3(rx.Component):
    library = "react-icons/si"
    tag = "SiAntena3"


class SiAnydesk(rx.Component):
    library = "react-icons/si"
    tag = "SiAnydesk"


class SiAol(rx.Component):
    library = "react-icons/si"
    tag = "SiAol"


class SiApache(rx.Component):
    library = "react-icons/si"
    tag = "SiApache"


class SiApacheairflow(rx.Component):
    library = "react-icons/si"
    tag = "SiApacheairflow"


class SiApacheant(rx.Component):
    library = "react-icons/si"
    tag = "SiApacheant"


class SiApachecassandra(rx.Component):
    library = "react-icons/si"
    tag = "SiApachecassandra"


class SiApachecloudstack(rx.Component):
    library = "react-icons/si"
    tag = "SiApachecloudstack"


class SiApachecordova(rx.Component):
    library = "react-icons/si"
    tag = "SiApachecordova"


class SiApachecouchdb(rx.Component):
    library = "react-icons/si"
    tag = "SiApachecouchdb"


class SiApachedruid(rx.Component):
    library = "react-icons/si"
    tag = "SiApachedruid"


class SiApacheecharts(rx.Component):
    library = "react-icons/si"
    tag = "SiApacheecharts"


class SiApacheflink(rx.Component):
    library = "react-icons/si"
    tag = "SiApacheflink"


class SiApachegroovy(rx.Component):
    library = "react-icons/si"
    tag = "SiApachegroovy"


class SiApachehadoop(rx.Component):
    library = "react-icons/si"
    tag = "SiApachehadoop"


class SiApachehive(rx.Component):
    library = "react-icons/si"
    tag = "SiApachehive"


class SiApachejmeter(rx.Component):
    library = "react-icons/si"
    tag = "SiApachejmeter"


class SiApachekafka(rx.Component):
    library = "react-icons/si"
    tag = "SiApachekafka"


class SiApachekylin(rx.Component):
    library = "react-icons/si"
    tag = "SiApachekylin"


class SiApachemaven(rx.Component):
    library = "react-icons/si"
    tag = "SiApachemaven"


class SiApachenetbeanside(rx.Component):
    library = "react-icons/si"
    tag = "SiApachenetbeanside"


class SiApacheopenoffice(rx.Component):
    library = "react-icons/si"
    tag = "SiApacheopenoffice"


class SiApachepulsar(rx.Component):
    library = "react-icons/si"
    tag = "SiApachepulsar"


class SiApacherocketmq(rx.Component):
    library = "react-icons/si"
    tag = "SiApacherocketmq"


class SiApachesolr(rx.Component):
    library = "react-icons/si"
    tag = "SiApachesolr"


class SiApachespark(rx.Component):
    library = "react-icons/si"
    tag = "SiApachespark"


class SiApachetomcat(rx.Component):
    library = "react-icons/si"
    tag = "SiApachetomcat"


class SiAparat(rx.Component):
    library = "react-icons/si"
    tag = "SiAparat"


class SiApollographql(rx.Component):
    library = "react-icons/si"
    tag = "SiApollographql"


class SiApostrophe(rx.Component):
    library = "react-icons/si"
    tag = "SiApostrophe"


class SiAppian(rx.Component):
    library = "react-icons/si"
    tag = "SiAppian"


class SiApple(rx.Component):
    library = "react-icons/si"
    tag = "SiApple"


class SiApplearcade(rx.Component):
    library = "react-icons/si"
    tag = "SiApplearcade"


class SiApplemusic(rx.Component):
    library = "react-icons/si"
    tag = "SiApplemusic"


class SiApplenews(rx.Component):
    library = "react-icons/si"
    tag = "SiApplenews"


class SiApplepay(rx.Component):
    library = "react-icons/si"
    tag = "SiApplepay"


class SiApplepodcasts(rx.Component):
    library = "react-icons/si"
    tag = "SiApplepodcasts"


class SiAppletv(rx.Component):
    library = "react-icons/si"
    tag = "SiAppletv"


class SiAppsignal(rx.Component):
    library = "react-icons/si"
    tag = "SiAppsignal"


class SiAppstore(rx.Component):
    library = "react-icons/si"
    tag = "SiAppstore"


class SiAppveyor(rx.Component):
    library = "react-icons/si"
    tag = "SiAppveyor"


class SiAppwrite(rx.Component):
    library = "react-icons/si"
    tag = "SiAppwrite"


class SiAqua(rx.Component):
    library = "react-icons/si"
    tag = "SiAqua"


class SiAral(rx.Component):
    library = "react-icons/si"
    tag = "SiAral"


class SiArangodb(rx.Component):
    library = "react-icons/si"
    tag = "SiArangodb"


class SiArcgis(rx.Component):
    library = "react-icons/si"
    tag = "SiArcgis"


class SiArchicad(rx.Component):
    library = "react-icons/si"
    tag = "SiArchicad"


class SiArchiveofourown(rx.Component):
    library = "react-icons/si"
    tag = "SiArchiveofourown"


class SiArchlinux(rx.Component):
    library = "react-icons/si"
    tag = "SiArchlinux"


class SiArdour(rx.Component):
    library = "react-icons/si"
    tag = "SiArdour"


class SiArduino(rx.Component):
    library = "react-icons/si"
    tag = "SiArduino"


class SiArgo(rx.Component):
    library = "react-icons/si"
    tag = "SiArgo"


class SiArgos(rx.Component):
    library = "react-icons/si"
    tag = "SiArgos"


class SiArkecosystem(rx.Component):
    library = "react-icons/si"
    tag = "SiArkecosystem"


class SiArlo(rx.Component):
    library = "react-icons/si"
    tag = "SiArlo"


class SiArm(rx.Component):
    library = "react-icons/si"
    tag = "SiArm"


class SiArtifacthub(rx.Component):
    library = "react-icons/si"
    tag = "SiArtifacthub"


class SiArtixlinux(rx.Component):
    library = "react-icons/si"
    tag = "SiArtixlinux"


class SiArtstation(rx.Component):
    library = "react-icons/si"
    tag = "SiArtstation"


class SiArxiv(rx.Component):
    library = "react-icons/si"
    tag = "SiArxiv"


class SiAsana(rx.Component):
    library = "react-icons/si"
    tag = "SiAsana"


class SiAsciidoctor(rx.Component):
    library = "react-icons/si"
    tag = "SiAsciidoctor"


class SiAsciinema(rx.Component):
    library = "react-icons/si"
    tag = "SiAsciinema"


class SiAsda(rx.Component):
    library = "react-icons/si"
    tag = "SiAsda"


class SiAseprite(rx.Component):
    library = "react-icons/si"
    tag = "SiAseprite"


class SiAskfm(rx.Component):
    library = "react-icons/si"
    tag = "SiAskfm"


class SiAskubuntu(rx.Component):
    library = "react-icons/si"
    tag = "SiAskubuntu"


class SiAssemblyscript(rx.Component):
    library = "react-icons/si"
    tag = "SiAssemblyscript"


class SiAstonmartin(rx.Component):
    library = "react-icons/si"
    tag = "SiAstonmartin"


class SiAstro(rx.Component):
    library = "react-icons/si"
    tag = "SiAstro"


class SiAsus(rx.Component):
    library = "react-icons/si"
    tag = "SiAsus"


class SiAtandt(rx.Component):
    library = "react-icons/si"
    tag = "SiAtandt"


class SiAtari(rx.Component):
    library = "react-icons/si"
    tag = "SiAtari"


class SiAtlassian(rx.Component):
    library = "react-icons/si"
    tag = "SiAtlassian"


class SiAtom(rx.Component):
    library = "react-icons/si"
    tag = "SiAtom"


class SiAuchan(rx.Component):
    library = "react-icons/si"
    tag = "SiAuchan"


class SiAudacity(rx.Component):
    library = "react-icons/si"
    tag = "SiAudacity"


class SiAudi(rx.Component):
    library = "react-icons/si"
    tag = "SiAudi"


class SiAudible(rx.Component):
    library = "react-icons/si"
    tag = "SiAudible"


class SiAudioboom(rx.Component):
    library = "react-icons/si"
    tag = "SiAudioboom"


class SiAudiomack(rx.Component):
    library = "react-icons/si"
    tag = "SiAudiomack"


class SiAudiotechnica(rx.Component):
    library = "react-icons/si"
    tag = "SiAudiotechnica"


class SiAurelia(rx.Component):
    library = "react-icons/si"
    tag = "SiAurelia"


class SiAuth0(rx.Component):
    library = "react-icons/si"
    tag = "SiAuth0"


class SiAuthy(rx.Component):
    library = "react-icons/si"
    tag = "SiAuthy"


class SiAutodesk(rx.Component):
    library = "react-icons/si"
    tag = "SiAutodesk"


class SiAutohotkey(rx.Component):
    library = "react-icons/si"
    tag = "SiAutohotkey"


class SiAutomattic(rx.Component):
    library = "react-icons/si"
    tag = "SiAutomattic"


class SiAutoprefixer(rx.Component):
    library = "react-icons/si"
    tag = "SiAutoprefixer"


class SiAvajs(rx.Component):
    library = "react-icons/si"
    tag = "SiAvajs"


class SiAvast(rx.Component):
    library = "react-icons/si"
    tag = "SiAvast"


class SiAwesomelists(rx.Component):
    library = "react-icons/si"
    tag = "SiAwesomelists"


class SiAwesomewm(rx.Component):
    library = "react-icons/si"
    tag = "SiAwesomewm"


class SiAwsamplify(rx.Component):
    library = "react-icons/si"
    tag = "SiAwsamplify"


class SiAwsfargate(rx.Component):
    library = "react-icons/si"
    tag = "SiAwsfargate"


class SiAwslambda(rx.Component):
    library = "react-icons/si"
    tag = "SiAwslambda"


class SiAxios(rx.Component):
    library = "react-icons/si"
    tag = "SiAxios"


class SiAzureartifacts(rx.Component):
    library = "react-icons/si"
    tag = "SiAzureartifacts"


class SiAzuredataexplorer(rx.Component):
    library = "react-icons/si"
    tag = "SiAzuredataexplorer"


class SiAzuredevops(rx.Component):
    library = "react-icons/si"
    tag = "SiAzuredevops"


class SiAzurefunctions(rx.Component):
    library = "react-icons/si"
    tag = "SiAzurefunctions"


class SiAzurepipelines(rx.Component):
    library = "react-icons/si"
    tag = "SiAzurepipelines"


class SiBabel(rx.Component):
    library = "react-icons/si"
    tag = "SiBabel"


class SiBackblaze(rx.Component):
    library = "react-icons/si"
    tag = "SiBackblaze"


class SiBackbonedotjs(rx.Component):
    library = "react-icons/si"
    tag = "SiBackbonedotjs"


class SiBackendless(rx.Component):
    library = "react-icons/si"
    tag = "SiBackendless"


class SiBackstage(rx.Component):
    library = "react-icons/si"
    tag = "SiBackstage"


class SiBadgr(rx.Component):
    library = "react-icons/si"
    tag = "SiBadgr"


class SiBadoo(rx.Component):
    library = "react-icons/si"
    tag = "SiBadoo"


class SiBaidu(rx.Component):
    library = "react-icons/si"
    tag = "SiBaidu"


class SiBamboo(rx.Component):
    library = "react-icons/si"
    tag = "SiBamboo"


class SiBandcamp(rx.Component):
    library = "react-icons/si"
    tag = "SiBandcamp"


class SiBandlab(rx.Component):
    library = "react-icons/si"
    tag = "SiBandlab"


class SiBandrautomation(rx.Component):
    library = "react-icons/si"
    tag = "SiBandrautomation"


class SiBandsintown(rx.Component):
    library = "react-icons/si"
    tag = "SiBandsintown"


class SiBankofamerica(rx.Component):
    library = "react-icons/si"
    tag = "SiBankofamerica"


class SiBarclays(rx.Component):
    library = "react-icons/si"
    tag = "SiBarclays"


class SiBaremetrics(rx.Component):
    library = "react-icons/si"
    tag = "SiBaremetrics"


class SiBasecamp(rx.Component):
    library = "react-icons/si"
    tag = "SiBasecamp"


class SiBastyon(rx.Component):
    library = "react-icons/si"
    tag = "SiBastyon"


class SiBata(rx.Component):
    library = "react-icons/si"
    tag = "SiBata"


class SiBathasu(rx.Component):
    library = "react-icons/si"
    tag = "SiBathasu"


class SiBattledotnet(rx.Component):
    library = "react-icons/si"
    tag = "SiBattledotnet"


class SiBbc(rx.Component):
    library = "react-icons/si"
    tag = "SiBbc"


class SiBbciplayer(rx.Component):
    library = "react-icons/si"
    tag = "SiBbciplayer"


class SiBeatport(rx.Component):
    library = "react-icons/si"
    tag = "SiBeatport"


class SiBeats(rx.Component):
    library = "react-icons/si"
    tag = "SiBeats"


class SiBeatsbydre(rx.Component):
    library = "react-icons/si"
    tag = "SiBeatsbydre"


class SiBehance(rx.Component):
    library = "react-icons/si"
    tag = "SiBehance"


class SiBeijingsubway(rx.Component):
    library = "react-icons/si"
    tag = "SiBeijingsubway"


class SiBem(rx.Component):
    library = "react-icons/si"
    tag = "SiBem"


class SiBentley(rx.Component):
    library = "react-icons/si"
    tag = "SiBentley"


class SiBento(rx.Component):
    library = "react-icons/si"
    tag = "SiBento"


class SiBetfair(rx.Component):
    library = "react-icons/si"
    tag = "SiBetfair"


class SiBigbasket(rx.Component):
    library = "react-icons/si"
    tag = "SiBigbasket"


class SiBigbluebutton(rx.Component):
    library = "react-icons/si"
    tag = "SiBigbluebutton"


class SiBigcartel(rx.Component):
    library = "react-icons/si"
    tag = "SiBigcartel"


class SiBigcommerce(rx.Component):
    library = "react-icons/si"
    tag = "SiBigcommerce"


class SiBilibili(rx.Component):
    library = "react-icons/si"
    tag = "SiBilibili"


class SiBillboard(rx.Component):
    library = "react-icons/si"
    tag = "SiBillboard"


class SiBim(rx.Component):
    library = "react-icons/si"
    tag = "SiBim"


class SiBinance(rx.Component):
    library = "react-icons/si"
    tag = "SiBinance"


class SiBiolink(rx.Component):
    library = "react-icons/si"
    tag = "SiBiolink"


class SiBit(rx.Component):
    library = "react-icons/si"
    tag = "SiBit"


class SiBitbucket(rx.Component):
    library = "react-icons/si"
    tag = "SiBitbucket"


class SiBitcoin(rx.Component):
    library = "react-icons/si"
    tag = "SiBitcoin"


class SiBitcoincash(rx.Component):
    library = "react-icons/si"
    tag = "SiBitcoincash"


class SiBitcoinsv(rx.Component):
    library = "react-icons/si"
    tag = "SiBitcoinsv"


class SiBitdefender(rx.Component):
    library = "react-icons/si"
    tag = "SiBitdefender"


class SiBitly(rx.Component):
    library = "react-icons/si"
    tag = "SiBitly"


class SiBitrise(rx.Component):
    library = "react-icons/si"
    tag = "SiBitrise"


class SiBitwarden(rx.Component):
    library = "react-icons/si"
    tag = "SiBitwarden"


class SiBitwig(rx.Component):
    library = "react-icons/si"
    tag = "SiBitwig"


class SiBlackberry(rx.Component):
    library = "react-icons/si"
    tag = "SiBlackberry"


class SiBlazemeter(rx.Component):
    library = "react-icons/si"
    tag = "SiBlazemeter"


class SiBlazor(rx.Component):
    library = "react-icons/si"
    tag = "SiBlazor"


class SiBlender(rx.Component):
    library = "react-icons/si"
    tag = "SiBlender"


class SiBlockchaindotcom(rx.Component):
    library = "react-icons/si"
    tag = "SiBlockchaindotcom"


class SiBlogger(rx.Component):
    library = "react-icons/si"
    tag = "SiBlogger"


class SiBloglovin(rx.Component):
    library = "react-icons/si"
    tag = "SiBloglovin"


class SiBlueprint(rx.Component):
    library = "react-icons/si"
    tag = "SiBlueprint"


class SiBluetooth(rx.Component):
    library = "react-icons/si"
    tag = "SiBluetooth"


class SiBmcsoftware(rx.Component):
    library = "react-icons/si"
    tag = "SiBmcsoftware"


class SiBmw(rx.Component):
    library = "react-icons/si"
    tag = "SiBmw"


class SiBoardgamegeek(rx.Component):
    library = "react-icons/si"
    tag = "SiBoardgamegeek"


class SiBoehringeringelheim(rx.Component):
    library = "react-icons/si"
    tag = "SiBoehringeringelheim"


class SiBoeing(rx.Component):
    library = "react-icons/si"
    tag = "SiBoeing"


class SiBookalope(rx.Component):
    library = "react-icons/si"
    tag = "SiBookalope"


class SiBookbub(rx.Component):
    library = "react-icons/si"
    tag = "SiBookbub"


class SiBookmeter(rx.Component):
    library = "react-icons/si"
    tag = "SiBookmeter"


class SiBookmyshow(rx.Component):
    library = "react-icons/si"
    tag = "SiBookmyshow"


class SiBookstack(rx.Component):
    library = "react-icons/si"
    tag = "SiBookstack"


class SiBoost(rx.Component):
    library = "react-icons/si"
    tag = "SiBoost"


class SiBoots(rx.Component):
    library = "react-icons/si"
    tag = "SiBoots"


class SiBootstrap(rx.Component):
    library = "react-icons/si"
    tag = "SiBootstrap"


class SiBorgbackup(rx.Component):
    library = "react-icons/si"
    tag = "SiBorgbackup"


class SiBosch(rx.Component):
    library = "react-icons/si"
    tag = "SiBosch"


class SiBose(rx.Component):
    library = "react-icons/si"
    tag = "SiBose"


class SiBotblecms(rx.Component):
    library = "react-icons/si"
    tag = "SiBotblecms"


class SiBoulanger(rx.Component):
    library = "react-icons/si"
    tag = "SiBoulanger"


class SiBower(rx.Component):
    library = "react-icons/si"
    tag = "SiBower"


class SiBox(rx.Component):
    library = "react-icons/si"
    tag = "SiBox"


class SiBoxysvg(rx.Component):
    library = "react-icons/si"
    tag = "SiBoxysvg"


class SiBrandfolder(rx.Component):
    library = "react-icons/si"
    tag = "SiBrandfolder"


class SiBrave(rx.Component):
    library = "react-icons/si"
    tag = "SiBrave"


class SiBreaker(rx.Component):
    library = "react-icons/si"
    tag = "SiBreaker"


class SiBritishairways(rx.Component):
    library = "react-icons/si"
    tag = "SiBritishairways"


class SiBroadcom(rx.Component):
    library = "react-icons/si"
    tag = "SiBroadcom"


class SiBt(rx.Component):
    library = "react-icons/si"
    tag = "SiBt"


class SiBuddy(rx.Component):
    library = "react-icons/si"
    tag = "SiBuddy"


class SiBudibase(rx.Component):
    library = "react-icons/si"
    tag = "SiBudibase"


class SiBuefy(rx.Component):
    library = "react-icons/si"
    tag = "SiBuefy"


class SiBuffer(rx.Component):
    library = "react-icons/si"
    tag = "SiBuffer"


class SiBugatti(rx.Component):
    library = "react-icons/si"
    tag = "SiBugatti"


class SiBugcrowd(rx.Component):
    library = "react-icons/si"
    tag = "SiBugcrowd"


class SiBugsnag(rx.Component):
    library = "react-icons/si"
    tag = "SiBugsnag"


class SiBuildkite(rx.Component):
    library = "react-icons/si"
    tag = "SiBuildkite"


class SiBukalapak(rx.Component):
    library = "react-icons/si"
    tag = "SiBukalapak"


class SiBulma(rx.Component):
    library = "react-icons/si"
    tag = "SiBulma"


class SiBun(rx.Component):
    library = "react-icons/si"
    tag = "SiBun"


class SiBunq(rx.Component):
    library = "react-icons/si"
    tag = "SiBunq"


class SiBurgerking(rx.Component):
    library = "react-icons/si"
    tag = "SiBurgerking"


class SiBurton(rx.Component):
    library = "react-icons/si"
    tag = "SiBurton"


class SiBuymeacoffee(rx.Component):
    library = "react-icons/si"
    tag = "SiBuymeacoffee"


class SiBuzzfeed(rx.Component):
    library = "react-icons/si"
    tag = "SiBuzzfeed"


class SiBvg(rx.Component):
    library = "react-icons/si"
    tag = "SiBvg"


class SiByjus(rx.Component):
    library = "react-icons/si"
    tag = "SiByjus"


class SiByte(rx.Component):
    library = "react-icons/si"
    tag = "SiByte"


class SiBytedance(rx.Component):
    library = "react-icons/si"
    tag = "SiBytedance"


class SiC(rx.Component):
    library = "react-icons/si"
    tag = "SiC"


class SiCachet(rx.Component):
    library = "react-icons/si"
    tag = "SiCachet"


class SiCafepress(rx.Component):
    library = "react-icons/si"
    tag = "SiCafepress"


class SiCaffeine(rx.Component):
    library = "react-icons/si"
    tag = "SiCaffeine"


class SiCairographics(rx.Component):
    library = "react-icons/si"
    tag = "SiCairographics"


class SiCairometro(rx.Component):
    library = "react-icons/si"
    tag = "SiCairometro"


class SiCakephp(rx.Component):
    library = "react-icons/si"
    tag = "SiCakephp"


class SiCampaignmonitor(rx.Component):
    library = "react-icons/si"
    tag = "SiCampaignmonitor"


class SiCanonical(rx.Component):
    library = "react-icons/si"
    tag = "SiCanonical"


class SiCanva(rx.Component):
    library = "react-icons/si"
    tag = "SiCanva"


class SiCapacitor(rx.Component):
    library = "react-icons/si"
    tag = "SiCapacitor"


class SiCardano(rx.Component):
    library = "react-icons/si"
    tag = "SiCardano"


class SiCarrefour(rx.Component):
    library = "react-icons/si"
    tag = "SiCarrefour"


class SiCarthrottle(rx.Component):
    library = "react-icons/si"
    tag = "SiCarthrottle"


class SiCarto(rx.Component):
    library = "react-icons/si"
    tag = "SiCarto"


class SiCashapp(rx.Component):
    library = "react-icons/si"
    tag = "SiCashapp"


class SiCastbox(rx.Component):
    library = "react-icons/si"
    tag = "SiCastbox"


class SiCastorama(rx.Component):
    library = "react-icons/si"
    tag = "SiCastorama"


class SiCastro(rx.Component):
    library = "react-icons/si"
    tag = "SiCastro"


class SiCaterpillar(rx.Component):
    library = "react-icons/si"
    tag = "SiCaterpillar"


class SiCbs(rx.Component):
    library = "react-icons/si"
    tag = "SiCbs"


class SiCdprojekt(rx.Component):
    library = "react-icons/si"
    tag = "SiCdprojekt"


class SiCelery(rx.Component):
    library = "react-icons/si"
    tag = "SiCelery"


class SiCentos(rx.Component):
    library = "react-icons/si"
    tag = "SiCentos"


class SiCeph(rx.Component):
    library = "react-icons/si"
    tag = "SiCeph"


class SiCesium(rx.Component):
    library = "react-icons/si"
    tag = "SiCesium"


class SiChai(rx.Component):
    library = "react-icons/si"
    tag = "SiChai"


class SiChainguard(rx.Component):
    library = "react-icons/si"
    tag = "SiChainguard"


class SiChainlink(rx.Component):
    library = "react-icons/si"
    tag = "SiChainlink"


class SiChakraui(rx.Component):
    library = "react-icons/si"
    tag = "SiChakraui"


class SiChartdotjs(rx.Component):
    library = "react-icons/si"
    tag = "SiChartdotjs"


class SiChartmogul(rx.Component):
    library = "react-icons/si"
    tag = "SiChartmogul"


class SiChase(rx.Component):
    library = "react-icons/si"
    tag = "SiChase"


class SiChatbot(rx.Component):
    library = "react-icons/si"
    tag = "SiChatbot"


class SiCheckio(rx.Component):
    library = "react-icons/si"
    tag = "SiCheckio"


class SiCheckmarx(rx.Component):
    library = "react-icons/si"
    tag = "SiCheckmarx"


class SiChef(rx.Component):
    library = "react-icons/si"
    tag = "SiChef"


class SiChemex(rx.Component):
    library = "react-icons/si"
    tag = "SiChemex"


class SiChevrolet(rx.Component):
    library = "react-icons/si"
    tag = "SiChevrolet"


class SiChinaeasternairlines(rx.Component):
    library = "react-icons/si"
    tag = "SiChinaeasternairlines"


class SiChinasouthernairlines(rx.Component):
    library = "react-icons/si"
    tag = "SiChinasouthernairlines"


class SiChocolatey(rx.Component):
    library = "react-icons/si"
    tag = "SiChocolatey"


class SiChromecast(rx.Component):
    library = "react-icons/si"
    tag = "SiChromecast"


class SiChrysler(rx.Component):
    library = "react-icons/si"
    tag = "SiChrysler"


class SiChupachups(rx.Component):
    library = "react-icons/si"
    tag = "SiChupachups"


class SiCilium(rx.Component):
    library = "react-icons/si"
    tag = "SiCilium"


class SiCinema4D(rx.Component):
    library = "react-icons/si"
    tag = "SiCinema4D"


class SiCircle(rx.Component):
    library = "react-icons/si"
    tag = "SiCircle"


class SiCircleci(rx.Component):
    library = "react-icons/si"
    tag = "SiCircleci"


class SiCircuitverse(rx.Component):
    library = "react-icons/si"
    tag = "SiCircuitverse"


class SiCirrusci(rx.Component):
    library = "react-icons/si"
    tag = "SiCirrusci"


class SiCisco(rx.Component):
    library = "react-icons/si"
    tag = "SiCisco"


class SiCitrix(rx.Component):
    library = "react-icons/si"
    tag = "SiCitrix"


class SiCitroen(rx.Component):
    library = "react-icons/si"
    tag = "SiCitroen"


class SiCivicrm(rx.Component):
    library = "react-icons/si"
    tag = "SiCivicrm"


class SiCivo(rx.Component):
    library = "react-icons/si"
    tag = "SiCivo"


class SiCkeditor4(rx.Component):
    library = "react-icons/si"
    tag = "SiCkeditor4"


class SiClaris(rx.Component):
    library = "react-icons/si"
    tag = "SiClaris"


class SiClickhouse(rx.Component):
    library = "react-icons/si"
    tag = "SiClickhouse"


class SiClickup(rx.Component):
    library = "react-icons/si"
    tag = "SiClickup"


class SiClion(rx.Component):
    library = "react-icons/si"
    tag = "SiClion"


class SiCliqz(rx.Component):
    library = "react-icons/si"
    tag = "SiCliqz"


class SiClockify(rx.Component):
    library = "react-icons/si"
    tag = "SiClockify"


class SiClojure(rx.Component):
    library = "react-icons/si"
    tag = "SiClojure"


class SiCloud66(rx.Component):
    library = "react-icons/si"
    tag = "SiCloud66"


class SiCloudbees(rx.Component):
    library = "react-icons/si"
    tag = "SiCloudbees"


class SiCloudcannon(rx.Component):
    library = "react-icons/si"
    tag = "SiCloudcannon"


class SiCloudera(rx.Component):
    library = "react-icons/si"
    tag = "SiCloudera"


class SiCloudflare(rx.Component):
    library = "react-icons/si"
    tag = "SiCloudflare"


class SiCloudflarepages(rx.Component):
    library = "react-icons/si"
    tag = "SiCloudflarepages"


class SiCloudfoundry(rx.Component):
    library = "react-icons/si"
    tag = "SiCloudfoundry"


class SiCloudsmith(rx.Component):
    library = "react-icons/si"
    tag = "SiCloudsmith"


class SiCloudways(rx.Component):
    library = "react-icons/si"
    tag = "SiCloudways"


class SiClubhouse(rx.Component):
    library = "react-icons/si"
    tag = "SiClubhouse"


class SiClyp(rx.Component):
    library = "react-icons/si"
    tag = "SiClyp"


class SiCmake(rx.Component):
    library = "react-icons/si"
    tag = "SiCmake"


class SiCncf(rx.Component):
    library = "react-icons/si"
    tag = "SiCncf"


class SiCnn(rx.Component):
    library = "react-icons/si"
    tag = "SiCnn"


class SiCocacola(rx.Component):
    library = "react-icons/si"
    tag = "SiCocacola"


class SiCockpit(rx.Component):
    library = "react-icons/si"
    tag = "SiCockpit"


class SiCockroachlabs(rx.Component):
    library = "react-icons/si"
    tag = "SiCockroachlabs"


class SiCocoapods(rx.Component):
    library = "react-icons/si"
    tag = "SiCocoapods"


class SiCocos(rx.Component):
    library = "react-icons/si"
    tag = "SiCocos"


class SiCoda(rx.Component):
    library = "react-icons/si"
    tag = "SiCoda"


class SiCodacy(rx.Component):
    library = "react-icons/si"
    tag = "SiCodacy"


class SiCodeberg(rx.Component):
    library = "react-icons/si"
    tag = "SiCodeberg"


class SiCodecademy(rx.Component):
    library = "react-icons/si"
    tag = "SiCodecademy"


class SiCodeceptjs(rx.Component):
    library = "react-icons/si"
    tag = "SiCodeceptjs"


class SiCodechef(rx.Component):
    library = "react-icons/si"
    tag = "SiCodechef"


class SiCodeclimate(rx.Component):
    library = "react-icons/si"
    tag = "SiCodeclimate"


class SiCodecov(rx.Component):
    library = "react-icons/si"
    tag = "SiCodecov"


class SiCodefactor(rx.Component):
    library = "react-icons/si"
    tag = "SiCodefactor"


class SiCodeforces(rx.Component):
    library = "react-icons/si"
    tag = "SiCodeforces"


class SiCodeigniter(rx.Component):
    library = "react-icons/si"
    tag = "SiCodeigniter"


class SiCodemagic(rx.Component):
    library = "react-icons/si"
    tag = "SiCodemagic"


class SiCodemirror(rx.Component):
    library = "react-icons/si"
    tag = "SiCodemirror"


class SiCodenewbie(rx.Component):
    library = "react-icons/si"
    tag = "SiCodenewbie"


class SiCodepen(rx.Component):
    library = "react-icons/si"
    tag = "SiCodepen"


class SiCodeproject(rx.Component):
    library = "react-icons/si"
    tag = "SiCodeproject"


class SiCodereview(rx.Component):
    library = "react-icons/si"
    tag = "SiCodereview"


class SiCodersrank(rx.Component):
    library = "react-icons/si"
    tag = "SiCodersrank"


class SiCoderwall(rx.Component):
    library = "react-icons/si"
    tag = "SiCoderwall"


class SiCodesandbox(rx.Component):
    library = "react-icons/si"
    tag = "SiCodesandbox"


class SiCodeship(rx.Component):
    library = "react-icons/si"
    tag = "SiCodeship"


class SiCodewars(rx.Component):
    library = "react-icons/si"
    tag = "SiCodewars"


class SiCodingame(rx.Component):
    library = "react-icons/si"
    tag = "SiCodingame"


class SiCodingninjas(rx.Component):
    library = "react-icons/si"
    tag = "SiCodingninjas"


class SiCodio(rx.Component):
    library = "react-icons/si"
    tag = "SiCodio"


class SiCoffeescript(rx.Component):
    library = "react-icons/si"
    tag = "SiCoffeescript"


class SiCognizant(rx.Component):
    library = "react-icons/si"
    tag = "SiCognizant"


class SiCoil(rx.Component):
    library = "react-icons/si"
    tag = "SiCoil"


class SiCoinbase(rx.Component):
    library = "react-icons/si"
    tag = "SiCoinbase"


class SiCoinmarketcap(rx.Component):
    library = "react-icons/si"
    tag = "SiCoinmarketcap"


class SiCommerzbank(rx.Component):
    library = "react-icons/si"
    tag = "SiCommerzbank"


class SiCommitlint(rx.Component):
    library = "react-icons/si"
    tag = "SiCommitlint"


class SiCommodore(rx.Component):
    library = "react-icons/si"
    tag = "SiCommodore"


class SiCommonworkflowlanguage(rx.Component):
    library = "react-icons/si"
    tag = "SiCommonworkflowlanguage"


class SiCompilerexplorer(rx.Component):
    library = "react-icons/si"
    tag = "SiCompilerexplorer"


class SiComposer(rx.Component):
    library = "react-icons/si"
    tag = "SiComposer"


class SiComsol(rx.Component):
    library = "react-icons/si"
    tag = "SiComsol"


class SiConan(rx.Component):
    library = "react-icons/si"
    tag = "SiConan"


class SiConcourse(rx.Component):
    library = "react-icons/si"
    tag = "SiConcourse"


class SiCondaforge(rx.Component):
    library = "react-icons/si"
    tag = "SiCondaforge"


class SiConekta(rx.Component):
    library = "react-icons/si"
    tag = "SiConekta"


class SiConfluence(rx.Component):
    library = "react-icons/si"
    tag = "SiConfluence"


class SiConstruct3(rx.Component):
    library = "react-icons/si"
    tag = "SiConstruct3"


class SiConsul(rx.Component):
    library = "react-icons/si"
    tag = "SiConsul"


class SiContactlesspayment(rx.Component):
    library = "react-icons/si"
    tag = "SiContactlesspayment"


class SiContainerd(rx.Component):
    library = "react-icons/si"
    tag = "SiContainerd"


class SiContao(rx.Component):
    library = "react-icons/si"
    tag = "SiContao"


class SiContentful(rx.Component):
    library = "react-icons/si"
    tag = "SiContentful"


class SiConventionalcommits(rx.Component):
    library = "react-icons/si"
    tag = "SiConventionalcommits"


class SiConvertio(rx.Component):
    library = "react-icons/si"
    tag = "SiConvertio"


class SiCookiecutter(rx.Component):
    library = "react-icons/si"
    tag = "SiCookiecutter"


class SiCoop(rx.Component):
    library = "react-icons/si"
    tag = "SiCoop"


class SiCora(rx.Component):
    library = "react-icons/si"
    tag = "SiCora"


class SiCoronaengine(rx.Component):
    library = "react-icons/si"
    tag = "SiCoronaengine"


class SiCoronarenderer(rx.Component):
    library = "react-icons/si"
    tag = "SiCoronarenderer"


class SiCorsair(rx.Component):
    library = "react-icons/si"
    tag = "SiCorsair"


class SiCouchbase(rx.Component):
    library = "react-icons/si"
    tag = "SiCouchbase"


class SiCounterstrike(rx.Component):
    library = "react-icons/si"
    tag = "SiCounterstrike"


class SiCountingworkspro(rx.Component):
    library = "react-icons/si"
    tag = "SiCountingworkspro"


class SiCoursera(rx.Component):
    library = "react-icons/si"
    tag = "SiCoursera"


class SiCoveralls(rx.Component):
    library = "react-icons/si"
    tag = "SiCoveralls"


class SiCpanel(rx.Component):
    library = "react-icons/si"
    tag = "SiCpanel"


class SiCplusplus(rx.Component):
    library = "react-icons/si"
    tag = "SiCplusplus"


class SiCraftcms(rx.Component):
    library = "react-icons/si"
    tag = "SiCraftcms"


class SiCratedb(rx.Component):
    library = "react-icons/si"
    tag = "SiCratedb"


class SiCrayon(rx.Component):
    library = "react-icons/si"
    tag = "SiCrayon"


class SiCreatereactapp(rx.Component):
    library = "react-icons/si"
    tag = "SiCreatereactapp"


class SiCreativecommons(rx.Component):
    library = "react-icons/si"
    tag = "SiCreativecommons"


class SiCreativetechnology(rx.Component):
    library = "react-icons/si"
    tag = "SiCreativetechnology"


class SiCredly(rx.Component):
    library = "react-icons/si"
    tag = "SiCredly"


class SiCrehana(rx.Component):
    library = "react-icons/si"
    tag = "SiCrehana"


class SiCriticalrole(rx.Component):
    library = "react-icons/si"
    tag = "SiCriticalrole"


class SiCrowdin(rx.Component):
    library = "react-icons/si"
    tag = "SiCrowdin"


class SiCrowdsource(rx.Component):
    library = "react-icons/si"
    tag = "SiCrowdsource"


class SiCrunchbase(rx.Component):
    library = "react-icons/si"
    tag = "SiCrunchbase"


class SiCrunchyroll(rx.Component):
    library = "react-icons/si"
    tag = "SiCrunchyroll"


class SiCryengine(rx.Component):
    library = "react-icons/si"
    tag = "SiCryengine"


class SiCrystal(rx.Component):
    library = "react-icons/si"
    tag = "SiCrystal"


class SiCsharp(rx.Component):
    library = "react-icons/si"
    tag = "SiCsharp"


class SiCss3(rx.Component):
    library = "react-icons/si"
    tag = "SiCss3"


class SiCssmodules(rx.Component):
    library = "react-icons/si"
    tag = "SiCssmodules"


class SiCsswizardry(rx.Component):
    library = "react-icons/si"
    tag = "SiCsswizardry"


class SiCts(rx.Component):
    library = "react-icons/si"
    tag = "SiCts"


class SiCucumber(rx.Component):
    library = "react-icons/si"
    tag = "SiCucumber"


class SiCultura(rx.Component):
    library = "react-icons/si"
    tag = "SiCultura"


class SiCurl(rx.Component):
    library = "react-icons/si"
    tag = "SiCurl"


class SiCurseforge(rx.Component):
    library = "react-icons/si"
    tag = "SiCurseforge"


class SiCycling74(rx.Component):
    library = "react-icons/si"
    tag = "SiCycling74"


class SiCypress(rx.Component):
    library = "react-icons/si"
    tag = "SiCypress"


class SiCytoscapedotjs(rx.Component):
    library = "react-icons/si"
    tag = "SiCytoscapedotjs"


class SiD(rx.Component):
    library = "react-icons/si"
    tag = "SiD"


class SiD3Dotjs(rx.Component):
    library = "react-icons/si"
    tag = "SiD3Dotjs"


class SiDacia(rx.Component):
    library = "react-icons/si"
    tag = "SiDacia"


class SiDaf(rx.Component):
    library = "react-icons/si"
    tag = "SiDaf"


class SiDailymotion(rx.Component):
    library = "react-icons/si"
    tag = "SiDailymotion"


class SiDaimler(rx.Component):
    library = "react-icons/si"
    tag = "SiDaimler"


class SiDaisyui(rx.Component):
    library = "react-icons/si"
    tag = "SiDaisyui"


class SiDapr(rx.Component):
    library = "react-icons/si"
    tag = "SiDapr"


class SiDarkreader(rx.Component):
    library = "react-icons/si"
    tag = "SiDarkreader"


class SiDart(rx.Component):
    library = "react-icons/si"
    tag = "SiDart"


class SiDarty(rx.Component):
    library = "react-icons/si"
    tag = "SiDarty"


class SiDaserste(rx.Component):
    library = "react-icons/si"
    tag = "SiDaserste"


class SiDash(rx.Component):
    library = "react-icons/si"
    tag = "SiDash"


class SiDashlane(rx.Component):
    library = "react-icons/si"
    tag = "SiDashlane"


class SiDask(rx.Component):
    library = "react-icons/si"
    tag = "SiDask"


class SiDassaultsystemes(rx.Component):
    library = "react-icons/si"
    tag = "SiDassaultsystemes"


class SiDatabricks(rx.Component):
    library = "react-icons/si"
    tag = "SiDatabricks"


class SiDatacamp(rx.Component):
    library = "react-icons/si"
    tag = "SiDatacamp"


class SiDatadog(rx.Component):
    library = "react-icons/si"
    tag = "SiDatadog"


class SiDatadotai(rx.Component):
    library = "react-icons/si"
    tag = "SiDatadotai"


class SiDatagrip(rx.Component):
    library = "react-icons/si"
    tag = "SiDatagrip"


class SiDataiku(rx.Component):
    library = "react-icons/si"
    tag = "SiDataiku"


class SiDatastax(rx.Component):
    library = "react-icons/si"
    tag = "SiDatastax"


class SiDataverse(rx.Component):
    library = "react-icons/si"
    tag = "SiDataverse"


class SiDatocms(rx.Component):
    library = "react-icons/si"
    tag = "SiDatocms"


class SiDatto(rx.Component):
    library = "react-icons/si"
    tag = "SiDatto"


class SiDazn(rx.Component):
    library = "react-icons/si"
    tag = "SiDazn"


class SiDblp(rx.Component):
    library = "react-icons/si"
    tag = "SiDblp"


class SiDbt(rx.Component):
    library = "react-icons/si"
    tag = "SiDbt"


class SiDcentertainment(rx.Component):
    library = "react-icons/si"
    tag = "SiDcentertainment"


class SiDebian(rx.Component):
    library = "react-icons/si"
    tag = "SiDebian"


class SiDedge(rx.Component):
    library = "react-icons/si"
    tag = "SiDedge"


class SiDeepin(rx.Component):
    library = "react-icons/si"
    tag = "SiDeepin"


class SiDeepnote(rx.Component):
    library = "react-icons/si"
    tag = "SiDeepnote"


class SiDeezer(rx.Component):
    library = "react-icons/si"
    tag = "SiDeezer"


class SiDelicious(rx.Component):
    library = "react-icons/si"
    tag = "SiDelicious"


class SiDeliveroo(rx.Component):
    library = "react-icons/si"
    tag = "SiDeliveroo"


class SiDell(rx.Component):
    library = "react-icons/si"
    tag = "SiDell"


class SiDelonghi(rx.Component):
    library = "react-icons/si"
    tag = "SiDelonghi"


class SiDelphi(rx.Component):
    library = "react-icons/si"
    tag = "SiDelphi"


class SiDelta(rx.Component):
    library = "react-icons/si"
    tag = "SiDelta"


class SiDeno(rx.Component):
    library = "react-icons/si"
    tag = "SiDeno"


class SiDependabot(rx.Component):
    library = "react-icons/si"
    tag = "SiDependabot"


class SiDerspiegel(rx.Component):
    library = "react-icons/si"
    tag = "SiDerspiegel"


class SiDesignernews(rx.Component):
    library = "react-icons/si"
    tag = "SiDesignernews"


class SiDeutschebahn(rx.Component):
    library = "react-icons/si"
    tag = "SiDeutschebahn"


class SiDeutschebank(rx.Component):
    library = "react-icons/si"
    tag = "SiDeutschebank"


class SiDevdotto(rx.Component):
    library = "react-icons/si"
    tag = "SiDevdotto"


class SiDevexpress(rx.Component):
    library = "react-icons/si"
    tag = "SiDevexpress"


class SiDeviantart(rx.Component):
    library = "react-icons/si"
    tag = "SiDeviantart"


class SiDevpost(rx.Component):
    library = "react-icons/si"
    tag = "SiDevpost"


class SiDevrant(rx.Component):
    library = "react-icons/si"
    tag = "SiDevrant"


class SiDgraph(rx.Component):
    library = "react-icons/si"
    tag = "SiDgraph"


class SiDhl(rx.Component):
    library = "react-icons/si"
    tag = "SiDhl"


class SiDiagramsdotnet(rx.Component):
    library = "react-icons/si"
    tag = "SiDiagramsdotnet"


class SiDialogflow(rx.Component):
    library = "react-icons/si"
    tag = "SiDialogflow"


class SiDiaspora(rx.Component):
    library = "react-icons/si"
    tag = "SiDiaspora"


class SiDigg(rx.Component):
    library = "react-icons/si"
    tag = "SiDigg"


class SiDigikeyelectronics(rx.Component):
    library = "react-icons/si"
    tag = "SiDigikeyelectronics"


class SiDigitalocean(rx.Component):
    library = "react-icons/si"
    tag = "SiDigitalocean"


class SiDior(rx.Component):
    library = "react-icons/si"
    tag = "SiDior"


class SiDirectus(rx.Component):
    library = "react-icons/si"
    tag = "SiDirectus"


class SiDiscogs(rx.Component):
    library = "react-icons/si"
    tag = "SiDiscogs"


class SiDiscord(rx.Component):
    library = "react-icons/si"
    tag = "SiDiscord"


class SiDiscourse(rx.Component):
    library = "react-icons/si"
    tag = "SiDiscourse"


class SiDiscover(rx.Component):
    library = "react-icons/si"
    tag = "SiDiscover"


class SiDisqus(rx.Component):
    library = "react-icons/si"
    tag = "SiDisqus"


class SiDisroot(rx.Component):
    library = "react-icons/si"
    tag = "SiDisroot"


class SiDjango(rx.Component):
    library = "react-icons/si"
    tag = "SiDjango"


class SiDlib(rx.Component):
    library = "react-icons/si"
    tag = "SiDlib"


class SiDlna(rx.Component):
    library = "react-icons/si"
    tag = "SiDlna"


class SiDm(rx.Component):
    library = "react-icons/si"
    tag = "SiDm"


class SiDocker(rx.Component):
    library = "react-icons/si"
    tag = "SiDocker"


class SiDocsdotrs(rx.Component):
    library = "react-icons/si"
    tag = "SiDocsdotrs"


class SiDocusign(rx.Component):
    library = "react-icons/si"
    tag = "SiDocusign"


class SiDogecoin(rx.Component):
    library = "react-icons/si"
    tag = "SiDogecoin"


class SiDolby(rx.Component):
    library = "react-icons/si"
    tag = "SiDolby"


class SiDoordash(rx.Component):
    library = "react-icons/si"
    tag = "SiDoordash"


class SiDotenv(rx.Component):
    library = "react-icons/si"
    tag = "SiDotenv"


class SiDotnet(rx.Component):
    library = "react-icons/si"
    tag = "SiDotnet"


class SiDouban(rx.Component):
    library = "react-icons/si"
    tag = "SiDouban"


class SiDoubanread(rx.Component):
    library = "react-icons/si"
    tag = "SiDoubanread"


class SiDovecot(rx.Component):
    library = "react-icons/si"
    tag = "SiDovecot"


class SiDpd(rx.Component):
    library = "react-icons/si"
    tag = "SiDpd"


class SiDragonframe(rx.Component):
    library = "react-icons/si"
    tag = "SiDragonframe"


class SiDraugiemdotlv(rx.Component):
    library = "react-icons/si"
    tag = "SiDraugiemdotlv"


class SiDribbble(rx.Component):
    library = "react-icons/si"
    tag = "SiDribbble"


class SiDrone(rx.Component):
    library = "react-icons/si"
    tag = "SiDrone"


class SiDrooble(rx.Component):
    library = "react-icons/si"
    tag = "SiDrooble"


class SiDropbox(rx.Component):
    library = "react-icons/si"
    tag = "SiDropbox"


class SiDrupal(rx.Component):
    library = "react-icons/si"
    tag = "SiDrupal"


class SiDsautomobiles(rx.Component):
    library = "react-icons/si"
    tag = "SiDsautomobiles"


class SiDtube(rx.Component):
    library = "react-icons/si"
    tag = "SiDtube"


class SiDucati(rx.Component):
    library = "react-icons/si"
    tag = "SiDucati"


class SiDuckdb(rx.Component):
    library = "react-icons/si"
    tag = "SiDuckdb"


class SiDuckduckgo(rx.Component):
    library = "react-icons/si"
    tag = "SiDuckduckgo"


class SiDungeonsanddragons(rx.Component):
    library = "react-icons/si"
    tag = "SiDungeonsanddragons"


class SiDunked(rx.Component):
    library = "react-icons/si"
    tag = "SiDunked"


class SiDuolingo(rx.Component):
    library = "react-icons/si"
    tag = "SiDuolingo"


class SiDvc(rx.Component):
    library = "react-icons/si"
    tag = "SiDvc"


class SiDwavesystems(rx.Component):
    library = "react-icons/si"
    tag = "SiDwavesystems"


class SiDwm(rx.Component):
    library = "react-icons/si"
    tag = "SiDwm"


class SiDynamics365(rx.Component):
    library = "react-icons/si"
    tag = "SiDynamics365"


class SiDynatrace(rx.Component):
    library = "react-icons/si"
    tag = "SiDynatrace"


class SiE(rx.Component):
    library = "react-icons/si"
    tag = "SiE"


class SiE3(rx.Component):
    library = "react-icons/si"
    tag = "SiE3"


class SiEa(rx.Component):
    library = "react-icons/si"
    tag = "SiEa"


class SiEagle(rx.Component):
    library = "react-icons/si"
    tag = "SiEagle"


class SiEasyjet(rx.Component):
    library = "react-icons/si"
    tag = "SiEasyjet"


class SiEbay(rx.Component):
    library = "react-icons/si"
    tag = "SiEbay"


class SiEbox(rx.Component):
    library = "react-icons/si"
    tag = "SiEbox"


class SiEclipseche(rx.Component):
    library = "react-icons/si"
    tag = "SiEclipseche"


class SiEclipseide(rx.Component):
    library = "react-icons/si"
    tag = "SiEclipseide"


class SiEclipsejetty(rx.Component):
    library = "react-icons/si"
    tag = "SiEclipsejetty"


class SiEclipsemosquitto(rx.Component):
    library = "react-icons/si"
    tag = "SiEclipsemosquitto"


class SiEclipsevertdotx(rx.Component):
    library = "react-icons/si"
    tag = "SiEclipsevertdotx"


class SiEdeka(rx.Component):
    library = "react-icons/si"
    tag = "SiEdeka"


class SiEditorconfig(rx.Component):
    library = "react-icons/si"
    tag = "SiEditorconfig"


class SiEdotleclerc(rx.Component):
    library = "react-icons/si"
    tag = "SiEdotleclerc"


class SiEdx(rx.Component):
    library = "react-icons/si"
    tag = "SiEdx"


class SiEgghead(rx.Component):
    library = "react-icons/si"
    tag = "SiEgghead"


class SiEgnyte(rx.Component):
    library = "react-icons/si"
    tag = "SiEgnyte"


class SiEightsleep(rx.Component):
    library = "react-icons/si"
    tag = "SiEightsleep"


class SiElastic(rx.Component):
    library = "react-icons/si"
    tag = "SiElastic"


class SiElasticcloud(rx.Component):
    library = "react-icons/si"
    tag = "SiElasticcloud"


class SiElasticsearch(rx.Component):
    library = "react-icons/si"
    tag = "SiElasticsearch"


class SiElasticstack(rx.Component):
    library = "react-icons/si"
    tag = "SiElasticstack"


class SiElectron(rx.Component):
    library = "react-icons/si"
    tag = "SiElectron"


class SiElectronbuilder(rx.Component):
    library = "react-icons/si"
    tag = "SiElectronbuilder"


class SiElectronfiddle(rx.Component):
    library = "react-icons/si"
    tag = "SiElectronfiddle"


class SiElement(rx.Component):
    library = "react-icons/si"
    tag = "SiElement"


class SiElementary(rx.Component):
    library = "react-icons/si"
    tag = "SiElementary"


class SiElementor(rx.Component):
    library = "react-icons/si"
    tag = "SiElementor"


class SiEleventy(rx.Component):
    library = "react-icons/si"
    tag = "SiEleventy"


class SiElgato(rx.Component):
    library = "react-icons/si"
    tag = "SiElgato"


class SiElixir(rx.Component):
    library = "react-icons/si"
    tag = "SiElixir"


class SiEljueves(rx.Component):
    library = "react-icons/si"
    tag = "SiEljueves"


class SiEllo(rx.Component):
    library = "react-icons/si"
    tag = "SiEllo"


class SiElm(rx.Component):
    library = "react-icons/si"
    tag = "SiElm"


class SiElsevier(rx.Component):
    library = "react-icons/si"
    tag = "SiElsevier"


class SiEmbarcadero(rx.Component):
    library = "react-icons/si"
    tag = "SiEmbarcadero"


class SiEmberdotjs(rx.Component):
    library = "react-icons/si"
    tag = "SiEmberdotjs"


class SiEmby(rx.Component):
    library = "react-icons/si"
    tag = "SiEmby"


class SiEmirates(rx.Component):
    library = "react-icons/si"
    tag = "SiEmirates"


class SiEmlakjet(rx.Component):
    library = "react-icons/si"
    tag = "SiEmlakjet"


class SiEmpirekred(rx.Component):
    library = "react-icons/si"
    tag = "SiEmpirekred"


class SiEngadget(rx.Component):
    library = "react-icons/si"
    tag = "SiEngadget"


class SiEnpass(rx.Component):
    library = "react-icons/si"
    tag = "SiEnpass"


class SiEnterprisedb(rx.Component):
    library = "react-icons/si"
    tag = "SiEnterprisedb"


class SiEnvato(rx.Component):
    library = "react-icons/si"
    tag = "SiEnvato"


class SiEnvoyproxy(rx.Component):
    library = "react-icons/si"
    tag = "SiEnvoyproxy"


class SiEpel(rx.Component):
    library = "react-icons/si"
    tag = "SiEpel"


class SiEpicgames(rx.Component):
    library = "react-icons/si"
    tag = "SiEpicgames"


class SiEpson(rx.Component):
    library = "react-icons/si"
    tag = "SiEpson"


class SiEquinixmetal(rx.Component):
    library = "react-icons/si"
    tag = "SiEquinixmetal"


class SiErlang(rx.Component):
    library = "react-icons/si"
    tag = "SiErlang"


class SiEsbuild(rx.Component):
    library = "react-icons/si"
    tag = "SiEsbuild"


class SiEsea(rx.Component):
    library = "react-icons/si"
    tag = "SiEsea"


class SiEslgaming(rx.Component):
    library = "react-icons/si"
    tag = "SiEslgaming"


class SiEslint(rx.Component):
    library = "react-icons/si"
    tag = "SiEslint"


class SiEsphome(rx.Component):
    library = "react-icons/si"
    tag = "SiEsphome"


class SiEspressif(rx.Component):
    library = "react-icons/si"
    tag = "SiEspressif"


class SiEsri(rx.Component):
    library = "react-icons/si"
    tag = "SiEsri"


class SiEtcd(rx.Component):
    library = "react-icons/si"
    tag = "SiEtcd"


class SiEthereum(rx.Component):
    library = "react-icons/si"
    tag = "SiEthereum"


class SiEthiopianairlines(rx.Component):
    library = "react-icons/si"
    tag = "SiEthiopianairlines"


class SiEtihadairways(rx.Component):
    library = "react-icons/si"
    tag = "SiEtihadairways"


class SiEtsy(rx.Component):
    library = "react-icons/si"
    tag = "SiEtsy"


class SiEventbrite(rx.Component):
    library = "react-icons/si"
    tag = "SiEventbrite"


class SiEventstore(rx.Component):
    library = "react-icons/si"
    tag = "SiEventstore"


class SiEvernote(rx.Component):
    library = "react-icons/si"
    tag = "SiEvernote"


class SiExercism(rx.Component):
    library = "react-icons/si"
    tag = "SiExercism"


class SiExordo(rx.Component):
    library = "react-icons/si"
    tag = "SiExordo"


class SiExoscale(rx.Component):
    library = "react-icons/si"
    tag = "SiExoscale"


class SiExpensify(rx.Component):
    library = "react-icons/si"
    tag = "SiExpensify"


class SiExpertsexchange(rx.Component):
    library = "react-icons/si"
    tag = "SiExpertsexchange"


class SiExpo(rx.Component):
    library = "react-icons/si"
    tag = "SiExpo"


class SiExpress(rx.Component):
    library = "react-icons/si"
    tag = "SiExpress"


class SiExpressvpn(rx.Component):
    library = "react-icons/si"
    tag = "SiExpressvpn"


class SiEyeem(rx.Component):
    library = "react-icons/si"
    tag = "SiEyeem"


class SiF1(rx.Component):
    library = "react-icons/si"
    tag = "SiF1"


class SiF5(rx.Component):
    library = "react-icons/si"
    tag = "SiF5"


class SiFacebook(rx.Component):
    library = "react-icons/si"
    tag = "SiFacebook"


class SiFacebookgaming(rx.Component):
    library = "react-icons/si"
    tag = "SiFacebookgaming"


class SiFacebooklive(rx.Component):
    library = "react-icons/si"
    tag = "SiFacebooklive"


class SiFaceit(rx.Component):
    library = "react-icons/si"
    tag = "SiFaceit"


class SiFacepunch(rx.Component):
    library = "react-icons/si"
    tag = "SiFacepunch"


class SiFalcon(rx.Component):
    library = "react-icons/si"
    tag = "SiFalcon"


class SiFampay(rx.Component):
    library = "react-icons/si"
    tag = "SiFampay"


class SiFandango(rx.Component):
    library = "react-icons/si"
    tag = "SiFandango"


class SiFandom(rx.Component):
    library = "react-icons/si"
    tag = "SiFandom"


class SiFanfou(rx.Component):
    library = "react-icons/si"
    tag = "SiFanfou"


class SiFantom(rx.Component):
    library = "react-icons/si"
    tag = "SiFantom"


class SiFarfetch(rx.Component):
    library = "react-icons/si"
    tag = "SiFarfetch"


class SiFastapi(rx.Component):
    library = "react-icons/si"
    tag = "SiFastapi"


class SiFastify(rx.Component):
    library = "react-icons/si"
    tag = "SiFastify"


class SiFastlane(rx.Component):
    library = "react-icons/si"
    tag = "SiFastlane"


class SiFastly(rx.Component):
    library = "react-icons/si"
    tag = "SiFastly"


class SiFathom(rx.Component):
    library = "react-icons/si"
    tag = "SiFathom"


class SiFauna(rx.Component):
    library = "react-icons/si"
    tag = "SiFauna"


class SiFavro(rx.Component):
    library = "react-icons/si"
    tag = "SiFavro"


class SiFdroid(rx.Component):
    library = "react-icons/si"
    tag = "SiFdroid"


class SiFeathub(rx.Component):
    library = "react-icons/si"
    tag = "SiFeathub"


class SiFedex(rx.Component):
    library = "react-icons/si"
    tag = "SiFedex"


class SiFedora(rx.Component):
    library = "react-icons/si"
    tag = "SiFedora"


class SiFeedly(rx.Component):
    library = "react-icons/si"
    tag = "SiFeedly"


class SiFerrari(rx.Component):
    library = "react-icons/si"
    tag = "SiFerrari"


class SiFerrarinv(rx.Component):
    library = "react-icons/si"
    tag = "SiFerrarinv"


class SiFfmpeg(rx.Component):
    library = "react-icons/si"
    tag = "SiFfmpeg"


class SiFiat(rx.Component):
    library = "react-icons/si"
    tag = "SiFiat"


class SiFidoalliance(rx.Component):
    library = "react-icons/si"
    tag = "SiFidoalliance"


class SiFifa(rx.Component):
    library = "react-icons/si"
    tag = "SiFifa"


class SiFig(rx.Component):
    library = "react-icons/si"
    tag = "SiFig"


class SiFigma(rx.Component):
    library = "react-icons/si"
    tag = "SiFigma"


class SiFigshare(rx.Component):
    library = "react-icons/si"
    tag = "SiFigshare"


class SiFila(rx.Component):
    library = "react-icons/si"
    tag = "SiFila"


class SiFiles(rx.Component):
    library = "react-icons/si"
    tag = "SiFiles"


class SiFilezilla(rx.Component):
    library = "react-icons/si"
    tag = "SiFilezilla"


class SiFing(rx.Component):
    library = "react-icons/si"
    tag = "SiFing"


class SiFirebase(rx.Component):
    library = "react-icons/si"
    tag = "SiFirebase"


class SiFirefox(rx.Component):
    library = "react-icons/si"
    tag = "SiFirefox"


class SiFirefoxbrowser(rx.Component):
    library = "react-icons/si"
    tag = "SiFirefoxbrowser"


class SiFireship(rx.Component):
    library = "react-icons/si"
    tag = "SiFireship"


class SiFirewalla(rx.Component):
    library = "react-icons/si"
    tag = "SiFirewalla"


class SiFirst(rx.Component):
    library = "react-icons/si"
    tag = "SiFirst"


class SiFitbit(rx.Component):
    library = "react-icons/si"
    tag = "SiFitbit"


class SiFite(rx.Component):
    library = "react-icons/si"
    tag = "SiFite"


class SiFivem(rx.Component):
    library = "react-icons/si"
    tag = "SiFivem"


class SiFiverr(rx.Component):
    library = "react-icons/si"
    tag = "SiFiverr"


class SiFlask(rx.Component):
    library = "react-icons/si"
    tag = "SiFlask"


class SiFlat(rx.Component):
    library = "react-icons/si"
    tag = "SiFlat"


class SiFlathub(rx.Component):
    library = "react-icons/si"
    tag = "SiFlathub"


class SiFlatpak(rx.Component):
    library = "react-icons/si"
    tag = "SiFlatpak"


class SiFlattr(rx.Component):
    library = "react-icons/si"
    tag = "SiFlattr"


class SiFlickr(rx.Component):
    library = "react-icons/si"
    tag = "SiFlickr"


class SiFlipboard(rx.Component):
    library = "react-icons/si"
    tag = "SiFlipboard"


class SiFlipkart(rx.Component):
    library = "react-icons/si"
    tag = "SiFlipkart"


class SiFloatplane(rx.Component):
    library = "react-icons/si"
    tag = "SiFloatplane"


class SiFlood(rx.Component):
    library = "react-icons/si"
    tag = "SiFlood"


class SiFluentbit(rx.Component):
    library = "react-icons/si"
    tag = "SiFluentbit"


class SiFluentd(rx.Component):
    library = "react-icons/si"
    tag = "SiFluentd"


class SiFlutter(rx.Component):
    library = "react-icons/si"
    tag = "SiFlutter"


class SiFluxus(rx.Component):
    library = "react-icons/si"
    tag = "SiFluxus"


class SiFlyway(rx.Component):
    library = "react-icons/si"
    tag = "SiFlyway"


class SiFmod(rx.Component):
    library = "react-icons/si"
    tag = "SiFmod"


class SiFnac(rx.Component):
    library = "react-icons/si"
    tag = "SiFnac"


class SiFolium(rx.Component):
    library = "react-icons/si"
    tag = "SiFolium"


class SiFonoma(rx.Component):
    library = "react-icons/si"
    tag = "SiFonoma"


class SiFontawesome(rx.Component):
    library = "react-icons/si"
    tag = "SiFontawesome"


class SiFontbase(rx.Component):
    library = "react-icons/si"
    tag = "SiFontbase"


class SiFontforge(rx.Component):
    library = "react-icons/si"
    tag = "SiFontforge"


class SiFoodpanda(rx.Component):
    library = "react-icons/si"
    tag = "SiFoodpanda"


class SiFord(rx.Component):
    library = "react-icons/si"
    tag = "SiFord"


class SiForestry(rx.Component):
    library = "react-icons/si"
    tag = "SiForestry"


class SiFormstack(rx.Component):
    library = "react-icons/si"
    tag = "SiFormstack"


class SiFortinet(rx.Component):
    library = "react-icons/si"
    tag = "SiFortinet"


class SiFortran(rx.Component):
    library = "react-icons/si"
    tag = "SiFortran"


class SiFossa(rx.Component):
    library = "react-icons/si"
    tag = "SiFossa"


class SiFossilscm(rx.Component):
    library = "react-icons/si"
    tag = "SiFossilscm"


class SiFoursquare(rx.Component):
    library = "react-icons/si"
    tag = "SiFoursquare"


class SiFoursquarecityguide(rx.Component):
    library = "react-icons/si"
    tag = "SiFoursquarecityguide"


class SiFox(rx.Component):
    library = "react-icons/si"
    tag = "SiFox"


class SiFoxtel(rx.Component):
    library = "react-icons/si"
    tag = "SiFoxtel"


class SiFozzy(rx.Component):
    library = "react-icons/si"
    tag = "SiFozzy"


class SiFramer(rx.Component):
    library = "react-icons/si"
    tag = "SiFramer"


class SiFramework7(rx.Component):
    library = "react-icons/si"
    tag = "SiFramework7"


class SiFranprix(rx.Component):
    library = "react-icons/si"
    tag = "SiFranprix"


class SiFraunhofergesellschaft(rx.Component):
    library = "react-icons/si"
    tag = "SiFraunhofergesellschaft"


class SiFreebsd(rx.Component):
    library = "react-icons/si"
    tag = "SiFreebsd"


class SiFreecodecamp(rx.Component):
    library = "react-icons/si"
    tag = "SiFreecodecamp"


class SiFreedesktopdotorg(rx.Component):
    library = "react-icons/si"
    tag = "SiFreedesktopdotorg"


class SiFreelancer(rx.Component):
    library = "react-icons/si"
    tag = "SiFreelancer"


class SiFreenas(rx.Component):
    library = "react-icons/si"
    tag = "SiFreenas"


class SiFrontendmentor(rx.Component):
    library = "react-icons/si"
    tag = "SiFrontendmentor"


class SiFrontify(rx.Component):
    library = "react-icons/si"
    tag = "SiFrontify"


class SiFsecure(rx.Component):
    library = "react-icons/si"
    tag = "SiFsecure"


class SiFugacloud(rx.Component):
    library = "react-icons/si"
    tag = "SiFugacloud"


class SiFujifilm(rx.Component):
    library = "react-icons/si"
    tag = "SiFujifilm"


class SiFujitsu(rx.Component):
    library = "react-icons/si"
    tag = "SiFujitsu"


class SiFunimation(rx.Component):
    library = "react-icons/si"
    tag = "SiFunimation"


class SiFuraffinity(rx.Component):
    library = "react-icons/si"
    tag = "SiFuraffinity"


class SiFurrynetwork(rx.Component):
    library = "react-icons/si"
    tag = "SiFurrynetwork"


class SiFuturelearn(rx.Component):
    library = "react-icons/si"
    tag = "SiFuturelearn"


class SiG2(rx.Component):
    library = "react-icons/si"
    tag = "SiG2"


class SiG2A(rx.Component):
    library = "react-icons/si"
    tag = "SiG2A"


class SiGameandwatch(rx.Component):
    library = "react-icons/si"
    tag = "SiGameandwatch"


class SiGamedeveloper(rx.Component):
    library = "react-icons/si"
    tag = "SiGamedeveloper"


class SiGamejolt(rx.Component):
    library = "react-icons/si"
    tag = "SiGamejolt"


class SiGarmin(rx.Component):
    library = "react-icons/si"
    tag = "SiGarmin"


class SiGatling(rx.Component):
    library = "react-icons/si"
    tag = "SiGatling"


class SiGatsby(rx.Component):
    library = "react-icons/si"
    tag = "SiGatsby"


class SiGeant(rx.Component):
    library = "react-icons/si"
    tag = "SiGeant"


class SiGeeksforgeeks(rx.Component):
    library = "react-icons/si"
    tag = "SiGeeksforgeeks"


class SiGeneralelectric(rx.Component):
    library = "react-icons/si"
    tag = "SiGeneralelectric"


class SiGeneralmotors(rx.Component):
    library = "react-icons/si"
    tag = "SiGeneralmotors"


class SiGenius(rx.Component):
    library = "react-icons/si"
    tag = "SiGenius"


class SiGentoo(rx.Component):
    library = "react-icons/si"
    tag = "SiGentoo"


class SiGeocaching(rx.Component):
    library = "react-icons/si"
    tag = "SiGeocaching"


class SiGerrit(rx.Component):
    library = "react-icons/si"
    tag = "SiGerrit"


class SiGhost(rx.Component):
    library = "react-icons/si"
    tag = "SiGhost"


class SiGhostery(rx.Component):
    library = "react-icons/si"
    tag = "SiGhostery"


class SiGimp(rx.Component):
    library = "react-icons/si"
    tag = "SiGimp"


class SiGiphy(rx.Component):
    library = "react-icons/si"
    tag = "SiGiphy"


class SiGit(rx.Component):
    library = "react-icons/si"
    tag = "SiGit"


class SiGitbook(rx.Component):
    library = "react-icons/si"
    tag = "SiGitbook"


class SiGitea(rx.Component):
    library = "react-icons/si"
    tag = "SiGitea"


class SiGitee(rx.Component):
    library = "react-icons/si"
    tag = "SiGitee"


class SiGitextensions(rx.Component):
    library = "react-icons/si"
    tag = "SiGitextensions"


class SiGithub(rx.Component):
    library = "react-icons/si"
    tag = "SiGithub"


class SiGithubactions(rx.Component):
    library = "react-icons/si"
    tag = "SiGithubactions"


class SiGithubpages(rx.Component):
    library = "react-icons/si"
    tag = "SiGithubpages"


class SiGithubsponsors(rx.Component):
    library = "react-icons/si"
    tag = "SiGithubsponsors"


class SiGitignoredotio(rx.Component):
    library = "react-icons/si"
    tag = "SiGitignoredotio"


class SiGitkraken(rx.Component):
    library = "react-icons/si"
    tag = "SiGitkraken"


class SiGitlab(rx.Component):
    library = "react-icons/si"
    tag = "SiGitlab"


class SiGitlfs(rx.Component):
    library = "react-icons/si"
    tag = "SiGitlfs"


class SiGitpod(rx.Component):
    library = "react-icons/si"
    tag = "SiGitpod"


class SiGitter(rx.Component):
    library = "react-icons/si"
    tag = "SiGitter"


class SiGlassdoor(rx.Component):
    library = "react-icons/si"
    tag = "SiGlassdoor"


class SiGlitch(rx.Component):
    library = "react-icons/si"
    tag = "SiGlitch"


class SiGlobus(rx.Component):
    library = "react-icons/si"
    tag = "SiGlobus"


class SiGmail(rx.Component):
    library = "react-icons/si"
    tag = "SiGmail"


class SiGnome(rx.Component):
    library = "react-icons/si"
    tag = "SiGnome"


class SiGnometerminal(rx.Component):
    library = "react-icons/si"
    tag = "SiGnometerminal"


class SiGnu(rx.Component):
    library = "react-icons/si"
    tag = "SiGnu"


class SiGnubash(rx.Component):
    library = "react-icons/si"
    tag = "SiGnubash"


class SiGnuemacs(rx.Component):
    library = "react-icons/si"
    tag = "SiGnuemacs"


class SiGnuicecat(rx.Component):
    library = "react-icons/si"
    tag = "SiGnuicecat"


class SiGnuprivacyguard(rx.Component):
    library = "react-icons/si"
    tag = "SiGnuprivacyguard"


class SiGnusocial(rx.Component):
    library = "react-icons/si"
    tag = "SiGnusocial"


class SiGo(rx.Component):
    library = "react-icons/si"
    tag = "SiGo"


class SiGocd(rx.Component):
    library = "react-icons/si"
    tag = "SiGocd"


class SiGodaddy(rx.Component):
    library = "react-icons/si"
    tag = "SiGodaddy"


class SiGodotengine(rx.Component):
    library = "react-icons/si"
    tag = "SiGodotengine"


class SiGofundme(rx.Component):
    library = "react-icons/si"
    tag = "SiGofundme"


class SiGogdotcom(rx.Component):
    library = "react-icons/si"
    tag = "SiGogdotcom"


class SiGoland(rx.Component):
    library = "react-icons/si"
    tag = "SiGoland"


class SiGoldenline(rx.Component):
    library = "react-icons/si"
    tag = "SiGoldenline"


class SiGoodreads(rx.Component):
    library = "react-icons/si"
    tag = "SiGoodreads"


class SiGoogle(rx.Component):
    library = "react-icons/si"
    tag = "SiGoogle"


class SiGoogleadmob(rx.Component):
    library = "react-icons/si"
    tag = "SiGoogleadmob"


class SiGoogleads(rx.Component):
    library = "react-icons/si"
    tag = "SiGoogleads"


class SiGoogleadsense(rx.Component):
    library = "react-icons/si"
    tag = "SiGoogleadsense"


class SiGoogleanalytics(rx.Component):
    library = "react-icons/si"
    tag = "SiGoogleanalytics"


class SiGoogleassistant(rx.Component):
    library = "react-icons/si"
    tag = "SiGoogleassistant"


class SiGooglecalendar(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglecalendar"


class SiGooglecardboard(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglecardboard"


class SiGooglechat(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglechat"


class SiGooglechrome(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglechrome"


class SiGoogleclassroom(rx.Component):
    library = "react-icons/si"
    tag = "SiGoogleclassroom"


class SiGooglecloud(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglecloud"


class SiGooglecolab(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglecolab"


class SiGoogledomains(rx.Component):
    library = "react-icons/si"
    tag = "SiGoogledomains"


class SiGoogledrive(rx.Component):
    library = "react-icons/si"
    tag = "SiGoogledrive"


class SiGoogleearth(rx.Component):
    library = "react-icons/si"
    tag = "SiGoogleearth"


class SiGooglefit(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglefit"


class SiGooglefonts(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglefonts"


class SiGooglehangouts(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglehangouts"


class SiGooglehome(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglehome"


class SiGooglekeep(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglekeep"


class SiGooglelens(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglelens"


class SiGooglemaps(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglemaps"


class SiGooglemarketingplatform(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglemarketingplatform"


class SiGooglemeet(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglemeet"


class SiGooglemessages(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglemessages"


class SiGooglemybusiness(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglemybusiness"


class SiGooglenearby(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglenearby"


class SiGooglenews(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglenews"


class SiGoogleoptimize(rx.Component):
    library = "react-icons/si"
    tag = "SiGoogleoptimize"


class SiGooglepay(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglepay"


class SiGooglephotos(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglephotos"


class SiGoogleplay(rx.Component):
    library = "react-icons/si"
    tag = "SiGoogleplay"


class SiGooglepodcasts(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglepodcasts"


class SiGooglescholar(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglescholar"


class SiGooglesearchconsole(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglesearchconsole"


class SiGooglesheets(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglesheets"


class SiGooglestreetview(rx.Component):
    library = "react-icons/si"
    tag = "SiGooglestreetview"


class SiGoogletagmanager(rx.Component):
    library = "react-icons/si"
    tag = "SiGoogletagmanager"


class SiGoogletranslate(rx.Component):
    library = "react-icons/si"
    tag = "SiGoogletranslate"


class SiGotomeeting(rx.Component):
    library = "react-icons/si"
    tag = "SiGotomeeting"


class SiGrab(rx.Component):
    library = "react-icons/si"
    tag = "SiGrab"


class SiGradle(rx.Component):
    library = "react-icons/si"
    tag = "SiGradle"


class SiGrafana(rx.Component):
    library = "react-icons/si"
    tag = "SiGrafana"


class SiGrammarly(rx.Component):
    library = "react-icons/si"
    tag = "SiGrammarly"


class SiGrandfrais(rx.Component):
    library = "react-icons/si"
    tag = "SiGrandfrais"


class SiGraphql(rx.Component):
    library = "react-icons/si"
    tag = "SiGraphql"


class SiGrav(rx.Component):
    library = "react-icons/si"
    tag = "SiGrav"


class SiGravatar(rx.Component):
    library = "react-icons/si"
    tag = "SiGravatar"


class SiGraylog(rx.Component):
    library = "react-icons/si"
    tag = "SiGraylog"


class SiGreenhouse(rx.Component):
    library = "react-icons/si"
    tag = "SiGreenhouse"


class SiGreensock(rx.Component):
    library = "react-icons/si"
    tag = "SiGreensock"


class SiGriddotai(rx.Component):
    library = "react-icons/si"
    tag = "SiGriddotai"


class SiGridsome(rx.Component):
    library = "react-icons/si"
    tag = "SiGridsome"


class SiGroupme(rx.Component):
    library = "react-icons/si"
    tag = "SiGroupme"


class SiGroupon(rx.Component):
    library = "react-icons/si"
    tag = "SiGroupon"


class SiGrubhub(rx.Component):
    library = "react-icons/si"
    tag = "SiGrubhub"


class SiGrunt(rx.Component):
    library = "react-icons/si"
    tag = "SiGrunt"


class SiGsk(rx.Component):
    library = "react-icons/si"
    tag = "SiGsk"


class SiGtk(rx.Component):
    library = "react-icons/si"
    tag = "SiGtk"


class SiGuangzhoumetro(rx.Component):
    library = "react-icons/si"
    tag = "SiGuangzhoumetro"


class SiGuilded(rx.Component):
    library = "react-icons/si"
    tag = "SiGuilded"


class SiGulp(rx.Component):
    library = "react-icons/si"
    tag = "SiGulp"


class SiGumroad(rx.Component):
    library = "react-icons/si"
    tag = "SiGumroad"


class SiGumtree(rx.Component):
    library = "react-icons/si"
    tag = "SiGumtree"


class SiGunicorn(rx.Component):
    library = "react-icons/si"
    tag = "SiGunicorn"


class SiGurobi(rx.Component):
    library = "react-icons/si"
    tag = "SiGurobi"


class SiGutenberg(rx.Component):
    library = "react-icons/si"
    tag = "SiGutenberg"


class SiHabr(rx.Component):
    library = "react-icons/si"
    tag = "SiHabr"


class SiHackaday(rx.Component):
    library = "react-icons/si"
    tag = "SiHackaday"


class SiHackclub(rx.Component):
    library = "react-icons/si"
    tag = "SiHackclub"


class SiHackerearth(rx.Component):
    library = "react-icons/si"
    tag = "SiHackerearth"


class SiHackernoon(rx.Component):
    library = "react-icons/si"
    tag = "SiHackernoon"


class SiHackerone(rx.Component):
    library = "react-icons/si"
    tag = "SiHackerone"


class SiHackerrank(rx.Component):
    library = "react-icons/si"
    tag = "SiHackerrank"


class SiHackster(rx.Component):
    library = "react-icons/si"
    tag = "SiHackster"


class SiHackthebox(rx.Component):
    library = "react-icons/si"
    tag = "SiHackthebox"


class SiHandlebarsdotjs(rx.Component):
    library = "react-icons/si"
    tag = "SiHandlebarsdotjs"


class SiHandshakeProtocol(rx.Component):
    library = "react-icons/si"
    tag = "SiHandshakeProtocol"


class SiHandshake(rx.Component):
    library = "react-icons/si"
    tag = "SiHandshake"


class SiHappycow(rx.Component):
    library = "react-icons/si"
    tag = "SiHappycow"


class SiHarbor(rx.Component):
    library = "react-icons/si"
    tag = "SiHarbor"


class SiHarmonyos(rx.Component):
    library = "react-icons/si"
    tag = "SiHarmonyos"


class SiHashnode(rx.Component):
    library = "react-icons/si"
    tag = "SiHashnode"


class SiHaskell(rx.Component):
    library = "react-icons/si"
    tag = "SiHaskell"


class SiHasura(rx.Component):
    library = "react-icons/si"
    tag = "SiHasura"


class SiHatenabookmark(rx.Component):
    library = "react-icons/si"
    tag = "SiHatenabookmark"


class SiHaveibeenpwned(rx.Component):
    library = "react-icons/si"
    tag = "SiHaveibeenpwned"


class SiHaxe(rx.Component):
    library = "react-icons/si"
    tag = "SiHaxe"


class SiHbo(rx.Component):
    library = "react-icons/si"
    tag = "SiHbo"


class SiHcl(rx.Component):
    library = "react-icons/si"
    tag = "SiHcl"


class SiHeadlessui(rx.Component):
    library = "react-icons/si"
    tag = "SiHeadlessui"


class SiHeadspace(rx.Component):
    library = "react-icons/si"
    tag = "SiHeadspace"


class SiHedera(rx.Component):
    library = "react-icons/si"
    tag = "SiHedera"


class SiHellofresh(rx.Component):
    library = "react-icons/si"
    tag = "SiHellofresh"


class SiHellyhansen(rx.Component):
    library = "react-icons/si"
    tag = "SiHellyhansen"


class SiHelm(rx.Component):
    library = "react-icons/si"
    tag = "SiHelm"


class SiHelpdesk(rx.Component):
    library = "react-icons/si"
    tag = "SiHelpdesk"


class SiHelpscout(rx.Component):
    library = "react-icons/si"
    tag = "SiHelpscout"


class SiHere(rx.Component):
    library = "react-icons/si"
    tag = "SiHere"


class SiHeroku(rx.Component):
    library = "react-icons/si"
    tag = "SiHeroku"


class SiHetzner(rx.Component):
    library = "react-icons/si"
    tag = "SiHetzner"


class SiHexo(rx.Component):
    library = "react-icons/si"
    tag = "SiHexo"


class SiHey(rx.Component):
    library = "react-icons/si"
    tag = "SiHey"


class SiHibernate(rx.Component):
    library = "react-icons/si"
    tag = "SiHibernate"


class SiHibob(rx.Component):
    library = "react-icons/si"
    tag = "SiHibob"


class SiHilton(rx.Component):
    library = "react-icons/si"
    tag = "SiHilton"


class SiHitachi(rx.Component):
    library = "react-icons/si"
    tag = "SiHitachi"


class SiHiveBlockchain(rx.Component):
    library = "react-icons/si"
    tag = "SiHiveBlockchain"


class SiHive(rx.Component):
    library = "react-icons/si"
    tag = "SiHive"


class SiHomeadvisor(rx.Component):
    library = "react-icons/si"
    tag = "SiHomeadvisor"


class SiHomeassistant(rx.Component):
    library = "react-icons/si"
    tag = "SiHomeassistant"


class SiHomeassistantcommunitystore(rx.Component):
    library = "react-icons/si"
    tag = "SiHomeassistantcommunitystore"


class SiHomebrew(rx.Component):
    library = "react-icons/si"
    tag = "SiHomebrew"


class SiHomebridge(rx.Component):
    library = "react-icons/si"
    tag = "SiHomebridge"


class SiHomify(rx.Component):
    library = "react-icons/si"
    tag = "SiHomify"


class SiHonda(rx.Component):
    library = "react-icons/si"
    tag = "SiHonda"


class SiHoney(rx.Component):
    library = "react-icons/si"
    tag = "SiHoney"


class SiHootsuite(rx.Component):
    library = "react-icons/si"
    tag = "SiHootsuite"


class SiHoppscotch(rx.Component):
    library = "react-icons/si"
    tag = "SiHoppscotch"


class SiHotelsdotcom(rx.Component):
    library = "react-icons/si"
    tag = "SiHotelsdotcom"


class SiHotjar(rx.Component):
    library = "react-icons/si"
    tag = "SiHotjar"


class SiHoudini(rx.Component):
    library = "react-icons/si"
    tag = "SiHoudini"


class SiHouzz(rx.Component):
    library = "react-icons/si"
    tag = "SiHouzz"


class SiHp(rx.Component):
    library = "react-icons/si"
    tag = "SiHp"


class SiHtml5(rx.Component):
    library = "react-icons/si"
    tag = "SiHtml5"


class SiHtmlacademy(rx.Component):
    library = "react-icons/si"
    tag = "SiHtmlacademy"


class SiHttpie(rx.Component):
    library = "react-icons/si"
    tag = "SiHttpie"


class SiHuawei(rx.Component):
    library = "react-icons/si"
    tag = "SiHuawei"


class SiHubspot(rx.Component):
    library = "react-icons/si"
    tag = "SiHubspot"


class SiHugo(rx.Component):
    library = "react-icons/si"
    tag = "SiHugo"


class SiHulu(rx.Component):
    library = "react-icons/si"
    tag = "SiHulu"


class SiHumblebundle(rx.Component):
    library = "react-icons/si"
    tag = "SiHumblebundle"


class SiHungryjacks(rx.Component):
    library = "react-icons/si"
    tag = "SiHungryjacks"


class SiHurriyetemlak(rx.Component):
    library = "react-icons/si"
    tag = "SiHurriyetemlak"


class SiHusqvarna(rx.Component):
    library = "react-icons/si"
    tag = "SiHusqvarna"


class SiHyper(rx.Component):
    library = "react-icons/si"
    tag = "SiHyper"


class SiHyperledger(rx.Component):
    library = "react-icons/si"
    tag = "SiHyperledger"


class SiHypothesis(rx.Component):
    library = "react-icons/si"
    tag = "SiHypothesis"


class SiHyundai(rx.Component):
    library = "react-icons/si"
    tag = "SiHyundai"


class SiI18Next(rx.Component):
    library = "react-icons/si"
    tag = "SiI18Next"


class SiIata(rx.Component):
    library = "react-icons/si"
    tag = "SiIata"


class SiIbeacon(rx.Component):
    library = "react-icons/si"
    tag = "SiIbeacon"


class SiIbm(rx.Component):
    library = "react-icons/si"
    tag = "SiIbm"


class SiIbmcloud(rx.Component):
    library = "react-icons/si"
    tag = "SiIbmcloud"


class SiIbmwatson(rx.Component):
    library = "react-icons/si"
    tag = "SiIbmwatson"


class SiIced(rx.Component):
    library = "react-icons/si"
    tag = "SiIced"


class SiIceland(rx.Component):
    library = "react-icons/si"
    tag = "SiIceland"


class SiIcinga(rx.Component):
    library = "react-icons/si"
    tag = "SiIcinga"


class SiIcloud(rx.Component):
    library = "react-icons/si"
    tag = "SiIcloud"


class SiIcomoon(rx.Component):
    library = "react-icons/si"
    tag = "SiIcomoon"


class SiIcon(rx.Component):
    library = "react-icons/si"
    tag = "SiIcon"


class SiIconfinder(rx.Component):
    library = "react-icons/si"
    tag = "SiIconfinder"


class SiIconify(rx.Component):
    library = "react-icons/si"
    tag = "SiIconify"


class SiIconjar(rx.Component):
    library = "react-icons/si"
    tag = "SiIconjar"


class SiIcons8(rx.Component):
    library = "react-icons/si"
    tag = "SiIcons8"


class SiIcq(rx.Component):
    library = "react-icons/si"
    tag = "SiIcq"


class SiIeee(rx.Component):
    library = "react-icons/si"
    tag = "SiIeee"


class SiIfixit(rx.Component):
    library = "react-icons/si"
    tag = "SiIfixit"


class SiIfood(rx.Component):
    library = "react-icons/si"
    tag = "SiIfood"


class SiIfttt(rx.Component):
    library = "react-icons/si"
    tag = "SiIfttt"


class SiIheartradio(rx.Component):
    library = "react-icons/si"
    tag = "SiIheartradio"


class SiIkea(rx.Component):
    library = "react-icons/si"
    tag = "SiIkea"


class SiIledefrancemobilites(rx.Component):
    library = "react-icons/si"
    tag = "SiIledefrancemobilites"


class SiImagej(rx.Component):
    library = "react-icons/si"
    tag = "SiImagej"


class SiImdb(rx.Component):
    library = "react-icons/si"
    tag = "SiImdb"


class SiImgur(rx.Component):
    library = "react-icons/si"
    tag = "SiImgur"


class SiImmer(rx.Component):
    library = "react-icons/si"
    tag = "SiImmer"


class SiImou(rx.Component):
    library = "react-icons/si"
    tag = "SiImou"


class SiIndeed(rx.Component):
    library = "react-icons/si"
    tag = "SiIndeed"


class SiInfiniti(rx.Component):
    library = "react-icons/si"
    tag = "SiInfiniti"


class SiInfluxdb(rx.Component):
    library = "react-icons/si"
    tag = "SiInfluxdb"


class SiInformatica(rx.Component):
    library = "react-icons/si"
    tag = "SiInformatica"


class SiInfosys(rx.Component):
    library = "react-icons/si"
    tag = "SiInfosys"


class SiInfracost(rx.Component):
    library = "react-icons/si"
    tag = "SiInfracost"


class SiIngress(rx.Component):
    library = "react-icons/si"
    tag = "SiIngress"


class SiInkdrop(rx.Component):
    library = "react-icons/si"
    tag = "SiInkdrop"


class SiInkscape(rx.Component):
    library = "react-icons/si"
    tag = "SiInkscape"


class SiInsomnia(rx.Component):
    library = "react-icons/si"
    tag = "SiInsomnia"


class SiInstacart(rx.Component):
    library = "react-icons/si"
    tag = "SiInstacart"


class SiInstagram(rx.Component):
    library = "react-icons/si"
    tag = "SiInstagram"


class SiInstapaper(rx.Component):
    library = "react-icons/si"
    tag = "SiInstapaper"


class SiInstatus(rx.Component):
    library = "react-icons/si"
    tag = "SiInstatus"


class SiInstructables(rx.Component):
    library = "react-icons/si"
    tag = "SiInstructables"


class SiInstructure(rx.Component):
    library = "react-icons/si"
    tag = "SiInstructure"


class SiIntegromat(rx.Component):
    library = "react-icons/si"
    tag = "SiIntegromat"


class SiIntel(rx.Component):
    library = "react-icons/si"
    tag = "SiIntel"


class SiIntellijidea(rx.Component):
    library = "react-icons/si"
    tag = "SiIntellijidea"


class SiInteractiondesignfoundation(rx.Component):
    library = "react-icons/si"
    tag = "SiInteractiondesignfoundation"


class SiInteractjs(rx.Component):
    library = "react-icons/si"
    tag = "SiInteractjs"


class SiIntercom(rx.Component):
    library = "react-icons/si"
    tag = "SiIntercom"


class SiIntermarche(rx.Component):
    library = "react-icons/si"
    tag = "SiIntermarche"


class SiInternetarchive(rx.Component):
    library = "react-icons/si"
    tag = "SiInternetarchive"


class SiInternetexplorer(rx.Component):
    library = "react-icons/si"
    tag = "SiInternetexplorer"


class SiIntigriti(rx.Component):
    library = "react-icons/si"
    tag = "SiIntigriti"


class SiInvision(rx.Component):
    library = "react-icons/si"
    tag = "SiInvision"


class SiInvoiceninja(rx.Component):
    library = "react-icons/si"
    tag = "SiInvoiceninja"


class SiIobroker(rx.Component):
    library = "react-icons/si"
    tag = "SiIobroker"


class SiIonic(rx.Component):
    library = "react-icons/si"
    tag = "SiIonic"


class SiIonos(rx.Component):
    library = "react-icons/si"
    tag = "SiIonos"


class SiIos(rx.Component):
    library = "react-icons/si"
    tag = "SiIos"


class SiIota(rx.Component):
    library = "react-icons/si"
    tag = "SiIota"


class SiIpfs(rx.Component):
    library = "react-icons/si"
    tag = "SiIpfs"


class SiIssuu(rx.Component):
    library = "react-icons/si"
    tag = "SiIssuu"


class SiIstio(rx.Component):
    library = "react-icons/si"
    tag = "SiIstio"


class SiItchdotio(rx.Component):
    library = "react-icons/si"
    tag = "SiItchdotio"


class SiIterm2(rx.Component):
    library = "react-icons/si"
    tag = "SiIterm2"


class SiItunes(rx.Component):
    library = "react-icons/si"
    tag = "SiItunes"


class SiItvx(rx.Component):
    library = "react-icons/si"
    tag = "SiItvx"


class SiIveco(rx.Component):
    library = "react-icons/si"
    tag = "SiIveco"


class SiJabber(rx.Component):
    library = "react-icons/si"
    tag = "SiJabber"


class SiJaguar(rx.Component):
    library = "react-icons/si"
    tag = "SiJaguar"


class SiJamboard(rx.Component):
    library = "react-icons/si"
    tag = "SiJamboard"


class SiJameson(rx.Component):
    library = "react-icons/si"
    tag = "SiJameson"


class SiJamstack(rx.Component):
    library = "react-icons/si"
    tag = "SiJamstack"


class SiJasmine(rx.Component):
    library = "react-icons/si"
    tag = "SiJasmine"


class SiJavascript(rx.Component):
    library = "react-icons/si"
    tag = "SiJavascript"


class SiJbl(rx.Component):
    library = "react-icons/si"
    tag = "SiJbl"


class SiJcb(rx.Component):
    library = "react-icons/si"
    tag = "SiJcb"


class SiJeep(rx.Component):
    library = "react-icons/si"
    tag = "SiJeep"


class SiJekyll(rx.Component):
    library = "react-icons/si"
    tag = "SiJekyll"


class SiJellyfin(rx.Component):
    library = "react-icons/si"
    tag = "SiJellyfin"


class SiJenkins(rx.Component):
    library = "react-icons/si"
    tag = "SiJenkins"


class SiJenkinsx(rx.Component):
    library = "react-icons/si"
    tag = "SiJenkinsx"


class SiJest(rx.Component):
    library = "react-icons/si"
    tag = "SiJest"


class SiJet(rx.Component):
    library = "react-icons/si"
    tag = "SiJet"


class SiJetbrains(rx.Component):
    library = "react-icons/si"
    tag = "SiJetbrains"


class SiJetpackcompose(rx.Component):
    library = "react-icons/si"
    tag = "SiJetpackcompose"


class SiJfrog(rx.Component):
    library = "react-icons/si"
    tag = "SiJfrog"


class SiJfrogbintray(rx.Component):
    library = "react-icons/si"
    tag = "SiJfrogbintray"


class SiJinja(rx.Component):
    library = "react-icons/si"
    tag = "SiJinja"


class SiJira(rx.Component):
    library = "react-icons/si"
    tag = "SiJira"


class SiJirasoftware(rx.Component):
    library = "react-icons/si"
    tag = "SiJirasoftware"


class SiJitsi(rx.Component):
    library = "react-icons/si"
    tag = "SiJitsi"


class SiJohndeere(rx.Component):
    library = "react-icons/si"
    tag = "SiJohndeere"


class SiJoomla(rx.Component):
    library = "react-icons/si"
    tag = "SiJoomla"


class SiJoplin(rx.Component):
    library = "react-icons/si"
    tag = "SiJoplin"


class SiJordan(rx.Component):
    library = "react-icons/si"
    tag = "SiJordan"


class SiJpeg(rx.Component):
    library = "react-icons/si"
    tag = "SiJpeg"


class SiJquery(rx.Component):
    library = "react-icons/si"
    tag = "SiJquery"


class SiJrgroup(rx.Component):
    library = "react-icons/si"
    tag = "SiJrgroup"


class SiJsdelivr(rx.Component):
    library = "react-icons/si"
    tag = "SiJsdelivr"


class SiJsfiddle(rx.Component):
    library = "react-icons/si"
    tag = "SiJsfiddle"


class SiJson(rx.Component):
    library = "react-icons/si"
    tag = "SiJson"


class SiJsonwebtokens(rx.Component):
    library = "react-icons/si"
    tag = "SiJsonwebtokens"


class SiJss(rx.Component):
    library = "react-icons/si"
    tag = "SiJss"


class SiJuke(rx.Component):
    library = "react-icons/si"
    tag = "SiJuke"


class SiJulia(rx.Component):
    library = "react-icons/si"
    tag = "SiJulia"


class SiJunipernetworks(rx.Component):
    library = "react-icons/si"
    tag = "SiJunipernetworks"


class SiJunit5(rx.Component):
    library = "react-icons/si"
    tag = "SiJunit5"


class SiJupyter(rx.Component):
    library = "react-icons/si"
    tag = "SiJupyter"


class SiJusteat(rx.Component):
    library = "react-icons/si"
    tag = "SiJusteat"


class SiJustgiving(rx.Component):
    library = "react-icons/si"
    tag = "SiJustgiving"


class SiK3S(rx.Component):
    library = "react-icons/si"
    tag = "SiK3S"


class SiK6(rx.Component):
    library = "react-icons/si"
    tag = "SiK6"


class SiKaggle(rx.Component):
    library = "react-icons/si"
    tag = "SiKaggle"


class SiKahoot(rx.Component):
    library = "react-icons/si"
    tag = "SiKahoot"


class SiKaios(rx.Component):
    library = "react-icons/si"
    tag = "SiKaios"


class SiKakao(rx.Component):
    library = "react-icons/si"
    tag = "SiKakao"


class SiKakaotalk(rx.Component):
    library = "react-icons/si"
    tag = "SiKakaotalk"


class SiKalilinux(rx.Component):
    library = "react-icons/si"
    tag = "SiKalilinux"


class SiKaniko(rx.Component):
    library = "react-icons/si"
    tag = "SiKaniko"


class SiKarlsruherverkehrsverbund(rx.Component):
    library = "react-icons/si"
    tag = "SiKarlsruherverkehrsverbund"


class SiKasasmart(rx.Component):
    library = "react-icons/si"
    tag = "SiKasasmart"


class SiKashflow(rx.Component):
    library = "react-icons/si"
    tag = "SiKashflow"


class SiKaspersky(rx.Component):
    library = "react-icons/si"
    tag = "SiKaspersky"


class SiKatacoda(rx.Component):
    library = "react-icons/si"
    tag = "SiKatacoda"


class SiKatana(rx.Component):
    library = "react-icons/si"
    tag = "SiKatana"


class SiKaufland(rx.Component):
    library = "react-icons/si"
    tag = "SiKaufland"


class SiKde(rx.Component):
    library = "react-icons/si"
    tag = "SiKde"


class SiKdenlive(rx.Component):
    library = "react-icons/si"
    tag = "SiKdenlive"


class SiKeepachangelog(rx.Component):
    library = "react-icons/si"
    tag = "SiKeepachangelog"


class SiKeepassxc(rx.Component):
    library = "react-icons/si"
    tag = "SiKeepassxc"


class SiKentico(rx.Component):
    library = "react-icons/si"
    tag = "SiKentico"


class SiKeras(rx.Component):
    library = "react-icons/si"
    tag = "SiKeras"


class SiKeybase(rx.Component):
    library = "react-icons/si"
    tag = "SiKeybase"


class SiKeycdn(rx.Component):
    library = "react-icons/si"
    tag = "SiKeycdn"


class SiKeystone(rx.Component):
    library = "react-icons/si"
    tag = "SiKeystone"


class SiKfc(rx.Component):
    library = "react-icons/si"
    tag = "SiKfc"


class SiKhanacademy(rx.Component):
    library = "react-icons/si"
    tag = "SiKhanacademy"


class SiKhronosgroup(rx.Component):
    library = "react-icons/si"
    tag = "SiKhronosgroup"


class SiKia(rx.Component):
    library = "react-icons/si"
    tag = "SiKia"


class SiKibana(rx.Component):
    library = "react-icons/si"
    tag = "SiKibana"


class SiKicad(rx.Component):
    library = "react-icons/si"
    tag = "SiKicad"


class SiKickstarter(rx.Component):
    library = "react-icons/si"
    tag = "SiKickstarter"


class SiKik(rx.Component):
    library = "react-icons/si"
    tag = "SiKik"


class SiKingstontechnology(rx.Component):
    library = "react-icons/si"
    tag = "SiKingstontechnology"


class SiKinopoisk(rx.Component):
    library = "react-icons/si"
    tag = "SiKinopoisk"


class SiKirby(rx.Component):
    library = "react-icons/si"
    tag = "SiKirby"


class SiKitsu(rx.Component):
    library = "react-icons/si"
    tag = "SiKitsu"


class SiKlarna(rx.Component):
    library = "react-icons/si"
    tag = "SiKlarna"


class SiKlm(rx.Component):
    library = "react-icons/si"
    tag = "SiKlm"


class SiKlook(rx.Component):
    library = "react-icons/si"
    tag = "SiKlook"


class SiKnative(rx.Component):
    library = "react-icons/si"
    tag = "SiKnative"


class SiKnowledgebase(rx.Component):
    library = "react-icons/si"
    tag = "SiKnowledgebase"


class SiKnown(rx.Component):
    library = "react-icons/si"
    tag = "SiKnown"


class SiKoa(rx.Component):
    library = "react-icons/si"
    tag = "SiKoa"


class SiKoc(rx.Component):
    library = "react-icons/si"
    tag = "SiKoc"


class SiKodi(rx.Component):
    library = "react-icons/si"
    tag = "SiKodi"


class SiKofax(rx.Component):
    library = "react-icons/si"
    tag = "SiKofax"


class SiKofi(rx.Component):
    library = "react-icons/si"
    tag = "SiKofi"


class SiKomoot(rx.Component):
    library = "react-icons/si"
    tag = "SiKomoot"


class SiKonami(rx.Component):
    library = "react-icons/si"
    tag = "SiKonami"


class SiKong(rx.Component):
    library = "react-icons/si"
    tag = "SiKong"


class SiKongregate(rx.Component):
    library = "react-icons/si"
    tag = "SiKongregate"


class SiKonva(rx.Component):
    library = "react-icons/si"
    tag = "SiKonva"


class SiKotlin(rx.Component):
    library = "react-icons/si"
    tag = "SiKotlin"


class SiKoyeb(rx.Component):
    library = "react-icons/si"
    tag = "SiKoyeb"


class SiKrita(rx.Component):
    library = "react-icons/si"
    tag = "SiKrita"


class SiKtm(rx.Component):
    library = "react-icons/si"
    tag = "SiKtm"


class SiKuaishou(rx.Component):
    library = "react-icons/si"
    tag = "SiKuaishou"


class SiKubernetes(rx.Component):
    library = "react-icons/si"
    tag = "SiKubernetes"


class SiKubuntu(rx.Component):
    library = "react-icons/si"
    tag = "SiKubuntu"


class SiKuma(rx.Component):
    library = "react-icons/si"
    tag = "SiKuma"


class SiKuula(rx.Component):
    library = "react-icons/si"
    tag = "SiKuula"


class SiKyocera(rx.Component):
    library = "react-icons/si"
    tag = "SiKyocera"


class SiLabview(rx.Component):
    library = "react-icons/si"
    tag = "SiLabview"


class SiLada(rx.Component):
    library = "react-icons/si"
    tag = "SiLada"


class SiLamborghini(rx.Component):
    library = "react-icons/si"
    tag = "SiLamborghini"


class SiLandrover(rx.Component):
    library = "react-icons/si"
    tag = "SiLandrover"


class SiLapce(rx.Component):
    library = "react-icons/si"
    tag = "SiLapce"


class SiLaragon(rx.Component):
    library = "react-icons/si"
    tag = "SiLaragon"


class SiLaravel(rx.Component):
    library = "react-icons/si"
    tag = "SiLaravel"


class SiLaravelhorizon(rx.Component):
    library = "react-icons/si"
    tag = "SiLaravelhorizon"


class SiLaravelnova(rx.Component):
    library = "react-icons/si"
    tag = "SiLaravelnova"


class SiLastdotfm(rx.Component):
    library = "react-icons/si"
    tag = "SiLastdotfm"


class SiLastpass(rx.Component):
    library = "react-icons/si"
    tag = "SiLastpass"


class SiLatex(rx.Component):
    library = "react-icons/si"
    tag = "SiLatex"


class SiLaunchpad(rx.Component):
    library = "react-icons/si"
    tag = "SiLaunchpad"


class SiLazarus(rx.Component):
    library = "react-icons/si"
    tag = "SiLazarus"


class SiLbry(rx.Component):
    library = "react-icons/si"
    tag = "SiLbry"


class SiLeaderprice(rx.Component):
    library = "react-icons/si"
    tag = "SiLeaderprice"


class SiLeaflet(rx.Component):
    library = "react-icons/si"
    tag = "SiLeaflet"


class SiLeanpub(rx.Component):
    library = "react-icons/si"
    tag = "SiLeanpub"


class SiLeetcode(rx.Component):
    library = "react-icons/si"
    tag = "SiLeetcode"


class SiLegacygames(rx.Component):
    library = "react-icons/si"
    tag = "SiLegacygames"


class SiLemmy(rx.Component):
    library = "react-icons/si"
    tag = "SiLemmy"


class SiLenovo(rx.Component):
    library = "react-icons/si"
    tag = "SiLenovo"


class SiLens(rx.Component):
    library = "react-icons/si"
    tag = "SiLens"


class SiLerna(rx.Component):
    library = "react-icons/si"
    tag = "SiLerna"


class SiLeroymerlin(rx.Component):
    library = "react-icons/si"
    tag = "SiLeroymerlin"


class SiLess(rx.Component):
    library = "react-icons/si"
    tag = "SiLess"


class SiLetsencrypt(rx.Component):
    library = "react-icons/si"
    tag = "SiLetsencrypt"


class SiLetterboxd(rx.Component):
    library = "react-icons/si"
    tag = "SiLetterboxd"


class SiLevelsdotfyi(rx.Component):
    library = "react-icons/si"
    tag = "SiLevelsdotfyi"


class SiLg(rx.Component):
    library = "react-icons/si"
    tag = "SiLg"


class SiLgtm(rx.Component):
    library = "react-icons/si"
    tag = "SiLgtm"


class SiLiberapay(rx.Component):
    library = "react-icons/si"
    tag = "SiLiberapay"


class SiLibrariesdotio(rx.Component):
    library = "react-icons/si"
    tag = "SiLibrariesdotio"


class SiLibrarything(rx.Component):
    library = "react-icons/si"
    tag = "SiLibrarything"


class SiLibreoffice(rx.Component):
    library = "react-icons/si"
    tag = "SiLibreoffice"


class SiLibuv(rx.Component):
    library = "react-icons/si"
    tag = "SiLibuv"


class SiLichess(rx.Component):
    library = "react-icons/si"
    tag = "SiLichess"


class SiLidl(rx.Component):
    library = "react-icons/si"
    tag = "SiLidl"


class SiLifx(rx.Component):
    library = "react-icons/si"
    tag = "SiLifx"


class SiLighthouse(rx.Component):
    library = "react-icons/si"
    tag = "SiLighthouse"


class SiLightning(rx.Component):
    library = "react-icons/si"
    tag = "SiLightning"


class SiLine(rx.Component):
    library = "react-icons/si"
    tag = "SiLine"


class SiLineageos(rx.Component):
    library = "react-icons/si"
    tag = "SiLineageos"


class SiLinear(rx.Component):
    library = "react-icons/si"
    tag = "SiLinear"


class SiLinkedin(rx.Component):
    library = "react-icons/si"
    tag = "SiLinkedin"


class SiLinkerd(rx.Component):
    library = "react-icons/si"
    tag = "SiLinkerd"


class SiLinkfire(rx.Component):
    library = "react-icons/si"
    tag = "SiLinkfire"


class SiLinktree(rx.Component):
    library = "react-icons/si"
    tag = "SiLinktree"


class SiLinux(rx.Component):
    library = "react-icons/si"
    tag = "SiLinux"


class SiLinuxcontainers(rx.Component):
    library = "react-icons/si"
    tag = "SiLinuxcontainers"


class SiLinuxfoundation(rx.Component):
    library = "react-icons/si"
    tag = "SiLinuxfoundation"


class SiLinuxmint(rx.Component):
    library = "react-icons/si"
    tag = "SiLinuxmint"


class SiLionair(rx.Component):
    library = "react-icons/si"
    tag = "SiLionair"


class SiLiquibase(rx.Component):
    library = "react-icons/si"
    tag = "SiLiquibase"


class SiLit(rx.Component):
    library = "react-icons/si"
    tag = "SiLit"


class SiLitecoin(rx.Component):
    library = "react-icons/si"
    tag = "SiLitecoin"


class SiLitiengine(rx.Component):
    library = "react-icons/si"
    tag = "SiLitiengine"


class SiLivechat(rx.Component):
    library = "react-icons/si"
    tag = "SiLivechat"


class SiLivejournal(rx.Component):
    library = "react-icons/si"
    tag = "SiLivejournal"


class SiLivewire(rx.Component):
    library = "react-icons/si"
    tag = "SiLivewire"


class SiLlvm(rx.Component):
    library = "react-icons/si"
    tag = "SiLlvm"


class SiLmms(rx.Component):
    library = "react-icons/si"
    tag = "SiLmms"


class SiLodash(rx.Component):
    library = "react-icons/si"
    tag = "SiLodash"


class SiLogitech(rx.Component):
    library = "react-icons/si"
    tag = "SiLogitech"


class SiLogmein(rx.Component):
    library = "react-icons/si"
    tag = "SiLogmein"


class SiLogstash(rx.Component):
    library = "react-icons/si"
    tag = "SiLogstash"


class SiLooker(rx.Component):
    library = "react-icons/si"
    tag = "SiLooker"


class SiLoom(rx.Component):
    library = "react-icons/si"
    tag = "SiLoom"


class SiLoop(rx.Component):
    library = "react-icons/si"
    tag = "SiLoop"


class SiLoopback(rx.Component):
    library = "react-icons/si"
    tag = "SiLoopback"


class SiLospec(rx.Component):
    library = "react-icons/si"
    tag = "SiLospec"


class SiLotpolishairlines(rx.Component):
    library = "react-icons/si"
    tag = "SiLotpolishairlines"


class SiLua(rx.Component):
    library = "react-icons/si"
    tag = "SiLua"


class SiLubuntu(rx.Component):
    library = "react-icons/si"
    tag = "SiLubuntu"


class SiLudwig(rx.Component):
    library = "react-icons/si"
    tag = "SiLudwig"


class SiLufthansa(rx.Component):
    library = "react-icons/si"
    tag = "SiLufthansa"


class SiLumen(rx.Component):
    library = "react-icons/si"
    tag = "SiLumen"


class SiLunacy(rx.Component):
    library = "react-icons/si"
    tag = "SiLunacy"


class SiLydia(rx.Component):
    library = "react-icons/si"
    tag = "SiLydia"


class SiLyft(rx.Component):
    library = "react-icons/si"
    tag = "SiLyft"


class SiMaas(rx.Component):
    library = "react-icons/si"
    tag = "SiMaas"


class SiMacos(rx.Component):
    library = "react-icons/si"
    tag = "SiMacos"


class SiMacpaw(rx.Component):
    library = "react-icons/si"
    tag = "SiMacpaw"


class SiMacys(rx.Component):
    library = "react-icons/si"
    tag = "SiMacys"


class SiMagasinsu(rx.Component):
    library = "react-icons/si"
    tag = "SiMagasinsu"


class SiMagento(rx.Component):
    library = "react-icons/si"
    tag = "SiMagento"


class SiMagisk(rx.Component):
    library = "react-icons/si"
    tag = "SiMagisk"


class SiMailchimp(rx.Component):
    library = "react-icons/si"
    tag = "SiMailchimp"


class SiMaildotru(rx.Component):
    library = "react-icons/si"
    tag = "SiMaildotru"


class SiMailgun(rx.Component):
    library = "react-icons/si"
    tag = "SiMailgun"


class SiMajorleaguehacking(rx.Component):
    library = "react-icons/si"
    tag = "SiMajorleaguehacking"


class SiMakerbot(rx.Component):
    library = "react-icons/si"
    tag = "SiMakerbot"


class SiMamp(rx.Component):
    library = "react-icons/si"
    tag = "SiMamp"


class SiMan(rx.Component):
    library = "react-icons/si"
    tag = "SiMan"


class SiManageiq(rx.Component):
    library = "react-icons/si"
    tag = "SiManageiq"


class SiManjaro(rx.Component):
    library = "react-icons/si"
    tag = "SiManjaro"


class SiMapbox(rx.Component):
    library = "react-icons/si"
    tag = "SiMapbox"


class SiMariadb(rx.Component):
    library = "react-icons/si"
    tag = "SiMariadb"


class SiMariadbfoundation(rx.Component):
    library = "react-icons/si"
    tag = "SiMariadbfoundation"


class SiMarkdown(rx.Component):
    library = "react-icons/si"
    tag = "SiMarkdown"


class SiMarketo(rx.Component):
    library = "react-icons/si"
    tag = "SiMarketo"


class SiMarko(rx.Component):
    library = "react-icons/si"
    tag = "SiMarko"


class SiMarriott(rx.Component):
    library = "react-icons/si"
    tag = "SiMarriott"


class SiMaserati(rx.Component):
    library = "react-icons/si"
    tag = "SiMaserati"


class SiMastercard(rx.Component):
    library = "react-icons/si"
    tag = "SiMastercard"


class SiMastercomfig(rx.Component):
    library = "react-icons/si"
    tag = "SiMastercomfig"


class SiMastodon(rx.Component):
    library = "react-icons/si"
    tag = "SiMastodon"


class SiMaterialdesign(rx.Component):
    library = "react-icons/si"
    tag = "SiMaterialdesign"


class SiMaterialdesignicons(rx.Component):
    library = "react-icons/si"
    tag = "SiMaterialdesignicons"


class SiMatomo(rx.Component):
    library = "react-icons/si"
    tag = "SiMatomo"


class SiMatrix(rx.Component):
    library = "react-icons/si"
    tag = "SiMatrix"


class SiMatterdotjs(rx.Component):
    library = "react-icons/si"
    tag = "SiMatterdotjs"


class SiMattermost(rx.Component):
    library = "react-icons/si"
    tag = "SiMattermost"


class SiMatternet(rx.Component):
    library = "react-icons/si"
    tag = "SiMatternet"


class SiMax(rx.Component):
    library = "react-icons/si"
    tag = "SiMax"


class SiMaxplanckgesellschaft(rx.Component):
    library = "react-icons/si"
    tag = "SiMaxplanckgesellschaft"


class SiMaytag(rx.Component):
    library = "react-icons/si"
    tag = "SiMaytag"


class SiMazda(rx.Component):
    library = "react-icons/si"
    tag = "SiMazda"


class SiMcafee(rx.Component):
    library = "react-icons/si"
    tag = "SiMcafee"


class SiMcdonalds(rx.Component):
    library = "react-icons/si"
    tag = "SiMcdonalds"


class SiMclaren(rx.Component):
    library = "react-icons/si"
    tag = "SiMclaren"


class SiMdbook(rx.Component):
    library = "react-icons/si"
    tag = "SiMdbook"


class SiMdnwebdocs(rx.Component):
    library = "react-icons/si"
    tag = "SiMdnwebdocs"


class SiMdx(rx.Component):
    library = "react-icons/si"
    tag = "SiMdx"


class SiMediafire(rx.Component):
    library = "react-icons/si"
    tag = "SiMediafire"


class SiMediamarkt(rx.Component):
    library = "react-icons/si"
    tag = "SiMediamarkt"


class SiMediatek(rx.Component):
    library = "react-icons/si"
    tag = "SiMediatek"


class SiMediatemple(rx.Component):
    library = "react-icons/si"
    tag = "SiMediatemple"


class SiMedium(rx.Component):
    library = "react-icons/si"
    tag = "SiMedium"


class SiMeetup(rx.Component):
    library = "react-icons/si"
    tag = "SiMeetup"


class SiMega(rx.Component):
    library = "react-icons/si"
    tag = "SiMega"


class SiMendeley(rx.Component):
    library = "react-icons/si"
    tag = "SiMendeley"


class SiMercadopago(rx.Component):
    library = "react-icons/si"
    tag = "SiMercadopago"


class SiMercedes(rx.Component):
    library = "react-icons/si"
    tag = "SiMercedes"


class SiMerck(rx.Component):
    library = "react-icons/si"
    tag = "SiMerck"


class SiMercurial(rx.Component):
    library = "react-icons/si"
    tag = "SiMercurial"


class SiMessenger(rx.Component):
    library = "react-icons/si"
    tag = "SiMessenger"


class SiMeta(rx.Component):
    library = "react-icons/si"
    tag = "SiMeta"


class SiMetabase(rx.Component):
    library = "react-icons/si"
    tag = "SiMetabase"


class SiMetafilter(rx.Component):
    library = "react-icons/si"
    tag = "SiMetafilter"


class SiMeteor(rx.Component):
    library = "react-icons/si"
    tag = "SiMeteor"


class SiMetro(rx.Component):
    library = "react-icons/si"
    tag = "SiMetro"


class SiMetrodelaciudaddemexico(rx.Component):
    library = "react-icons/si"
    tag = "SiMetrodelaciudaddemexico"


class SiMetrodemadrid(rx.Component):
    library = "react-icons/si"
    tag = "SiMetrodemadrid"


class SiMetrodeparis(rx.Component):
    library = "react-icons/si"
    tag = "SiMetrodeparis"


class SiMewe(rx.Component):
    library = "react-icons/si"
    tag = "SiMewe"


class SiMicrobit(rx.Component):
    library = "react-icons/si"
    tag = "SiMicrobit"


class SiMicrodotblog(rx.Component):
    library = "react-icons/si"
    tag = "SiMicrodotblog"


class SiMicrogenetics(rx.Component):
    library = "react-icons/si"
    tag = "SiMicrogenetics"


class SiMicropython(rx.Component):
    library = "react-icons/si"
    tag = "SiMicropython"


class SiMicrosoft(rx.Component):
    library = "react-icons/si"
    tag = "SiMicrosoft"


class SiMicrosoftacademic(rx.Component):
    library = "react-icons/si"
    tag = "SiMicrosoftacademic"


class SiMicrosoftaccess(rx.Component):
    library = "react-icons/si"
    tag = "SiMicrosoftaccess"


class SiMicrosoftazure(rx.Component):
    library = "react-icons/si"
    tag = "SiMicrosoftazure"


class SiMicrosoftbing(rx.Component):
    library = "react-icons/si"
    tag = "SiMicrosoftbing"


class SiMicrosoftedge(rx.Component):
    library = "react-icons/si"
    tag = "SiMicrosoftedge"


class SiMicrosoftexcel(rx.Component):
    library = "react-icons/si"
    tag = "SiMicrosoftexcel"


class SiMicrosoftexchange(rx.Component):
    library = "react-icons/si"
    tag = "SiMicrosoftexchange"


class SiMicrosoftoffice(rx.Component):
    library = "react-icons/si"
    tag = "SiMicrosoftoffice"


class SiMicrosoftonedrive(rx.Component):
    library = "react-icons/si"
    tag = "SiMicrosoftonedrive"


class SiMicrosoftonenote(rx.Component):
    library = "react-icons/si"
    tag = "SiMicrosoftonenote"


class SiMicrosoftoutlook(rx.Component):
    library = "react-icons/si"
    tag = "SiMicrosoftoutlook"


class SiMicrosoftpowerpoint(rx.Component):
    library = "react-icons/si"
    tag = "SiMicrosoftpowerpoint"


class SiMicrosoftsharepoint(rx.Component):
    library = "react-icons/si"
    tag = "SiMicrosoftsharepoint"


class SiMicrosoftsqlserver(rx.Component):
    library = "react-icons/si"
    tag = "SiMicrosoftsqlserver"


class SiMicrosoftteams(rx.Component):
    library = "react-icons/si"
    tag = "SiMicrosoftteams"


class SiMicrosofttranslator(rx.Component):
    library = "react-icons/si"
    tag = "SiMicrosofttranslator"


class SiMicrosoftvisio(rx.Component):
    library = "react-icons/si"
    tag = "SiMicrosoftvisio"


class SiMicrosoftword(rx.Component):
    library = "react-icons/si"
    tag = "SiMicrosoftword"


class SiMicrostrategy(rx.Component):
    library = "react-icons/si"
    tag = "SiMicrostrategy"


class SiMidi(rx.Component):
    library = "react-icons/si"
    tag = "SiMidi"


class SiMinds(rx.Component):
    library = "react-icons/si"
    tag = "SiMinds"


class SiMinecraft(rx.Component):
    library = "react-icons/si"
    tag = "SiMinecraft"


class SiMinetest(rx.Component):
    library = "react-icons/si"
    tag = "SiMinetest"


class SiMini(rx.Component):
    library = "react-icons/si"
    tag = "SiMini"


class SiMinutemailer(rx.Component):
    library = "react-icons/si"
    tag = "SiMinutemailer"


class SiMiro(rx.Component):
    library = "react-icons/si"
    tag = "SiMiro"


class SiMisskey(rx.Component):
    library = "react-icons/si"
    tag = "SiMisskey"


class SiMitsubishi(rx.Component):
    library = "react-icons/si"
    tag = "SiMitsubishi"


class SiMix(rx.Component):
    library = "react-icons/si"
    tag = "SiMix"


class SiMixcloud(rx.Component):
    library = "react-icons/si"
    tag = "SiMixcloud"


class SiMlb(rx.Component):
    library = "react-icons/si"
    tag = "SiMlb"


class SiMlflow(rx.Component):
    library = "react-icons/si"
    tag = "SiMlflow"


class SiMobx(rx.Component):
    library = "react-icons/si"
    tag = "SiMobx"


class SiMobxstatetree(rx.Component):
    library = "react-icons/si"
    tag = "SiMobxstatetree"


class SiMocha(rx.Component):
    library = "react-icons/si"
    tag = "SiMocha"


class SiModin(rx.Component):
    library = "react-icons/si"
    tag = "SiModin"


class SiModrinth(rx.Component):
    library = "react-icons/si"
    tag = "SiModrinth"


class SiModx(rx.Component):
    library = "react-icons/si"
    tag = "SiModx"


class SiMojangstudios(rx.Component):
    library = "react-icons/si"
    tag = "SiMojangstudios"


class SiMoleculer(rx.Component):
    library = "react-icons/si"
    tag = "SiMoleculer"


class SiMomenteo(rx.Component):
    library = "react-icons/si"
    tag = "SiMomenteo"


class SiMonero(rx.Component):
    library = "react-icons/si"
    tag = "SiMonero"


class SiMoneygram(rx.Component):
    library = "react-icons/si"
    tag = "SiMoneygram"


class SiMongodb(rx.Component):
    library = "react-icons/si"
    tag = "SiMongodb"


class SiMongoose(rx.Component):
    library = "react-icons/si"
    tag = "SiMongoose"


class SiMonica(rx.Component):
    library = "react-icons/si"
    tag = "SiMonica"


class SiMonkeytie(rx.Component):
    library = "react-icons/si"
    tag = "SiMonkeytie"


class SiMonogame(rx.Component):
    library = "react-icons/si"
    tag = "SiMonogame"


class SiMonoprix(rx.Component):
    library = "react-icons/si"
    tag = "SiMonoprix"


class SiMonster(rx.Component):
    library = "react-icons/si"
    tag = "SiMonster"


class SiMonzo(rx.Component):
    library = "react-icons/si"
    tag = "SiMonzo"


class SiMoo(rx.Component):
    library = "react-icons/si"
    tag = "SiMoo"


class SiMoonrepo(rx.Component):
    library = "react-icons/si"
    tag = "SiMoonrepo"


class SiMorrisons(rx.Component):
    library = "react-icons/si"
    tag = "SiMorrisons"


class SiMoscowmetro(rx.Component):
    library = "react-icons/si"
    tag = "SiMoscowmetro"


class SiMotorola(rx.Component):
    library = "react-icons/si"
    tag = "SiMotorola"


class SiMozilla(rx.Component):
    library = "react-icons/si"
    tag = "SiMozilla"


class SiMqtt(rx.Component):
    library = "react-icons/si"
    tag = "SiMqtt"


class SiMsi(rx.Component):
    library = "react-icons/si"
    tag = "SiMsi"


class SiMsibusiness(rx.Component):
    library = "react-icons/si"
    tag = "SiMsibusiness"


class SiMta(rx.Component):
    library = "react-icons/si"
    tag = "SiMta"


class SiMtr(rx.Component):
    library = "react-icons/si"
    tag = "SiMtr"


class SiMubi(rx.Component):
    library = "react-icons/si"
    tag = "SiMubi"


class SiMui(rx.Component):
    library = "react-icons/si"
    tag = "SiMui"


class SiMulesoft(rx.Component):
    library = "react-icons/si"
    tag = "SiMulesoft"


class SiMuller(rx.Component):
    library = "react-icons/si"
    tag = "SiMuller"


class SiMumble(rx.Component):
    library = "react-icons/si"
    tag = "SiMumble"


class SiMusescore(rx.Component):
    library = "react-icons/si"
    tag = "SiMusescore"


class SiMusicbrainz(rx.Component):
    library = "react-icons/si"
    tag = "SiMusicbrainz"


class SiMxlinux(rx.Component):
    library = "react-icons/si"
    tag = "SiMxlinux"


class SiMyanimelist(rx.Component):
    library = "react-icons/si"
    tag = "SiMyanimelist"


class SiMyob(rx.Component):
    library = "react-icons/si"
    tag = "SiMyob"


class SiMyspace(rx.Component):
    library = "react-icons/si"
    tag = "SiMyspace"


class SiMysql(rx.Component):
    library = "react-icons/si"
    tag = "SiMysql"


class SiN26(rx.Component):
    library = "react-icons/si"
    tag = "SiN26"


class SiNamebase(rx.Component):
    library = "react-icons/si"
    tag = "SiNamebase"


class SiNamecheap(rx.Component):
    library = "react-icons/si"
    tag = "SiNamecheap"


class SiNano(rx.Component):
    library = "react-icons/si"
    tag = "SiNano"


class SiNasa(rx.Component):
    library = "react-icons/si"
    tag = "SiNasa"


class SiNationalgrid(rx.Component):
    library = "react-icons/si"
    tag = "SiNationalgrid"


class SiNativescript(rx.Component):
    library = "react-icons/si"
    tag = "SiNativescript"


class SiNaver(rx.Component):
    library = "react-icons/si"
    tag = "SiNaver"


class SiNba(rx.Component):
    library = "react-icons/si"
    tag = "SiNba"


class SiNbb(rx.Component):
    library = "react-icons/si"
    tag = "SiNbb"


class SiNdr(rx.Component):
    library = "react-icons/si"
    tag = "SiNdr"


class SiNec(rx.Component):
    library = "react-icons/si"
    tag = "SiNec"


class SiNeo4J(rx.Component):
    library = "react-icons/si"
    tag = "SiNeo4J"


class SiNeovim(rx.Component):
    library = "react-icons/si"
    tag = "SiNeovim"


class SiNestjs(rx.Component):
    library = "react-icons/si"
    tag = "SiNestjs"


class SiNetapp(rx.Component):
    library = "react-icons/si"
    tag = "SiNetapp"


class SiNetbsd(rx.Component):
    library = "react-icons/si"
    tag = "SiNetbsd"


class SiNetflix(rx.Component):
    library = "react-icons/si"
    tag = "SiNetflix"


class SiNetlify(rx.Component):
    library = "react-icons/si"
    tag = "SiNetlify"


class SiNette(rx.Component):
    library = "react-icons/si"
    tag = "SiNette"


class SiNetto(rx.Component):
    library = "react-icons/si"
    tag = "SiNetto"


class SiNeutralinojs(rx.Component):
    library = "react-icons/si"
    tag = "SiNeutralinojs"


class SiNewbalance(rx.Component):
    library = "react-icons/si"
    tag = "SiNewbalance"


class SiNewjapanprowrestling(rx.Component):
    library = "react-icons/si"
    tag = "SiNewjapanprowrestling"


class SiNewrelic(rx.Component):
    library = "react-icons/si"
    tag = "SiNewrelic"


class SiNewyorktimes(rx.Component):
    library = "react-icons/si"
    tag = "SiNewyorktimes"


class SiNextbilliondotai(rx.Component):
    library = "react-icons/si"
    tag = "SiNextbilliondotai"


class SiNextcloud(rx.Component):
    library = "react-icons/si"
    tag = "SiNextcloud"


class SiNextdoor(rx.Component):
    library = "react-icons/si"
    tag = "SiNextdoor"


class SiNextdotjs(rx.Component):
    library = "react-icons/si"
    tag = "SiNextdotjs"


class SiNfc(rx.Component):
    library = "react-icons/si"
    tag = "SiNfc"


class SiNginx(rx.Component):
    library = "react-icons/si"
    tag = "SiNginx"


class SiNgrok(rx.Component):
    library = "react-icons/si"
    tag = "SiNgrok"


class SiNiconico(rx.Component):
    library = "react-icons/si"
    tag = "SiNiconico"


class SiNike(rx.Component):
    library = "react-icons/si"
    tag = "SiNike"


class SiNim(rx.Component):
    library = "react-icons/si"
    tag = "SiNim"


class SiNintendo(rx.Component):
    library = "react-icons/si"
    tag = "SiNintendo"


class SiNintendo3Ds(rx.Component):
    library = "react-icons/si"
    tag = "SiNintendo3Ds"


class SiNintendogamecube(rx.Component):
    library = "react-icons/si"
    tag = "SiNintendogamecube"


class SiNintendonetwork(rx.Component):
    library = "react-icons/si"
    tag = "SiNintendonetwork"


class SiNintendoswitch(rx.Component):
    library = "react-icons/si"
    tag = "SiNintendoswitch"


class SiNissan(rx.Component):
    library = "react-icons/si"
    tag = "SiNissan"


class SiNixos(rx.Component):
    library = "react-icons/si"
    tag = "SiNixos"


class SiNodedotjs(rx.Component):
    library = "react-icons/si"
    tag = "SiNodedotjs"


class SiNodemon(rx.Component):
    library = "react-icons/si"
    tag = "SiNodemon"


class SiNodered(rx.Component):
    library = "react-icons/si"
    tag = "SiNodered"


class SiNokia(rx.Component):
    library = "react-icons/si"
    tag = "SiNokia"


class SiNorco(rx.Component):
    library = "react-icons/si"
    tag = "SiNorco"


class SiNordvpn(rx.Component):
    library = "react-icons/si"
    tag = "SiNordvpn"


class SiNormalizedotcss(rx.Component):
    library = "react-icons/si"
    tag = "SiNormalizedotcss"


class SiNorwegian(rx.Component):
    library = "react-icons/si"
    tag = "SiNorwegian"


class SiNotepadplusplus(rx.Component):
    library = "react-icons/si"
    tag = "SiNotepadplusplus"


class SiNotion(rx.Component):
    library = "react-icons/si"
    tag = "SiNotion"


class SiNotist(rx.Component):
    library = "react-icons/si"
    tag = "SiNotist"


class SiNounproject(rx.Component):
    library = "react-icons/si"
    tag = "SiNounproject"


class SiNovu(rx.Component):
    library = "react-icons/si"
    tag = "SiNovu"


class SiNow(rx.Component):
    library = "react-icons/si"
    tag = "SiNow"


class SiNpm(rx.Component):
    library = "react-icons/si"
    tag = "SiNpm"


class SiNrwl(rx.Component):
    library = "react-icons/si"
    tag = "SiNrwl"


class SiNubank(rx.Component):
    library = "react-icons/si"
    tag = "SiNubank"


class SiNucleo(rx.Component):
    library = "react-icons/si"
    tag = "SiNucleo"


class SiNuget(rx.Component):
    library = "react-icons/si"
    tag = "SiNuget"


class SiNuke(rx.Component):
    library = "react-icons/si"
    tag = "SiNuke"


class SiNumba(rx.Component):
    library = "react-icons/si"
    tag = "SiNumba"


class SiNumpy(rx.Component):
    library = "react-icons/si"
    tag = "SiNumpy"


class SiNunjucks(rx.Component):
    library = "react-icons/si"
    tag = "SiNunjucks"


class SiNutanix(rx.Component):
    library = "react-icons/si"
    tag = "SiNutanix"


class SiNuxtdotjs(rx.Component):
    library = "react-icons/si"
    tag = "SiNuxtdotjs"


class SiNvidia(rx.Component):
    library = "react-icons/si"
    tag = "SiNvidia"


class SiNx(rx.Component):
    library = "react-icons/si"
    tag = "SiNx"


class SiNzxt(rx.Component):
    library = "react-icons/si"
    tag = "SiNzxt"


class SiObservable(rx.Component):
    library = "react-icons/si"
    tag = "SiObservable"


class SiObsidian(rx.Component):
    library = "react-icons/si"
    tag = "SiObsidian"


class SiObsstudio(rx.Component):
    library = "react-icons/si"
    tag = "SiObsstudio"


class SiOcaml(rx.Component):
    library = "react-icons/si"
    tag = "SiOcaml"


class SiOctanerender(rx.Component):
    library = "react-icons/si"
    tag = "SiOctanerender"


class SiOctave(rx.Component):
    library = "react-icons/si"
    tag = "SiOctave"


class SiOctoprint(rx.Component):
    library = "react-icons/si"
    tag = "SiOctoprint"


class SiOctopusdeploy(rx.Component):
    library = "react-icons/si"
    tag = "SiOctopusdeploy"


class SiOculus(rx.Component):
    library = "react-icons/si"
    tag = "SiOculus"


class SiOdnoklassniki(rx.Component):
    library = "react-icons/si"
    tag = "SiOdnoklassniki"


class SiOdysee(rx.Component):
    library = "react-icons/si"
    tag = "SiOdysee"


class SiOhdear(rx.Component):
    library = "react-icons/si"
    tag = "SiOhdear"


class SiOkcupid(rx.Component):
    library = "react-icons/si"
    tag = "SiOkcupid"


class SiOkta(rx.Component):
    library = "react-icons/si"
    tag = "SiOkta"


class SiOneplus(rx.Component):
    library = "react-icons/si"
    tag = "SiOneplus"


class SiOnlyfans(rx.Component):
    library = "react-icons/si"
    tag = "SiOnlyfans"


class SiOnlyoffice(rx.Component):
    library = "react-icons/si"
    tag = "SiOnlyoffice"


class SiOnnx(rx.Component):
    library = "react-icons/si"
    tag = "SiOnnx"


class SiOnstar(rx.Component):
    library = "react-icons/si"
    tag = "SiOnstar"


class SiOpel(rx.Component):
    library = "react-icons/si"
    tag = "SiOpel"


class SiOpenaccess(rx.Component):
    library = "react-icons/si"
    tag = "SiOpenaccess"


class SiOpenai(rx.Component):
    library = "react-icons/si"
    tag = "SiOpenai"


class SiOpenaigym(rx.Component):
    library = "react-icons/si"
    tag = "SiOpenaigym"


class SiOpenapiinitiative(rx.Component):
    library = "react-icons/si"
    tag = "SiOpenapiinitiative"


class SiOpenbadges(rx.Component):
    library = "react-icons/si"
    tag = "SiOpenbadges"


class SiOpenbsd(rx.Component):
    library = "react-icons/si"
    tag = "SiOpenbsd"


class SiOpenbugbounty(rx.Component):
    library = "react-icons/si"
    tag = "SiOpenbugbounty"


class SiOpencollective(rx.Component):
    library = "react-icons/si"
    tag = "SiOpencollective"


class SiOpencontainersinitiative(rx.Component):
    library = "react-icons/si"
    tag = "SiOpencontainersinitiative"


class SiOpencv(rx.Component):
    library = "react-icons/si"
    tag = "SiOpencv"


class SiOpenfaas(rx.Component):
    library = "react-icons/si"
    tag = "SiOpenfaas"


class SiOpengl(rx.Component):
    library = "react-icons/si"
    tag = "SiOpengl"


class SiOpenid(rx.Component):
    library = "react-icons/si"
    tag = "SiOpenid"


class SiOpenjdk(rx.Component):
    library = "react-icons/si"
    tag = "SiOpenjdk"


class SiOpenlayers(rx.Component):
    library = "react-icons/si"
    tag = "SiOpenlayers"


class SiOpenmined(rx.Component):
    library = "react-icons/si"
    tag = "SiOpenmined"


class SiOpennebula(rx.Component):
    library = "react-icons/si"
    tag = "SiOpennebula"


class SiOpenproject(rx.Component):
    library = "react-icons/si"
    tag = "SiOpenproject"


class SiOpensea(rx.Component):
    library = "react-icons/si"
    tag = "SiOpensea"


class SiOpensearch(rx.Component):
    library = "react-icons/si"
    tag = "SiOpensearch"


class SiOpensourceinitiative(rx.Component):
    library = "react-icons/si"
    tag = "SiOpensourceinitiative"


class SiOpenssl(rx.Component):
    library = "react-icons/si"
    tag = "SiOpenssl"


class SiOpenstack(rx.Component):
    library = "react-icons/si"
    tag = "SiOpenstack"


class SiOpenstreetmap(rx.Component):
    library = "react-icons/si"
    tag = "SiOpenstreetmap"


class SiOpensuse(rx.Component):
    library = "react-icons/si"
    tag = "SiOpensuse"


class SiOpentelemetry(rx.Component):
    library = "react-icons/si"
    tag = "SiOpentelemetry"


class SiOpenverse(rx.Component):
    library = "react-icons/si"
    tag = "SiOpenverse"


class SiOpenvpn(rx.Component):
    library = "react-icons/si"
    tag = "SiOpenvpn"


class SiOpenwrt(rx.Component):
    library = "react-icons/si"
    tag = "SiOpenwrt"


class SiOpenzeppelin(rx.Component):
    library = "react-icons/si"
    tag = "SiOpenzeppelin"


class SiOpenzfs(rx.Component):
    library = "react-icons/si"
    tag = "SiOpenzfs"


class SiOpera(rx.Component):
    library = "react-icons/si"
    tag = "SiOpera"


class SiOpnsense(rx.Component):
    library = "react-icons/si"
    tag = "SiOpnsense"


class SiOpsgenie(rx.Component):
    library = "react-icons/si"
    tag = "SiOpsgenie"


class SiOpslevel(rx.Component):
    library = "react-icons/si"
    tag = "SiOpslevel"


class SiOracle(rx.Component):
    library = "react-icons/si"
    tag = "SiOracle"


class SiOrcid(rx.Component):
    library = "react-icons/si"
    tag = "SiOrcid"


class SiOreilly(rx.Component):
    library = "react-icons/si"
    tag = "SiOreilly"


class SiOrg(rx.Component):
    library = "react-icons/si"
    tag = "SiOrg"


class SiOrigin(rx.Component):
    library = "react-icons/si"
    tag = "SiOrigin"


class SiOsano(rx.Component):
    library = "react-icons/si"
    tag = "SiOsano"


class SiOsgeo(rx.Component):
    library = "react-icons/si"
    tag = "SiOsgeo"


class SiOshkosh(rx.Component):
    library = "react-icons/si"
    tag = "SiOshkosh"


class SiOsmc(rx.Component):
    library = "react-icons/si"
    tag = "SiOsmc"


class SiOsu(rx.Component):
    library = "react-icons/si"
    tag = "SiOsu"


class SiOtto(rx.Component):
    library = "react-icons/si"
    tag = "SiOtto"


class SiOvercast(rx.Component):
    library = "react-icons/si"
    tag = "SiOvercast"


class SiOverleaf(rx.Component):
    library = "react-icons/si"
    tag = "SiOverleaf"


class SiOvh(rx.Component):
    library = "react-icons/si"
    tag = "SiOvh"


class SiOwasp(rx.Component):
    library = "react-icons/si"
    tag = "SiOwasp"


class SiOxygen(rx.Component):
    library = "react-icons/si"
    tag = "SiOxygen"


class SiOyo(rx.Component):
    library = "react-icons/si"
    tag = "SiOyo"


class SiP5Dotjs(rx.Component):
    library = "react-icons/si"
    tag = "SiP5Dotjs"


class SiPackagist(rx.Component):
    library = "react-icons/si"
    tag = "SiPackagist"


class SiPacker(rx.Component):
    library = "react-icons/si"
    tag = "SiPacker"


class SiPaddlepaddle(rx.Component):
    library = "react-icons/si"
    tag = "SiPaddlepaddle"


class SiPaddypower(rx.Component):
    library = "react-icons/si"
    tag = "SiPaddypower"


class SiPagekit(rx.Component):
    library = "react-icons/si"
    tag = "SiPagekit"


class SiPagerduty(rx.Component):
    library = "react-icons/si"
    tag = "SiPagerduty"


class SiPagespeedinsights(rx.Component):
    library = "react-icons/si"
    tag = "SiPagespeedinsights"


class SiPagseguro(rx.Component):
    library = "react-icons/si"
    tag = "SiPagseguro"


class SiPalantir(rx.Component):
    library = "react-icons/si"
    tag = "SiPalantir"


class SiPaloaltosoftware(rx.Component):
    library = "react-icons/si"
    tag = "SiPaloaltosoftware"


class SiPandas(rx.Component):
    library = "react-icons/si"
    tag = "SiPandas"


class SiPandora(rx.Component):
    library = "react-icons/si"
    tag = "SiPandora"


class SiPantheon(rx.Component):
    library = "react-icons/si"
    tag = "SiPantheon"


class SiPaperspace(rx.Component):
    library = "react-icons/si"
    tag = "SiPaperspace"


class SiParitysubstrate(rx.Component):
    library = "react-icons/si"
    tag = "SiParitysubstrate"


class SiParsedotly(rx.Component):
    library = "react-icons/si"
    tag = "SiParsedotly"


class SiPassport(rx.Component):
    library = "react-icons/si"
    tag = "SiPassport"


class SiPastebin(rx.Component):
    library = "react-icons/si"
    tag = "SiPastebin"


class SiPatreon(rx.Component):
    library = "react-icons/si"
    tag = "SiPatreon"


class SiPayloadcms(rx.Component):
    library = "react-icons/si"
    tag = "SiPayloadcms"


class SiPayoneer(rx.Component):
    library = "react-icons/si"
    tag = "SiPayoneer"


class SiPaypal(rx.Component):
    library = "react-icons/si"
    tag = "SiPaypal"


class SiPaytm(rx.Component):
    library = "react-icons/si"
    tag = "SiPaytm"


class SiPcgamingwiki(rx.Component):
    library = "react-icons/si"
    tag = "SiPcgamingwiki"


class SiPeakdesign(rx.Component):
    library = "react-icons/si"
    tag = "SiPeakdesign"


class SiPeertube(rx.Component):
    library = "react-icons/si"
    tag = "SiPeertube"


class SiPegasusairlines(rx.Component):
    library = "react-icons/si"
    tag = "SiPegasusairlines"


class SiPelican(rx.Component):
    library = "react-icons/si"
    tag = "SiPelican"


class SiPeloton(rx.Component):
    library = "react-icons/si"
    tag = "SiPeloton"


class SiPenny(rx.Component):
    library = "react-icons/si"
    tag = "SiPenny"


class SiPenpot(rx.Component):
    library = "react-icons/si"
    tag = "SiPenpot"


class SiPepsi(rx.Component):
    library = "react-icons/si"
    tag = "SiPepsi"


class SiPercy(rx.Component):
    library = "react-icons/si"
    tag = "SiPercy"


class SiPerforce(rx.Component):
    library = "react-icons/si"
    tag = "SiPerforce"


class SiPerl(rx.Component):
    library = "react-icons/si"
    tag = "SiPerl"


class SiPersistent(rx.Component):
    library = "react-icons/si"
    tag = "SiPersistent"


class SiPersonio(rx.Component):
    library = "react-icons/si"
    tag = "SiPersonio"


class SiPetsathome(rx.Component):
    library = "react-icons/si"
    tag = "SiPetsathome"


class SiPeugeot(rx.Component):
    library = "react-icons/si"
    tag = "SiPeugeot"


class SiPexels(rx.Component):
    library = "react-icons/si"
    tag = "SiPexels"


class SiPfsense(rx.Component):
    library = "react-icons/si"
    tag = "SiPfsense"


class SiPhabricator(rx.Component):
    library = "react-icons/si"
    tag = "SiPhabricator"


class SiPhilipshue(rx.Component):
    library = "react-icons/si"
    tag = "SiPhilipshue"


class SiPhonepe(rx.Component):
    library = "react-icons/si"
    tag = "SiPhonepe"


class SiPhotobucket(rx.Component):
    library = "react-icons/si"
    tag = "SiPhotobucket"


class SiPhotocrowd(rx.Component):
    library = "react-icons/si"
    tag = "SiPhotocrowd"


class SiPhotopea(rx.Component):
    library = "react-icons/si"
    tag = "SiPhotopea"


class SiPhp(rx.Component):
    library = "react-icons/si"
    tag = "SiPhp"


class SiPhpmyadmin(rx.Component):
    library = "react-icons/si"
    tag = "SiPhpmyadmin"


class SiPhpstorm(rx.Component):
    library = "react-icons/si"
    tag = "SiPhpstorm"


class SiPicardsurgeles(rx.Component):
    library = "react-icons/si"
    tag = "SiPicardsurgeles"


class SiPicartodottv(rx.Component):
    library = "react-icons/si"
    tag = "SiPicartodottv"


class SiPicnic(rx.Component):
    library = "react-icons/si"
    tag = "SiPicnic"


class SiPicpay(rx.Component):
    library = "react-icons/si"
    tag = "SiPicpay"


class SiPihole(rx.Component):
    library = "react-icons/si"
    tag = "SiPihole"


class SiPimcore(rx.Component):
    library = "react-icons/si"
    tag = "SiPimcore"


class SiPinboard(rx.Component):
    library = "react-icons/si"
    tag = "SiPinboard"


class SiPingdom(rx.Component):
    library = "react-icons/si"
    tag = "SiPingdom"


class SiPinterest(rx.Component):
    library = "react-icons/si"
    tag = "SiPinterest"


class SiPioneerdj(rx.Component):
    library = "react-icons/si"
    tag = "SiPioneerdj"


class SiPivotaltracker(rx.Component):
    library = "react-icons/si"
    tag = "SiPivotaltracker"


class SiPiwigo(rx.Component):
    library = "react-icons/si"
    tag = "SiPiwigo"


class SiPix(rx.Component):
    library = "react-icons/si"
    tag = "SiPix"


class SiPixabay(rx.Component):
    library = "react-icons/si"
    tag = "SiPixabay"


class SiPixiv(rx.Component):
    library = "react-icons/si"
    tag = "SiPixiv"


class SiPkgsrc(rx.Component):
    library = "react-icons/si"
    tag = "SiPkgsrc"


class SiPlanet(rx.Component):
    library = "react-icons/si"
    tag = "SiPlanet"


class SiPlanetscale(rx.Component):
    library = "react-icons/si"
    tag = "SiPlanetscale"


class SiPlangrid(rx.Component):
    library = "react-icons/si"
    tag = "SiPlangrid"


class SiPlatformdotsh(rx.Component):
    library = "react-icons/si"
    tag = "SiPlatformdotsh"


class SiPlatzi(rx.Component):
    library = "react-icons/si"
    tag = "SiPlatzi"


class SiPlausibleanalytics(rx.Component):
    library = "react-icons/si"
    tag = "SiPlausibleanalytics"


class SiPlaycanvas(rx.Component):
    library = "react-icons/si"
    tag = "SiPlaycanvas"


class SiPlayerdotme(rx.Component):
    library = "react-icons/si"
    tag = "SiPlayerdotme"


class SiPlayerfm(rx.Component):
    library = "react-icons/si"
    tag = "SiPlayerfm"


class SiPlaystation(rx.Component):
    library = "react-icons/si"
    tag = "SiPlaystation"


class SiPlaystation2(rx.Component):
    library = "react-icons/si"
    tag = "SiPlaystation2"


class SiPlaystation3(rx.Component):
    library = "react-icons/si"
    tag = "SiPlaystation3"


class SiPlaystation4(rx.Component):
    library = "react-icons/si"
    tag = "SiPlaystation4"


class SiPlaystation5(rx.Component):
    library = "react-icons/si"
    tag = "SiPlaystation5"


class SiPlaystationvita(rx.Component):
    library = "react-icons/si"
    tag = "SiPlaystationvita"


class SiPlaywright(rx.Component):
    library = "react-icons/si"
    tag = "SiPlaywright"


class SiPleroma(rx.Component):
    library = "react-icons/si"
    tag = "SiPleroma"


class SiPlesk(rx.Component):
    library = "react-icons/si"
    tag = "SiPlesk"


class SiPlex(rx.Component):
    library = "react-icons/si"
    tag = "SiPlex"


class SiPlotly(rx.Component):
    library = "react-icons/si"
    tag = "SiPlotly"


class SiPluralsight(rx.Component):
    library = "react-icons/si"
    tag = "SiPluralsight"


class SiPlurk(rx.Component):
    library = "react-icons/si"
    tag = "SiPlurk"


class SiPluscodes(rx.Component):
    library = "react-icons/si"
    tag = "SiPluscodes"


class SiPm2(rx.Component):
    library = "react-icons/si"
    tag = "SiPm2"


class SiPnpm(rx.Component):
    library = "react-icons/si"
    tag = "SiPnpm"


class SiPocket(rx.Component):
    library = "react-icons/si"
    tag = "SiPocket"


class SiPocketbase(rx.Component):
    library = "react-icons/si"
    tag = "SiPocketbase"


class SiPocketcasts(rx.Component):
    library = "react-icons/si"
    tag = "SiPocketcasts"


class SiPodcastaddict(rx.Component):
    library = "react-icons/si"
    tag = "SiPodcastaddict"


class SiPodman(rx.Component):
    library = "react-icons/si"
    tag = "SiPodman"


class SiPoe(rx.Component):
    library = "react-icons/si"
    tag = "SiPoe"


class SiPoetry(rx.Component):
    library = "react-icons/si"
    tag = "SiPoetry"


class SiPointy(rx.Component):
    library = "react-icons/si"
    tag = "SiPointy"


class SiPokemon(rx.Component):
    library = "react-icons/si"
    tag = "SiPokemon"


class SiPolars(rx.Component):
    library = "react-icons/si"
    tag = "SiPolars"


class SiPolkadot(rx.Component):
    library = "react-icons/si"
    tag = "SiPolkadot"


class SiPoly(rx.Component):
    library = "react-icons/si"
    tag = "SiPoly"


class SiPolymerproject(rx.Component):
    library = "react-icons/si"
    tag = "SiPolymerproject"


class SiPolywork(rx.Component):
    library = "react-icons/si"
    tag = "SiPolywork"


class SiPopos(rx.Component):
    library = "react-icons/si"
    tag = "SiPopos"


class SiPorsche(rx.Component):
    library = "react-icons/si"
    tag = "SiPorsche"


class SiPortainer(rx.Component):
    library = "react-icons/si"
    tag = "SiPortainer"


class SiPostcss(rx.Component):
    library = "react-icons/si"
    tag = "SiPostcss"


class SiPostgresql(rx.Component):
    library = "react-icons/si"
    tag = "SiPostgresql"


class SiPostman(rx.Component):
    library = "react-icons/si"
    tag = "SiPostman"


class SiPostmates(rx.Component):
    library = "react-icons/si"
    tag = "SiPostmates"


class SiPowerapps(rx.Component):
    library = "react-icons/si"
    tag = "SiPowerapps"


class SiPowerautomate(rx.Component):
    library = "react-icons/si"
    tag = "SiPowerautomate"


class SiPowerbi(rx.Component):
    library = "react-icons/si"
    tag = "SiPowerbi"


class SiPowerfx(rx.Component):
    library = "react-icons/si"
    tag = "SiPowerfx"


class SiPowerpages(rx.Component):
    library = "react-icons/si"
    tag = "SiPowerpages"


class SiPowers(rx.Component):
    library = "react-icons/si"
    tag = "SiPowers"


class SiPowershell(rx.Component):
    library = "react-icons/si"
    tag = "SiPowershell"


class SiPowervirtualagents(rx.Component):
    library = "react-icons/si"
    tag = "SiPowervirtualagents"


class SiPrdotco(rx.Component):
    library = "react-icons/si"
    tag = "SiPrdotco"


class SiPreact(rx.Component):
    library = "react-icons/si"
    tag = "SiPreact"


class SiPrecommit(rx.Component):
    library = "react-icons/si"
    tag = "SiPrecommit"


class SiPremierleague(rx.Component):
    library = "react-icons/si"
    tag = "SiPremierleague"


class SiPrestashop(rx.Component):
    library = "react-icons/si"
    tag = "SiPrestashop"


class SiPresto(rx.Component):
    library = "react-icons/si"
    tag = "SiPresto"


class SiPrettier(rx.Component):
    library = "react-icons/si"
    tag = "SiPrettier"


class SiPrevention(rx.Component):
    library = "react-icons/si"
    tag = "SiPrevention"


class SiPrezi(rx.Component):
    library = "react-icons/si"
    tag = "SiPrezi"


class SiPrime(rx.Component):
    library = "react-icons/si"
    tag = "SiPrime"


class SiPrimevideo(rx.Component):
    library = "react-icons/si"
    tag = "SiPrimevideo"


class SiPrintables(rx.Component):
    library = "react-icons/si"
    tag = "SiPrintables"


class SiPrisma(rx.Component):
    library = "react-icons/si"
    tag = "SiPrisma"


class SiPrismic(rx.Component):
    library = "react-icons/si"
    tag = "SiPrismic"


class SiPrivateinternetaccess(rx.Component):
    library = "react-icons/si"
    tag = "SiPrivateinternetaccess"


class SiProbot(rx.Component):
    library = "react-icons/si"
    tag = "SiProbot"


class SiProcessingfoundation(rx.Component):
    library = "react-icons/si"
    tag = "SiProcessingfoundation"


class SiProcesswire(rx.Component):
    library = "react-icons/si"
    tag = "SiProcesswire"


class SiProducthunt(rx.Component):
    library = "react-icons/si"
    tag = "SiProducthunt"


class SiProgate(rx.Component):
    library = "react-icons/si"
    tag = "SiProgate"


class SiProgress(rx.Component):
    library = "react-icons/si"
    tag = "SiProgress"


class SiPrometheus(rx.Component):
    library = "react-icons/si"
    tag = "SiPrometheus"


class SiProsieben(rx.Component):
    library = "react-icons/si"
    tag = "SiProsieben"


class SiProtocolsdotio(rx.Component):
    library = "react-icons/si"
    tag = "SiProtocolsdotio"


class SiProtodotio(rx.Component):
    library = "react-icons/si"
    tag = "SiProtodotio"


class SiProtondb(rx.Component):
    library = "react-icons/si"
    tag = "SiProtondb"


class SiProtonmail(rx.Component):
    library = "react-icons/si"
    tag = "SiProtonmail"


class SiProtonvpn(rx.Component):
    library = "react-icons/si"
    tag = "SiProtonvpn"


class SiProtools(rx.Component):
    library = "react-icons/si"
    tag = "SiProtools"


class SiProtractor(rx.Component):
    library = "react-icons/si"
    tag = "SiProtractor"


class SiProxmox(rx.Component):
    library = "react-icons/si"
    tag = "SiProxmox"


class SiPubg(rx.Component):
    library = "react-icons/si"
    tag = "SiPubg"


class SiPublons(rx.Component):
    library = "react-icons/si"
    tag = "SiPublons"


class SiPubmed(rx.Component):
    library = "react-icons/si"
    tag = "SiPubmed"


class SiPug(rx.Component):
    library = "react-icons/si"
    tag = "SiPug"


class SiPulumi(rx.Component):
    library = "react-icons/si"
    tag = "SiPulumi"


class SiPuma(rx.Component):
    library = "react-icons/si"
    tag = "SiPuma"


class SiPuppet(rx.Component):
    library = "react-icons/si"
    tag = "SiPuppet"


class SiPuppeteer(rx.Component):
    library = "react-icons/si"
    tag = "SiPuppeteer"


class SiPurescript(rx.Component):
    library = "react-icons/si"
    tag = "SiPurescript"


class SiPurgecss(rx.Component):
    library = "react-icons/si"
    tag = "SiPurgecss"


class SiPurism(rx.Component):
    library = "react-icons/si"
    tag = "SiPurism"


class SiPusher(rx.Component):
    library = "react-icons/si"
    tag = "SiPusher"


class SiPwa(rx.Component):
    library = "react-icons/si"
    tag = "SiPwa"


class SiPycharm(rx.Component):
    library = "react-icons/si"
    tag = "SiPycharm"


class SiPyg(rx.Component):
    library = "react-icons/si"
    tag = "SiPyg"


class SiPypi(rx.Component):
    library = "react-icons/si"
    tag = "SiPypi"


class SiPypy(rx.Component):
    library = "react-icons/si"
    tag = "SiPypy"


class SiPyscaffold(rx.Component):
    library = "react-icons/si"
    tag = "SiPyscaffold"


class SiPysyft(rx.Component):
    library = "react-icons/si"
    tag = "SiPysyft"


class SiPytest(rx.Component):
    library = "react-icons/si"
    tag = "SiPytest"


class SiPython(rx.Component):
    library = "react-icons/si"
    tag = "SiPython"


class SiPytorch(rx.Component):
    library = "react-icons/si"
    tag = "SiPytorch"


class SiPyup(rx.Component):
    library = "react-icons/si"
    tag = "SiPyup"


class SiQantas(rx.Component):
    library = "react-icons/si"
    tag = "SiQantas"


class SiQatarairways(rx.Component):
    library = "react-icons/si"
    tag = "SiQatarairways"


class SiQemu(rx.Component):
    library = "react-icons/si"
    tag = "SiQemu"


class SiQgis(rx.Component):
    library = "react-icons/si"
    tag = "SiQgis"


class SiQi(rx.Component):
    library = "react-icons/si"
    tag = "SiQi"


class SiQiita(rx.Component):
    library = "react-icons/si"
    tag = "SiQiita"


class SiQiskit(rx.Component):
    library = "react-icons/si"
    tag = "SiQiskit"


class SiQiwi(rx.Component):
    library = "react-icons/si"
    tag = "SiQiwi"


class SiQmk(rx.Component):
    library = "react-icons/si"
    tag = "SiQmk"


class SiQt(rx.Component):
    library = "react-icons/si"
    tag = "SiQt"


class SiQualcomm(rx.Component):
    library = "react-icons/si"
    tag = "SiQualcomm"


class SiQualtrics(rx.Component):
    library = "react-icons/si"
    tag = "SiQualtrics"


class SiQualys(rx.Component):
    library = "react-icons/si"
    tag = "SiQualys"


class SiQuantcast(rx.Component):
    library = "react-icons/si"
    tag = "SiQuantcast"


class SiQuantconnect(rx.Component):
    library = "react-icons/si"
    tag = "SiQuantconnect"


class SiQuarkus(rx.Component):
    library = "react-icons/si"
    tag = "SiQuarkus"


class SiQuasar(rx.Component):
    library = "react-icons/si"
    tag = "SiQuasar"


class SiQubesos(rx.Component):
    library = "react-icons/si"
    tag = "SiQubesos"


class SiQuest(rx.Component):
    library = "react-icons/si"
    tag = "SiQuest"


class SiQuickbooks(rx.Component):
    library = "react-icons/si"
    tag = "SiQuickbooks"


class SiQuicklook(rx.Component):
    library = "react-icons/si"
    tag = "SiQuicklook"


class SiQuicktime(rx.Component):
    library = "react-icons/si"
    tag = "SiQuicktime"


class SiQuip(rx.Component):
    library = "react-icons/si"
    tag = "SiQuip"


class SiQuora(rx.Component):
    library = "react-icons/si"
    tag = "SiQuora"


class SiQwiklabs(rx.Component):
    library = "react-icons/si"
    tag = "SiQwiklabs"


class SiQzone(rx.Component):
    library = "react-icons/si"
    tag = "SiQzone"


class SiR(rx.Component):
    library = "react-icons/si"
    tag = "SiR"


class SiR3(rx.Component):
    library = "react-icons/si"
    tag = "SiR3"


class SiRabbitmq(rx.Component):
    library = "react-icons/si"
    tag = "SiRabbitmq"


class SiRacket(rx.Component):
    library = "react-icons/si"
    tag = "SiRacket"


class SiRadar(rx.Component):
    library = "react-icons/si"
    tag = "SiRadar"


class SiRadiopublic(rx.Component):
    library = "react-icons/si"
    tag = "SiRadiopublic"


class SiRailway(rx.Component):
    library = "react-icons/si"
    tag = "SiRailway"


class SiRainmeter(rx.Component):
    library = "react-icons/si"
    tag = "SiRainmeter"


class SiRakuten(rx.Component):
    library = "react-icons/si"
    tag = "SiRakuten"


class SiRam(rx.Component):
    library = "react-icons/si"
    tag = "SiRam"


class SiRancher(rx.Component):
    library = "react-icons/si"
    tag = "SiRancher"


class SiRarible(rx.Component):
    library = "react-icons/si"
    tag = "SiRarible"


class SiRasa(rx.Component):
    library = "react-icons/si"
    tag = "SiRasa"


class SiRaspberrypi(rx.Component):
    library = "react-icons/si"
    tag = "SiRaspberrypi"


class SiRavelry(rx.Component):
    library = "react-icons/si"
    tag = "SiRavelry"


class SiRay(rx.Component):
    library = "react-icons/si"
    tag = "SiRay"


class SiRazer(rx.Component):
    library = "react-icons/si"
    tag = "SiRazer"


class SiRazorpay(rx.Component):
    library = "react-icons/si"
    tag = "SiRazorpay"


class SiReact(rx.Component):
    library = "react-icons/si"
    tag = "SiReact"


class SiReacthookform(rx.Component):
    library = "react-icons/si"
    tag = "SiReacthookform"


class SiReactivex(rx.Component):
    library = "react-icons/si"
    tag = "SiReactivex"


class SiReactos(rx.Component):
    library = "react-icons/si"
    tag = "SiReactos"


class SiReactquery(rx.Component):
    library = "react-icons/si"
    tag = "SiReactquery"


class SiReactrouter(rx.Component):
    library = "react-icons/si"
    tag = "SiReactrouter"


class SiReacttable(rx.Component):
    library = "react-icons/si"
    tag = "SiReacttable"


class SiReadme(rx.Component):
    library = "react-icons/si"
    tag = "SiReadme"


class SiReadthedocs(rx.Component):
    library = "react-icons/si"
    tag = "SiReadthedocs"


class SiRealm(rx.Component):
    library = "react-icons/si"
    tag = "SiRealm"


class SiReason(rx.Component):
    library = "react-icons/si"
    tag = "SiReason"


class SiReasonstudios(rx.Component):
    library = "react-icons/si"
    tag = "SiReasonstudios"


class SiRed(rx.Component):
    library = "react-icons/si"
    tag = "SiRed"


class SiRedbubble(rx.Component):
    library = "react-icons/si"
    tag = "SiRedbubble"


class SiReddit(rx.Component):
    library = "react-icons/si"
    tag = "SiReddit"


class SiRedhat(rx.Component):
    library = "react-icons/si"
    tag = "SiRedhat"


class SiRedhatopenshift(rx.Component):
    library = "react-icons/si"
    tag = "SiRedhatopenshift"


class SiRedis(rx.Component):
    library = "react-icons/si"
    tag = "SiRedis"


class SiRedmine(rx.Component):
    library = "react-icons/si"
    tag = "SiRedmine"


class SiRedox(rx.Component):
    library = "react-icons/si"
    tag = "SiRedox"


class SiRedux(rx.Component):
    library = "react-icons/si"
    tag = "SiRedux"


class SiReduxsaga(rx.Component):
    library = "react-icons/si"
    tag = "SiReduxsaga"


class SiRedwoodjs(rx.Component):
    library = "react-icons/si"
    tag = "SiRedwoodjs"


class SiReebok(rx.Component):
    library = "react-icons/si"
    tag = "SiReebok"


class SiRelay(rx.Component):
    library = "react-icons/si"
    tag = "SiRelay"


class SiRelianceindustrieslimited(rx.Component):
    library = "react-icons/si"
    tag = "SiRelianceindustrieslimited"


class SiRemix(rx.Component):
    library = "react-icons/si"
    tag = "SiRemix"


class SiRenault(rx.Component):
    library = "react-icons/si"
    tag = "SiRenault"


class SiRender(rx.Component):
    library = "react-icons/si"
    tag = "SiRender"


class SiRenovatebot(rx.Component):
    library = "react-icons/si"
    tag = "SiRenovatebot"


class SiRenpy(rx.Component):
    library = "react-icons/si"
    tag = "SiRenpy"


class SiRenren(rx.Component):
    library = "react-icons/si"
    tag = "SiRenren"


class SiReplit(rx.Component):
    library = "react-icons/si"
    tag = "SiReplit"


class SiRepublicofgamers(rx.Component):
    library = "react-icons/si"
    tag = "SiRepublicofgamers"


class SiRescript(rx.Component):
    library = "react-icons/si"
    tag = "SiRescript"


class SiRescuetime(rx.Component):
    library = "react-icons/si"
    tag = "SiRescuetime"


class SiResearchgate(rx.Component):
    library = "react-icons/si"
    tag = "SiResearchgate"


class SiResharper(rx.Component):
    library = "react-icons/si"
    tag = "SiResharper"


class SiResurrectionremixos(rx.Component):
    library = "react-icons/si"
    tag = "SiResurrectionremixos"


class SiRetroarch(rx.Component):
    library = "react-icons/si"
    tag = "SiRetroarch"


class SiRetropie(rx.Component):
    library = "react-icons/si"
    tag = "SiRetropie"


class SiRevealdotjs(rx.Component):
    library = "react-icons/si"
    tag = "SiRevealdotjs"


class SiReverbnation(rx.Component):
    library = "react-icons/si"
    tag = "SiReverbnation"


class SiRevoltdotchat(rx.Component):
    library = "react-icons/si"
    tag = "SiRevoltdotchat"


class SiRevolut(rx.Component):
    library = "react-icons/si"
    tag = "SiRevolut"


class SiRevue(rx.Component):
    library = "react-icons/si"
    tag = "SiRevue"


class SiRewe(rx.Component):
    library = "react-icons/si"
    tag = "SiRewe"


class SiRezgo(rx.Component):
    library = "react-icons/si"
    tag = "SiRezgo"


class SiRhinoceros(rx.Component):
    library = "react-icons/si"
    tag = "SiRhinoceros"


class SiRider(rx.Component):
    library = "react-icons/si"
    tag = "SiRider"


class SiRimacautomobili(rx.Component):
    library = "react-icons/si"
    tag = "SiRimacautomobili"


class SiRing(rx.Component):
    library = "react-icons/si"
    tag = "SiRing"


class SiRiotgames(rx.Component):
    library = "react-icons/si"
    tag = "SiRiotgames"


class SiRipple(rx.Component):
    library = "react-icons/si"
    tag = "SiRipple"


class SiRiseup(rx.Component):
    library = "react-icons/si"
    tag = "SiRiseup"


class SiRoamresearch(rx.Component):
    library = "react-icons/si"
    tag = "SiRoamresearch"


class SiRoblox(rx.Component):
    library = "react-icons/si"
    tag = "SiRoblox"


class SiRobloxstudio(rx.Component):
    library = "react-icons/si"
    tag = "SiRobloxstudio"


class SiRobotframework(rx.Component):
    library = "react-icons/si"
    tag = "SiRobotframework"


class SiRocketdotchat(rx.Component):
    library = "react-icons/si"
    tag = "SiRocketdotchat"


class SiRocksdb(rx.Component):
    library = "react-icons/si"
    tag = "SiRocksdb"


class SiRockylinux(rx.Component):
    library = "react-icons/si"
    tag = "SiRockylinux"


class SiRoku(rx.Component):
    library = "react-icons/si"
    tag = "SiRoku"


class SiRollsroyce(rx.Component):
    library = "react-icons/si"
    tag = "SiRollsroyce"


class SiRollupdotjs(rx.Component):
    library = "react-icons/si"
    tag = "SiRollupdotjs"


class SiRome(rx.Component):
    library = "react-icons/si"
    tag = "SiRome"


class SiRoots(rx.Component):
    library = "react-icons/si"
    tag = "SiRoots"


class SiRootsbedrock(rx.Component):
    library = "react-icons/si"
    tag = "SiRootsbedrock"


class SiRootssage(rx.Component):
    library = "react-icons/si"
    tag = "SiRootssage"


class SiRos(rx.Component):
    library = "react-icons/si"
    tag = "SiRos"


class SiRossmann(rx.Component):
    library = "react-icons/si"
    tag = "SiRossmann"


class SiRotaryinternational(rx.Component):
    library = "react-icons/si"
    tag = "SiRotaryinternational"


class SiRottentomatoes(rx.Component):
    library = "react-icons/si"
    tag = "SiRottentomatoes"


class SiRoundcube(rx.Component):
    library = "react-icons/si"
    tag = "SiRoundcube"


class SiRsocket(rx.Component):
    library = "react-icons/si"
    tag = "SiRsocket"


class SiRss(rx.Component):
    library = "react-icons/si"
    tag = "SiRss"


class SiRstudio(rx.Component):
    library = "react-icons/si"
    tag = "SiRstudio"


class SiRte(rx.Component):
    library = "react-icons/si"
    tag = "SiRte"


class SiRtl(rx.Component):
    library = "react-icons/si"
    tag = "SiRtl"


class SiRtlzwei(rx.Component):
    library = "react-icons/si"
    tag = "SiRtlzwei"


class SiRubocop(rx.Component):
    library = "react-icons/si"
    tag = "SiRubocop"


class SiRuby(rx.Component):
    library = "react-icons/si"
    tag = "SiRuby"


class SiRubygems(rx.Component):
    library = "react-icons/si"
    tag = "SiRubygems"


class SiRubyonrails(rx.Component):
    library = "react-icons/si"
    tag = "SiRubyonrails"


class SiRubysinatra(rx.Component):
    library = "react-icons/si"
    tag = "SiRubysinatra"


class SiRuff(rx.Component):
    library = "react-icons/si"
    tag = "SiRuff"


class SiRunkeeper(rx.Component):
    library = "react-icons/si"
    tag = "SiRunkeeper"


class SiRunkit(rx.Component):
    library = "react-icons/si"
    tag = "SiRunkit"


class SiRust(rx.Component):
    library = "react-icons/si"
    tag = "SiRust"


class SiRxdb(rx.Component):
    library = "react-icons/si"
    tag = "SiRxdb"


class SiRyanair(rx.Component):
    library = "react-icons/si"
    tag = "SiRyanair"


class SiS7Airlines(rx.Component):
    library = "react-icons/si"
    tag = "SiS7Airlines"


class SiSabanci(rx.Component):
    library = "react-icons/si"
    tag = "SiSabanci"


class SiSafari(rx.Component):
    library = "react-icons/si"
    tag = "SiSafari"


class SiSahibinden(rx.Component):
    library = "react-icons/si"
    tag = "SiSahibinden"


class SiSailfishos(rx.Component):
    library = "react-icons/si"
    tag = "SiSailfishos"


class SiSalesforce(rx.Component):
    library = "react-icons/si"
    tag = "SiSalesforce"


class SiSaltproject(rx.Component):
    library = "react-icons/si"
    tag = "SiSaltproject"


class SiSamsung(rx.Component):
    library = "react-icons/si"
    tag = "SiSamsung"


class SiSamsungpay(rx.Component):
    library = "react-icons/si"
    tag = "SiSamsungpay"


class SiSandisk(rx.Component):
    library = "react-icons/si"
    tag = "SiSandisk"


class SiSanfranciscomunicipalrailway(rx.Component):
    library = "react-icons/si"
    tag = "SiSanfranciscomunicipalrailway"


class SiSaopaulometro(rx.Component):
    library = "react-icons/si"
    tag = "SiSaopaulometro"


class SiSap(rx.Component):
    library = "react-icons/si"
    tag = "SiSap"


class SiSass(rx.Component):
    library = "react-icons/si"
    tag = "SiSass"


class SiSat1(rx.Component):
    library = "react-icons/si"
    tag = "SiSat1"


class SiSaturn(rx.Component):
    library = "react-icons/si"
    tag = "SiSaturn"


class SiSaucelabs(rx.Component):
    library = "react-icons/si"
    tag = "SiSaucelabs"


class SiScala(rx.Component):
    library = "react-icons/si"
    tag = "SiScala"


class SiScaleway(rx.Component):
    library = "react-icons/si"
    tag = "SiScaleway"


class SiScania(rx.Component):
    library = "react-icons/si"
    tag = "SiScania"


class SiSchneiderelectric(rx.Component):
    library = "react-icons/si"
    tag = "SiSchneiderelectric"


class SiScikitlearn(rx.Component):
    library = "react-icons/si"
    tag = "SiScikitlearn"


class SiScipy(rx.Component):
    library = "react-icons/si"
    tag = "SiScipy"


class SiScopus(rx.Component):
    library = "react-icons/si"
    tag = "SiScopus"


class SiScpfoundation(rx.Component):
    library = "react-icons/si"
    tag = "SiScpfoundation"


class SiScratch(rx.Component):
    library = "react-icons/si"
    tag = "SiScratch"


class SiScreencastify(rx.Component):
    library = "react-icons/si"
    tag = "SiScreencastify"


class SiScribd(rx.Component):
    library = "react-icons/si"
    tag = "SiScribd"


class SiScrimba(rx.Component):
    library = "react-icons/si"
    tag = "SiScrimba"


class SiScrollreveal(rx.Component):
    library = "react-icons/si"
    tag = "SiScrollreveal"


class SiScrumalliance(rx.Component):
    library = "react-icons/si"
    tag = "SiScrumalliance"


class SiScrutinizerci(rx.Component):
    library = "react-icons/si"
    tag = "SiScrutinizerci"


class SiSeagate(rx.Component):
    library = "react-icons/si"
    tag = "SiSeagate"


class SiSeat(rx.Component):
    library = "react-icons/si"
    tag = "SiSeat"


class SiSecurityscorecard(rx.Component):
    library = "react-icons/si"
    tag = "SiSecurityscorecard"


class SiSefaria(rx.Component):
    library = "react-icons/si"
    tag = "SiSefaria"


class SiSega(rx.Component):
    library = "react-icons/si"
    tag = "SiSega"


class SiSelenium(rx.Component):
    library = "react-icons/si"
    tag = "SiSelenium"


class SiSellfy(rx.Component):
    library = "react-icons/si"
    tag = "SiSellfy"


class SiSemanticrelease(rx.Component):
    library = "react-icons/si"
    tag = "SiSemanticrelease"


class SiSemanticscholar(rx.Component):
    library = "react-icons/si"
    tag = "SiSemanticscholar"


class SiSemanticuireact(rx.Component):
    library = "react-icons/si"
    tag = "SiSemanticuireact"


class SiSemanticweb(rx.Component):
    library = "react-icons/si"
    tag = "SiSemanticweb"


class SiSemaphoreci(rx.Component):
    library = "react-icons/si"
    tag = "SiSemaphoreci"


class SiSemver(rx.Component):
    library = "react-icons/si"
    tag = "SiSemver"


class SiSencha(rx.Component):
    library = "react-icons/si"
    tag = "SiSencha"


class SiSendinblue(rx.Component):
    library = "react-icons/si"
    tag = "SiSendinblue"


class SiSennheiser(rx.Component):
    library = "react-icons/si"
    tag = "SiSennheiser"


class SiSensu(rx.Component):
    library = "react-icons/si"
    tag = "SiSensu"


class SiSentry(rx.Component):
    library = "react-icons/si"
    tag = "SiSentry"


class SiSepa(rx.Component):
    library = "react-icons/si"
    tag = "SiSepa"


class SiSequelize(rx.Component):
    library = "react-icons/si"
    tag = "SiSequelize"


class SiServerfault(rx.Component):
    library = "react-icons/si"
    tag = "SiServerfault"


class SiServerless(rx.Component):
    library = "react-icons/si"
    tag = "SiServerless"


class SiSessionize(rx.Component):
    library = "react-icons/si"
    tag = "SiSessionize"


class SiSetapp(rx.Component):
    library = "react-icons/si"
    tag = "SiSetapp"


class SiSfml(rx.Component):
    library = "react-icons/si"
    tag = "SiSfml"


class SiShadow(rx.Component):
    library = "react-icons/si"
    tag = "SiShadow"


class SiShanghaimetro(rx.Component):
    library = "react-icons/si"
    tag = "SiShanghaimetro"


class SiSharp(rx.Component):
    library = "react-icons/si"
    tag = "SiSharp"


class SiShazam(rx.Component):
    library = "react-icons/si"
    tag = "SiShazam"


class SiShell(rx.Component):
    library = "react-icons/si"
    tag = "SiShell"


class SiShelly(rx.Component):
    library = "react-icons/si"
    tag = "SiShelly"


class SiShenzhenmetro(rx.Component):
    library = "react-icons/si"
    tag = "SiShenzhenmetro"


class SiShieldsdotio(rx.Component):
    library = "react-icons/si"
    tag = "SiShieldsdotio"


class SiShikimori(rx.Component):
    library = "react-icons/si"
    tag = "SiShikimori"


class SiShopee(rx.Component):
    library = "react-icons/si"
    tag = "SiShopee"


class SiShopify(rx.Component):
    library = "react-icons/si"
    tag = "SiShopify"


class SiShopware(rx.Component):
    library = "react-icons/si"
    tag = "SiShopware"


class SiShotcut(rx.Component):
    library = "react-icons/si"
    tag = "SiShotcut"


class SiShowpad(rx.Component):
    library = "react-icons/si"
    tag = "SiShowpad"


class SiShowtime(rx.Component):
    library = "react-icons/si"
    tag = "SiShowtime"


class SiShutterstock(rx.Component):
    library = "react-icons/si"
    tag = "SiShutterstock"


class SiSiemens(rx.Component):
    library = "react-icons/si"
    tag = "SiSiemens"


class SiSignal(rx.Component):
    library = "react-icons/si"
    tag = "SiSignal"


class SiSimilarweb(rx.Component):
    library = "react-icons/si"
    tag = "SiSimilarweb"


class SiSimkl(rx.Component):
    library = "react-icons/si"
    tag = "SiSimkl"


class SiSimpleanalytics(rx.Component):
    library = "react-icons/si"
    tag = "SiSimpleanalytics"


class SiSimpleicons(rx.Component):
    library = "react-icons/si"
    tag = "SiSimpleicons"


class SiSimplenote(rx.Component):
    library = "react-icons/si"
    tag = "SiSimplenote"


class SiSinaweibo(rx.Component):
    library = "react-icons/si"
    tag = "SiSinaweibo"


class SiSinglestore(rx.Component):
    library = "react-icons/si"
    tag = "SiSinglestore"


class SiSitepoint(rx.Component):
    library = "react-icons/si"
    tag = "SiSitepoint"


class SiSketch(rx.Component):
    library = "react-icons/si"
    tag = "SiSketch"


class SiSketchfab(rx.Component):
    library = "react-icons/si"
    tag = "SiSketchfab"


class SiSketchup(rx.Component):
    library = "react-icons/si"
    tag = "SiSketchup"


class SiSkillshare(rx.Component):
    library = "react-icons/si"
    tag = "SiSkillshare"


class SiSkoda(rx.Component):
    library = "react-icons/si"
    tag = "SiSkoda"


class SiSky(rx.Component):
    library = "react-icons/si"
    tag = "SiSky"


class SiSkynet(rx.Component):
    library = "react-icons/si"
    tag = "SiSkynet"


class SiSkypack(rx.Component):
    library = "react-icons/si"
    tag = "SiSkypack"


class SiSkype(rx.Component):
    library = "react-icons/si"
    tag = "SiSkype"


class SiSkypeforbusiness(rx.Component):
    library = "react-icons/si"
    tag = "SiSkypeforbusiness"


class SiSlack(rx.Component):
    library = "react-icons/si"
    tag = "SiSlack"


class SiSlackware(rx.Component):
    library = "react-icons/si"
    tag = "SiSlackware"


class SiSlashdot(rx.Component):
    library = "react-icons/si"
    tag = "SiSlashdot"


class SiSlickpic(rx.Component):
    library = "react-icons/si"
    tag = "SiSlickpic"


class SiSlides(rx.Component):
    library = "react-icons/si"
    tag = "SiSlides"


class SiSlideshare(rx.Component):
    library = "react-icons/si"
    tag = "SiSlideshare"


class SiSmart(rx.Component):
    library = "react-icons/si"
    tag = "SiSmart"


class SiSmartthings(rx.Component):
    library = "react-icons/si"
    tag = "SiSmartthings"


class SiSmashdotgg(rx.Component):
    library = "react-icons/si"
    tag = "SiSmashdotgg"


class SiSmashingmagazine(rx.Component):
    library = "react-icons/si"
    tag = "SiSmashingmagazine"


class SiSmrt(rx.Component):
    library = "react-icons/si"
    tag = "SiSmrt"


class SiSmugmug(rx.Component):
    library = "react-icons/si"
    tag = "SiSmugmug"


class SiSnapchat(rx.Component):
    library = "react-icons/si"
    tag = "SiSnapchat"


class SiSnapcraft(rx.Component):
    library = "react-icons/si"
    tag = "SiSnapcraft"


class SiSncf(rx.Component):
    library = "react-icons/si"
    tag = "SiSncf"


class SiSnowflake(rx.Component):
    library = "react-icons/si"
    tag = "SiSnowflake"


class SiSnowpack(rx.Component):
    library = "react-icons/si"
    tag = "SiSnowpack"


class SiSnyk(rx.Component):
    library = "react-icons/si"
    tag = "SiSnyk"


class SiSocialblade(rx.Component):
    library = "react-icons/si"
    tag = "SiSocialblade"


class SiSociety6(rx.Component):
    library = "react-icons/si"
    tag = "SiSociety6"


class SiSocketdotio(rx.Component):
    library = "react-icons/si"
    tag = "SiSocketdotio"


class SiSogou(rx.Component):
    library = "react-icons/si"
    tag = "SiSogou"


class SiSolid(rx.Component):
    library = "react-icons/si"
    tag = "SiSolid"


class SiSolidity(rx.Component):
    library = "react-icons/si"
    tag = "SiSolidity"


class SiSololearn(rx.Component):
    library = "react-icons/si"
    tag = "SiSololearn"


class SiSolus(rx.Component):
    library = "react-icons/si"
    tag = "SiSolus"


class SiSonar(rx.Component):
    library = "react-icons/si"
    tag = "SiSonar"


class SiSonarcloud(rx.Component):
    library = "react-icons/si"
    tag = "SiSonarcloud"


class SiSonarlint(rx.Component):
    library = "react-icons/si"
    tag = "SiSonarlint"


class SiSonarqube(rx.Component):
    library = "react-icons/si"
    tag = "SiSonarqube"


class SiSonarsource(rx.Component):
    library = "react-icons/si"
    tag = "SiSonarsource"


class SiSongkick(rx.Component):
    library = "react-icons/si"
    tag = "SiSongkick"


class SiSongoda(rx.Component):
    library = "react-icons/si"
    tag = "SiSongoda"


class SiSonicwall(rx.Component):
    library = "react-icons/si"
    tag = "SiSonicwall"


class SiSonos(rx.Component):
    library = "react-icons/si"
    tag = "SiSonos"


class SiSony(rx.Component):
    library = "react-icons/si"
    tag = "SiSony"


class SiSoundcharts(rx.Component):
    library = "react-icons/si"
    tag = "SiSoundcharts"


class SiSoundcloud(rx.Component):
    library = "react-icons/si"
    tag = "SiSoundcloud"


class SiSourceengine(rx.Component):
    library = "react-icons/si"
    tag = "SiSourceengine"


class SiSourceforge(rx.Component):
    library = "react-icons/si"
    tag = "SiSourceforge"


class SiSourcegraph(rx.Component):
    library = "react-icons/si"
    tag = "SiSourcegraph"


class SiSourcetree(rx.Component):
    library = "react-icons/si"
    tag = "SiSourcetree"


class SiSouthwestairlines(rx.Component):
    library = "react-icons/si"
    tag = "SiSouthwestairlines"


class SiSpacemacs(rx.Component):
    library = "react-icons/si"
    tag = "SiSpacemacs"


class SiSpacex(rx.Component):
    library = "react-icons/si"
    tag = "SiSpacex"


class SiSpacy(rx.Component):
    library = "react-icons/si"
    tag = "SiSpacy"


class SiSparkar(rx.Component):
    library = "react-icons/si"
    tag = "SiSparkar"


class SiSparkasse(rx.Component):
    library = "react-icons/si"
    tag = "SiSparkasse"


class SiSparkfun(rx.Component):
    library = "react-icons/si"
    tag = "SiSparkfun"


class SiSparkpost(rx.Component):
    library = "react-icons/si"
    tag = "SiSparkpost"


class SiSpdx(rx.Component):
    library = "react-icons/si"
    tag = "SiSpdx"


class SiSpeakerdeck(rx.Component):
    library = "react-icons/si"
    tag = "SiSpeakerdeck"


class SiSpectrum(rx.Component):
    library = "react-icons/si"
    tag = "SiSpectrum"


class SiSpeedtest(rx.Component):
    library = "react-icons/si"
    tag = "SiSpeedtest"


class SiSpinnaker(rx.Component):
    library = "react-icons/si"
    tag = "SiSpinnaker"


class SiSpinrilla(rx.Component):
    library = "react-icons/si"
    tag = "SiSpinrilla"


class SiSplunk(rx.Component):
    library = "react-icons/si"
    tag = "SiSplunk"


class SiSpond(rx.Component):
    library = "react-icons/si"
    tag = "SiSpond"


class SiSpotify(rx.Component):
    library = "react-icons/si"
    tag = "SiSpotify"


class SiSpotlight(rx.Component):
    library = "react-icons/si"
    tag = "SiSpotlight"


class SiSpreadshirt(rx.Component):
    library = "react-icons/si"
    tag = "SiSpreadshirt"


class SiSpreaker(rx.Component):
    library = "react-icons/si"
    tag = "SiSpreaker"


class SiSpringCreators(rx.Component):
    library = "react-icons/si"
    tag = "SiSpringCreators"


class SiSpring(rx.Component):
    library = "react-icons/si"
    tag = "SiSpring"


class SiSpringboot(rx.Component):
    library = "react-icons/si"
    tag = "SiSpringboot"


class SiSpringsecurity(rx.Component):
    library = "react-icons/si"
    tag = "SiSpringsecurity"


class SiSpyderide(rx.Component):
    library = "react-icons/si"
    tag = "SiSpyderide"


class SiSqlite(rx.Component):
    library = "react-icons/si"
    tag = "SiSqlite"


class SiSquare(rx.Component):
    library = "react-icons/si"
    tag = "SiSquare"


class SiSquareenix(rx.Component):
    library = "react-icons/si"
    tag = "SiSquareenix"


class SiSquarespace(rx.Component):
    library = "react-icons/si"
    tag = "SiSquarespace"


class SiSsrn(rx.Component):
    library = "react-icons/si"
    tag = "SiSsrn"


class SiStackbit(rx.Component):
    library = "react-icons/si"
    tag = "SiStackbit"


class SiStackblitz(rx.Component):
    library = "react-icons/si"
    tag = "SiStackblitz"


class SiStackedit(rx.Component):
    library = "react-icons/si"
    tag = "SiStackedit"


class SiStackexchange(rx.Component):
    library = "react-icons/si"
    tag = "SiStackexchange"


class SiStackhawk(rx.Component):
    library = "react-icons/si"
    tag = "SiStackhawk"


class SiStackoverflow(rx.Component):
    library = "react-icons/si"
    tag = "SiStackoverflow"


class SiStackpath(rx.Component):
    library = "react-icons/si"
    tag = "SiStackpath"


class SiStackshare(rx.Component):
    library = "react-icons/si"
    tag = "SiStackshare"


class SiStadia(rx.Component):
    library = "react-icons/si"
    tag = "SiStadia"


class SiStaffbase(rx.Component):
    library = "react-icons/si"
    tag = "SiStaffbase"


class SiStandardjs(rx.Component):
    library = "react-icons/si"
    tag = "SiStandardjs"


class SiStarbucks(rx.Component):
    library = "react-icons/si"
    tag = "SiStarbucks"


class SiStardock(rx.Component):
    library = "react-icons/si"
    tag = "SiStardock"


class SiStarlingbank(rx.Component):
    library = "react-icons/si"
    tag = "SiStarlingbank"


class SiStarship(rx.Component):
    library = "react-icons/si"
    tag = "SiStarship"


class SiStartrek(rx.Component):
    library = "react-icons/si"
    tag = "SiStartrek"


class SiStarz(rx.Component):
    library = "react-icons/si"
    tag = "SiStarz"


class SiStatamic(rx.Component):
    library = "react-icons/si"
    tag = "SiStatamic"


class SiStatuspage(rx.Component):
    library = "react-icons/si"
    tag = "SiStatuspage"


class SiStatuspal(rx.Component):
    library = "react-icons/si"
    tag = "SiStatuspal"


class SiSteam(rx.Component):
    library = "react-icons/si"
    tag = "SiSteam"


class SiSteamdb(rx.Component):
    library = "react-icons/si"
    tag = "SiSteamdb"


class SiSteamdeck(rx.Component):
    library = "react-icons/si"
    tag = "SiSteamdeck"


class SiSteamworks(rx.Component):
    library = "react-icons/si"
    tag = "SiSteamworks"


class SiSteelseries(rx.Component):
    library = "react-icons/si"
    tag = "SiSteelseries"


class SiSteem(rx.Component):
    library = "react-icons/si"
    tag = "SiSteem"


class SiSteemit(rx.Component):
    library = "react-icons/si"
    tag = "SiSteemit"


class SiSteinberg(rx.Component):
    library = "react-icons/si"
    tag = "SiSteinberg"


class SiStellar(rx.Component):
    library = "react-icons/si"
    tag = "SiStellar"


class SiStencyl(rx.Component):
    library = "react-icons/si"
    tag = "SiStencyl"


class SiStimulus(rx.Component):
    library = "react-icons/si"
    tag = "SiStimulus"


class SiStitcher(rx.Component):
    library = "react-icons/si"
    tag = "SiStitcher"


class SiStmicroelectronics(rx.Component):
    library = "react-icons/si"
    tag = "SiStmicroelectronics"


class SiStopstalk(rx.Component):
    library = "react-icons/si"
    tag = "SiStopstalk"


class SiStoryblok(rx.Component):
    library = "react-icons/si"
    tag = "SiStoryblok"


class SiStorybook(rx.Component):
    library = "react-icons/si"
    tag = "SiStorybook"


class SiStrapi(rx.Component):
    library = "react-icons/si"
    tag = "SiStrapi"


class SiStrava(rx.Component):
    library = "react-icons/si"
    tag = "SiStrava"


class SiStreamlit(rx.Component):
    library = "react-icons/si"
    tag = "SiStreamlit"


class SiStripe(rx.Component):
    library = "react-icons/si"
    tag = "SiStripe"


class SiStrongswan(rx.Component):
    library = "react-icons/si"
    tag = "SiStrongswan"


class SiStubhub(rx.Component):
    library = "react-icons/si"
    tag = "SiStubhub"


class SiStyledcomponents(rx.Component):
    library = "react-icons/si"
    tag = "SiStyledcomponents"


class SiStylelint(rx.Component):
    library = "react-icons/si"
    tag = "SiStylelint"


class SiStyleshare(rx.Component):
    library = "react-icons/si"
    tag = "SiStyleshare"


class SiStylus(rx.Component):
    library = "react-icons/si"
    tag = "SiStylus"


class SiSubaru(rx.Component):
    library = "react-icons/si"
    tag = "SiSubaru"


class SiSublimetext(rx.Component):
    library = "react-icons/si"
    tag = "SiSublimetext"


class SiSubstack(rx.Component):
    library = "react-icons/si"
    tag = "SiSubstack"


class SiSubversion(rx.Component):
    library = "react-icons/si"
    tag = "SiSubversion"


class SiSuckless(rx.Component):
    library = "react-icons/si"
    tag = "SiSuckless"


class SiSumologic(rx.Component):
    library = "react-icons/si"
    tag = "SiSumologic"


class SiSupabase(rx.Component):
    library = "react-icons/si"
    tag = "SiSupabase"


class SiSupermicro(rx.Component):
    library = "react-icons/si"
    tag = "SiSupermicro"


class SiSuperuser(rx.Component):
    library = "react-icons/si"
    tag = "SiSuperuser"


class SiSurrealdb(rx.Component):
    library = "react-icons/si"
    tag = "SiSurrealdb"


class SiSurveymonkey(rx.Component):
    library = "react-icons/si"
    tag = "SiSurveymonkey"


class SiSuse(rx.Component):
    library = "react-icons/si"
    tag = "SiSuse"


class SiSuzuki(rx.Component):
    library = "react-icons/si"
    tag = "SiSuzuki"


class SiSvelte(rx.Component):
    library = "react-icons/si"
    tag = "SiSvelte"


class SiSvg(rx.Component):
    library = "react-icons/si"
    tag = "SiSvg"


class SiSvgo(rx.Component):
    library = "react-icons/si"
    tag = "SiSvgo"


class SiSwagger(rx.Component):
    library = "react-icons/si"
    tag = "SiSwagger"


class SiSwarm(rx.Component):
    library = "react-icons/si"
    tag = "SiSwarm"


class SiSwc(rx.Component):
    library = "react-icons/si"
    tag = "SiSwc"


class SiSwift(rx.Component):
    library = "react-icons/si"
    tag = "SiSwift"


class SiSwiggy(rx.Component):
    library = "react-icons/si"
    tag = "SiSwiggy"


class SiSwiper(rx.Component):
    library = "react-icons/si"
    tag = "SiSwiper"


class SiSymantec(rx.Component):
    library = "react-icons/si"
    tag = "SiSymantec"


class SiSymbolab(rx.Component):
    library = "react-icons/si"
    tag = "SiSymbolab"


class SiSymfony(rx.Component):
    library = "react-icons/si"
    tag = "SiSymfony"


class SiSymphony(rx.Component):
    library = "react-icons/si"
    tag = "SiSymphony"


class SiSympy(rx.Component):
    library = "react-icons/si"
    tag = "SiSympy"


class SiSynology(rx.Component):
    library = "react-icons/si"
    tag = "SiSynology"


class SiSystem76(rx.Component):
    library = "react-icons/si"
    tag = "SiSystem76"


class SiTableau(rx.Component):
    library = "react-icons/si"
    tag = "SiTableau"


class SiTablecheck(rx.Component):
    library = "react-icons/si"
    tag = "SiTablecheck"


class SiTacobell(rx.Component):
    library = "react-icons/si"
    tag = "SiTacobell"


class SiTado(rx.Component):
    library = "react-icons/si"
    tag = "SiTado"


class SiTaichigraphics(rx.Component):
    library = "react-icons/si"
    tag = "SiTaichigraphics"


class SiTaichilang(rx.Component):
    library = "react-icons/si"
    tag = "SiTaichilang"


class SiTails(rx.Component):
    library = "react-icons/si"
    tag = "SiTails"


class SiTailwindcss(rx.Component):
    library = "react-icons/si"
    tag = "SiTailwindcss"


class SiTalend(rx.Component):
    library = "react-icons/si"
    tag = "SiTalend"


class SiTalenthouse(rx.Component):
    library = "react-icons/si"
    tag = "SiTalenthouse"


class SiTamiya(rx.Component):
    library = "react-icons/si"
    tag = "SiTamiya"


class SiTampermonkey(rx.Component):
    library = "react-icons/si"
    tag = "SiTampermonkey"


class SiTaobao(rx.Component):
    library = "react-icons/si"
    tag = "SiTaobao"


class SiTapas(rx.Component):
    library = "react-icons/si"
    tag = "SiTapas"


class SiTarget(rx.Component):
    library = "react-icons/si"
    tag = "SiTarget"


class SiTask(rx.Component):
    library = "react-icons/si"
    tag = "SiTask"


class SiTasmota(rx.Component):
    library = "react-icons/si"
    tag = "SiTasmota"


class SiTata(rx.Component):
    library = "react-icons/si"
    tag = "SiTata"


class SiTauri(rx.Component):
    library = "react-icons/si"
    tag = "SiTauri"


class SiTaxbuzz(rx.Component):
    library = "react-icons/si"
    tag = "SiTaxbuzz"


class SiTeamcity(rx.Component):
    library = "react-icons/si"
    tag = "SiTeamcity"


class SiTeamspeak(rx.Component):
    library = "react-icons/si"
    tag = "SiTeamspeak"


class SiTeamviewer(rx.Component):
    library = "react-icons/si"
    tag = "SiTeamviewer"


class SiTed(rx.Component):
    library = "react-icons/si"
    tag = "SiTed"


class SiTeespring(rx.Component):
    library = "react-icons/si"
    tag = "SiTeespring"


class SiTekton(rx.Component):
    library = "react-icons/si"
    tag = "SiTekton"


class SiTele5(rx.Component):
    library = "react-icons/si"
    tag = "SiTele5"


class SiTelegram(rx.Component):
    library = "react-icons/si"
    tag = "SiTelegram"


class SiTelegraph(rx.Component):
    library = "react-icons/si"
    tag = "SiTelegraph"


class SiTemporal(rx.Component):
    library = "react-icons/si"
    tag = "SiTemporal"


class SiTencentqq(rx.Component):
    library = "react-icons/si"
    tag = "SiTencentqq"


class SiTensorflow(rx.Component):
    library = "react-icons/si"
    tag = "SiTensorflow"


class SiTeradata(rx.Component):
    library = "react-icons/si"
    tag = "SiTeradata"


class SiTeratail(rx.Component):
    library = "react-icons/si"
    tag = "SiTeratail"


class SiTerraform(rx.Component):
    library = "react-icons/si"
    tag = "SiTerraform"


class SiTesco(rx.Component):
    library = "react-icons/si"
    tag = "SiTesco"


class SiTesla(rx.Component):
    library = "react-icons/si"
    tag = "SiTesla"


class SiTestcafe(rx.Component):
    library = "react-icons/si"
    tag = "SiTestcafe"


class SiTestin(rx.Component):
    library = "react-icons/si"
    tag = "SiTestin"


class SiTestinglibrary(rx.Component):
    library = "react-icons/si"
    tag = "SiTestinglibrary"


class SiTether(rx.Component):
    library = "react-icons/si"
    tag = "SiTether"


class SiTextpattern(rx.Component):
    library = "react-icons/si"
    tag = "SiTextpattern"


class SiTga(rx.Component):
    library = "react-icons/si"
    tag = "SiTga"


class SiThealgorithms(rx.Component):
    library = "react-icons/si"
    tag = "SiThealgorithms"


class SiTheconversation(rx.Component):
    library = "react-icons/si"
    tag = "SiTheconversation"


class SiTheirishtimes(rx.Component):
    library = "react-icons/si"
    tag = "SiTheirishtimes"


class SiThemighty(rx.Component):
    library = "react-icons/si"
    tag = "SiThemighty"


class SiThemodelsresource(rx.Component):
    library = "react-icons/si"
    tag = "SiThemodelsresource"


class SiThemoviedatabase(rx.Component):
    library = "react-icons/si"
    tag = "SiThemoviedatabase"


class SiThenorthface(rx.Component):
    library = "react-icons/si"
    tag = "SiThenorthface"


class SiTheregister(rx.Component):
    library = "react-icons/si"
    tag = "SiTheregister"


class SiThesoundsresource(rx.Component):
    library = "react-icons/si"
    tag = "SiThesoundsresource"


class SiThespritersresource(rx.Component):
    library = "react-icons/si"
    tag = "SiThespritersresource"


class SiThewashingtonpost(rx.Component):
    library = "react-icons/si"
    tag = "SiThewashingtonpost"


class SiThingiverse(rx.Component):
    library = "react-icons/si"
    tag = "SiThingiverse"


class SiThinkpad(rx.Component):
    library = "react-icons/si"
    tag = "SiThinkpad"


class SiThreadless(rx.Component):
    library = "react-icons/si"
    tag = "SiThreadless"


class SiThreedotjs(rx.Component):
    library = "react-icons/si"
    tag = "SiThreedotjs"


class SiThreema(rx.Component):
    library = "react-icons/si"
    tag = "SiThreema"


class SiThumbtack(rx.Component):
    library = "react-icons/si"
    tag = "SiThumbtack"


class SiThunderbird(rx.Component):
    library = "react-icons/si"
    tag = "SiThunderbird"


class SiThymeleaf(rx.Component):
    library = "react-icons/si"
    tag = "SiThymeleaf"


class SiTicketmaster(rx.Component):
    library = "react-icons/si"
    tag = "SiTicketmaster"


class SiTidal(rx.Component):
    library = "react-icons/si"
    tag = "SiTidal"


class SiTide(rx.Component):
    library = "react-icons/si"
    tag = "SiTide"


class SiTidyverse(rx.Component):
    library = "react-icons/si"
    tag = "SiTidyverse"


class SiTietoevry(rx.Component):
    library = "react-icons/si"
    tag = "SiTietoevry"


class SiTiktok(rx.Component):
    library = "react-icons/si"
    tag = "SiTiktok"


class SiTile(rx.Component):
    library = "react-icons/si"
    tag = "SiTile"


class SiTimescale(rx.Component):
    library = "react-icons/si"
    tag = "SiTimescale"


class SiTinder(rx.Component):
    library = "react-icons/si"
    tag = "SiTinder"


class SiTinyletter(rx.Component):
    library = "react-icons/si"
    tag = "SiTinyletter"


class SiTistory(rx.Component):
    library = "react-icons/si"
    tag = "SiTistory"


class SiTmobile(rx.Component):
    library = "react-icons/si"
    tag = "SiTmobile"


class SiTmux(rx.Component):
    library = "react-icons/si"
    tag = "SiTmux"


class SiTnt(rx.Component):
    library = "react-icons/si"
    tag = "SiTnt"


class SiTodoist(rx.Component):
    library = "react-icons/si"
    tag = "SiTodoist"


class SiToggl(rx.Component):
    library = "react-icons/si"
    tag = "SiToggl"


class SiTokyometro(rx.Component):
    library = "react-icons/si"
    tag = "SiTokyometro"


class SiToml(rx.Component):
    library = "react-icons/si"
    tag = "SiToml"


class SiTomorrowland(rx.Component):
    library = "react-icons/si"
    tag = "SiTomorrowland"


class SiTopcoder(rx.Component):
    library = "react-icons/si"
    tag = "SiTopcoder"


class SiToptal(rx.Component):
    library = "react-icons/si"
    tag = "SiToptal"


class SiTorbrowser(rx.Component):
    library = "react-icons/si"
    tag = "SiTorbrowser"


class SiTorproject(rx.Component):
    library = "react-icons/si"
    tag = "SiTorproject"


class SiToshiba(rx.Component):
    library = "react-icons/si"
    tag = "SiToshiba"


class SiToyota(rx.Component):
    library = "react-icons/si"
    tag = "SiToyota"


class SiTplink(rx.Component):
    library = "react-icons/si"
    tag = "SiTplink"


class SiTqdm(rx.Component):
    library = "react-icons/si"
    tag = "SiTqdm"


class SiTraefikmesh(rx.Component):
    library = "react-icons/si"
    tag = "SiTraefikmesh"


class SiTraefikproxy(rx.Component):
    library = "react-icons/si"
    tag = "SiTraefikproxy"


class SiTrailforks(rx.Component):
    library = "react-icons/si"
    tag = "SiTrailforks"


class SiTrainerroad(rx.Component):
    library = "react-icons/si"
    tag = "SiTrainerroad"


class SiTrakt(rx.Component):
    library = "react-icons/si"
    tag = "SiTrakt"


class SiTransportforireland(rx.Component):
    library = "react-icons/si"
    tag = "SiTransportforireland"


class SiTransportforlondon(rx.Component):
    library = "react-icons/si"
    tag = "SiTransportforlondon"


class SiTravisci(rx.Component):
    library = "react-icons/si"
    tag = "SiTravisci"


class SiTreehouse(rx.Component):
    library = "react-icons/si"
    tag = "SiTreehouse"


class SiTrello(rx.Component):
    library = "react-icons/si"
    tag = "SiTrello"


class SiTrendmicro(rx.Component):
    library = "react-icons/si"
    tag = "SiTrendmicro"


class SiTreyarch(rx.Component):
    library = "react-icons/si"
    tag = "SiTreyarch"


class SiTriller(rx.Component):
    library = "react-icons/si"
    tag = "SiTriller"


class SiTrino(rx.Component):
    library = "react-icons/si"
    tag = "SiTrino"


class SiTripadvisor(rx.Component):
    library = "react-icons/si"
    tag = "SiTripadvisor"


class SiTripdotcom(rx.Component):
    library = "react-icons/si"
    tag = "SiTripdotcom"


class SiTrove(rx.Component):
    library = "react-icons/si"
    tag = "SiTrove"


class SiTrpc(rx.Component):
    library = "react-icons/si"
    tag = "SiTrpc"


class SiTruenas(rx.Component):
    library = "react-icons/si"
    tag = "SiTruenas"


class SiTrulia(rx.Component):
    library = "react-icons/si"
    tag = "SiTrulia"


class SiTrustedshops(rx.Component):
    library = "react-icons/si"
    tag = "SiTrustedshops"


class SiTrustpilot(rx.Component):
    library = "react-icons/si"
    tag = "SiTrustpilot"


class SiTryhackme(rx.Component):
    library = "react-icons/si"
    tag = "SiTryhackme"


class SiTryitonline(rx.Component):
    library = "react-icons/si"
    tag = "SiTryitonline"


class SiTsnode(rx.Component):
    library = "react-icons/si"
    tag = "SiTsnode"


class SiTubi(rx.Component):
    library = "react-icons/si"
    tag = "SiTubi"


class SiTui(rx.Component):
    library = "react-icons/si"
    tag = "SiTui"


class SiTumblr(rx.Component):
    library = "react-icons/si"
    tag = "SiTumblr"


class SiTunein(rx.Component):
    library = "react-icons/si"
    tag = "SiTunein"


class SiTurborepo(rx.Component):
    library = "react-icons/si"
    tag = "SiTurborepo"


class SiTurbosquid(rx.Component):
    library = "react-icons/si"
    tag = "SiTurbosquid"


class SiTurkishairlines(rx.Component):
    library = "react-icons/si"
    tag = "SiTurkishairlines"


class SiTutanota(rx.Component):
    library = "react-icons/si"
    tag = "SiTutanota"


class SiTvtime(rx.Component):
    library = "react-icons/si"
    tag = "SiTvtime"


class SiTwilio(rx.Component):
    library = "react-icons/si"
    tag = "SiTwilio"


class SiTwitch(rx.Component):
    library = "react-icons/si"
    tag = "SiTwitch"


class SiTwitter(rx.Component):
    library = "react-icons/si"
    tag = "SiTwitter"


class SiTwoo(rx.Component):
    library = "react-icons/si"
    tag = "SiTwoo"


class SiTypeform(rx.Component):
    library = "react-icons/si"
    tag = "SiTypeform"


class SiTypescript(rx.Component):
    library = "react-icons/si"
    tag = "SiTypescript"


class SiTypo3(rx.Component):
    library = "react-icons/si"
    tag = "SiTypo3"


class SiUber(rx.Component):
    library = "react-icons/si"
    tag = "SiUber"


class SiUbereats(rx.Component):
    library = "react-icons/si"
    tag = "SiUbereats"


class SiUbiquiti(rx.Component):
    library = "react-icons/si"
    tag = "SiUbiquiti"


class SiUbisoft(rx.Component):
    library = "react-icons/si"
    tag = "SiUbisoft"


class SiUblockorigin(rx.Component):
    library = "react-icons/si"
    tag = "SiUblockorigin"


class SiUbuntu(rx.Component):
    library = "react-icons/si"
    tag = "SiUbuntu"


class SiUdacity(rx.Component):
    library = "react-icons/si"
    tag = "SiUdacity"


class SiUdemy(rx.Component):
    library = "react-icons/si"
    tag = "SiUdemy"


class SiUfc(rx.Component):
    library = "react-icons/si"
    tag = "SiUfc"


class SiUikit(rx.Component):
    library = "react-icons/si"
    tag = "SiUikit"


class SiUlule(rx.Component):
    library = "react-icons/si"
    tag = "SiUlule"


class SiUmbraco(rx.Component):
    library = "react-icons/si"
    tag = "SiUmbraco"


class SiUnacademy(rx.Component):
    library = "react-icons/si"
    tag = "SiUnacademy"


class SiUnderarmour(rx.Component):
    library = "react-icons/si"
    tag = "SiUnderarmour"


class SiUnderscoredotjs(rx.Component):
    library = "react-icons/si"
    tag = "SiUnderscoredotjs"


class SiUndertale(rx.Component):
    library = "react-icons/si"
    tag = "SiUndertale"


class SiUnicode(rx.Component):
    library = "react-icons/si"
    tag = "SiUnicode"


class SiUnilever(rx.Component):
    library = "react-icons/si"
    tag = "SiUnilever"


class SiUnitedairlines(rx.Component):
    library = "react-icons/si"
    tag = "SiUnitedairlines"


class SiUnity(rx.Component):
    library = "react-icons/si"
    tag = "SiUnity"


class SiUnlicense(rx.Component):
    library = "react-icons/si"
    tag = "SiUnlicense"


class SiUnocss(rx.Component):
    library = "react-icons/si"
    tag = "SiUnocss"


class SiUnraid(rx.Component):
    library = "react-icons/si"
    tag = "SiUnraid"


class SiUnrealengine(rx.Component):
    library = "react-icons/si"
    tag = "SiUnrealengine"


class SiUnsplash(rx.Component):
    library = "react-icons/si"
    tag = "SiUnsplash"


class SiUntangle(rx.Component):
    library = "react-icons/si"
    tag = "SiUntangle"


class SiUntappd(rx.Component):
    library = "react-icons/si"
    tag = "SiUntappd"


class SiUpcloud(rx.Component):
    library = "react-icons/si"
    tag = "SiUpcloud"


class SiUplabs(rx.Component):
    library = "react-icons/si"
    tag = "SiUplabs"


class SiUploaded(rx.Component):
    library = "react-icons/si"
    tag = "SiUploaded"


class SiUps(rx.Component):
    library = "react-icons/si"
    tag = "SiUps"


class SiUpstash(rx.Component):
    library = "react-icons/si"
    tag = "SiUpstash"


class SiUptimekuma(rx.Component):
    library = "react-icons/si"
    tag = "SiUptimekuma"


class SiUptobox(rx.Component):
    library = "react-icons/si"
    tag = "SiUptobox"


class SiUpwork(rx.Component):
    library = "react-icons/si"
    tag = "SiUpwork"


class SiUsps(rx.Component):
    library = "react-icons/si"
    tag = "SiUsps"


class SiV(rx.Component):
    library = "react-icons/si"
    tag = "SiV"


class SiV2Ex(rx.Component):
    library = "react-icons/si"
    tag = "SiV2Ex"


class SiV8(rx.Component):
    library = "react-icons/si"
    tag = "SiV8"


class SiVaadin(rx.Component):
    library = "react-icons/si"
    tag = "SiVaadin"


class SiVagrant(rx.Component):
    library = "react-icons/si"
    tag = "SiVagrant"


class SiVala(rx.Component):
    library = "react-icons/si"
    tag = "SiVala"


class SiValorant(rx.Component):
    library = "react-icons/si"
    tag = "SiValorant"


class SiValve(rx.Component):
    library = "react-icons/si"
    tag = "SiValve"


class SiVapor(rx.Component):
    library = "react-icons/si"
    tag = "SiVapor"


class SiVault(rx.Component):
    library = "react-icons/si"
    tag = "SiVault"


class SiVauxhall(rx.Component):
    library = "react-icons/si"
    tag = "SiVauxhall"


class SiVbulletin(rx.Component):
    library = "react-icons/si"
    tag = "SiVbulletin"


class SiVectorlogozone(rx.Component):
    library = "react-icons/si"
    tag = "SiVectorlogozone"


class SiVectorworks(rx.Component):
    library = "react-icons/si"
    tag = "SiVectorworks"


class SiVeeam(rx.Component):
    library = "react-icons/si"
    tag = "SiVeeam"


class SiVeepee(rx.Component):
    library = "react-icons/si"
    tag = "SiVeepee"


class SiVelog(rx.Component):
    library = "react-icons/si"
    tag = "SiVelog"


class SiVenmo(rx.Component):
    library = "react-icons/si"
    tag = "SiVenmo"


class SiVercel(rx.Component):
    library = "react-icons/si"
    tag = "SiVercel"


class SiVerdaccio(rx.Component):
    library = "react-icons/si"
    tag = "SiVerdaccio"


class SiVeritas(rx.Component):
    library = "react-icons/si"
    tag = "SiVeritas"


class SiVerizon(rx.Component):
    library = "react-icons/si"
    tag = "SiVerizon"


class SiVexxhost(rx.Component):
    library = "react-icons/si"
    tag = "SiVexxhost"


class SiVfairs(rx.Component):
    library = "react-icons/si"
    tag = "SiVfairs"


class SiViadeo(rx.Component):
    library = "react-icons/si"
    tag = "SiViadeo"


class SiViber(rx.Component):
    library = "react-icons/si"
    tag = "SiViber"


class SiVim(rx.Component):
    library = "react-icons/si"
    tag = "SiVim"


class SiVimeo(rx.Component):
    library = "react-icons/si"
    tag = "SiVimeo"


class SiVimeolivestream(rx.Component):
    library = "react-icons/si"
    tag = "SiVimeolivestream"


class SiVirgin(rx.Component):
    library = "react-icons/si"
    tag = "SiVirgin"


class SiVirginmedia(rx.Component):
    library = "react-icons/si"
    tag = "SiVirginmedia"


class SiVirtualbox(rx.Component):
    library = "react-icons/si"
    tag = "SiVirtualbox"


class SiVirustotal(rx.Component):
    library = "react-icons/si"
    tag = "SiVirustotal"


class SiVisa(rx.Component):
    library = "react-icons/si"
    tag = "SiVisa"


class SiVisualstudio(rx.Component):
    library = "react-icons/si"
    tag = "SiVisualstudio"


class SiVisualstudiocode(rx.Component):
    library = "react-icons/si"
    tag = "SiVisualstudiocode"


class SiVite(rx.Component):
    library = "react-icons/si"
    tag = "SiVite"


class SiVitess(rx.Component):
    library = "react-icons/si"
    tag = "SiVitess"


class SiVitest(rx.Component):
    library = "react-icons/si"
    tag = "SiVitest"


class SiVivaldi(rx.Component):
    library = "react-icons/si"
    tag = "SiVivaldi"


class SiVivino(rx.Component):
    library = "react-icons/si"
    tag = "SiVivino"


class SiVk(rx.Component):
    library = "react-icons/si"
    tag = "SiVk"


class SiVlcmediaplayer(rx.Component):
    library = "react-icons/si"
    tag = "SiVlcmediaplayer"


class SiVmware(rx.Component):
    library = "react-icons/si"
    tag = "SiVmware"


class SiVodafone(rx.Component):
    library = "react-icons/si"
    tag = "SiVodafone"


class SiVoipdotms(rx.Component):
    library = "react-icons/si"
    tag = "SiVoipdotms"


class SiVolkswagen(rx.Component):
    library = "react-icons/si"
    tag = "SiVolkswagen"


class SiVolvo(rx.Component):
    library = "react-icons/si"
    tag = "SiVolvo"


class SiVonage(rx.Component):
    library = "react-icons/si"
    tag = "SiVonage"


class SiVowpalwabbit(rx.Component):
    library = "react-icons/si"
    tag = "SiVowpalwabbit"


class SiVox(rx.Component):
    library = "react-icons/si"
    tag = "SiVox"


class SiVsco(rx.Component):
    library = "react-icons/si"
    tag = "SiVsco"


class SiVscodium(rx.Component):
    library = "react-icons/si"
    tag = "SiVscodium"


class SiVtex(rx.Component):
    library = "react-icons/si"
    tag = "SiVtex"


class SiVuedotjs(rx.Component):
    library = "react-icons/si"
    tag = "SiVuedotjs"


class SiVuetify(rx.Component):
    library = "react-icons/si"
    tag = "SiVuetify"


class SiVulkan(rx.Component):
    library = "react-icons/si"
    tag = "SiVulkan"


class SiVultr(rx.Component):
    library = "react-icons/si"
    tag = "SiVultr"


class SiW3C(rx.Component):
    library = "react-icons/si"
    tag = "SiW3C"


class SiWacom(rx.Component):
    library = "react-icons/si"
    tag = "SiWacom"


class SiWagtail(rx.Component):
    library = "react-icons/si"
    tag = "SiWagtail"


class SiWails(rx.Component):
    library = "react-icons/si"
    tag = "SiWails"


class SiWakatime(rx.Component):
    library = "react-icons/si"
    tag = "SiWakatime"


class SiWalkman(rx.Component):
    library = "react-icons/si"
    tag = "SiWalkman"


class SiWallabag(rx.Component):
    library = "react-icons/si"
    tag = "SiWallabag"


class SiWalmart(rx.Component):
    library = "react-icons/si"
    tag = "SiWalmart"


class SiWantedly(rx.Component):
    library = "react-icons/si"
    tag = "SiWantedly"


class SiWappalyzer(rx.Component):
    library = "react-icons/si"
    tag = "SiWappalyzer"


class SiWarnerbros(rx.Component):
    library = "react-icons/si"
    tag = "SiWarnerbros"


class SiWarp(rx.Component):
    library = "react-icons/si"
    tag = "SiWarp"


class SiWasmcloud(rx.Component):
    library = "react-icons/si"
    tag = "SiWasmcloud"


class SiWasmer(rx.Component):
    library = "react-icons/si"
    tag = "SiWasmer"


class SiWattpad(rx.Component):
    library = "react-icons/si"
    tag = "SiWattpad"


class SiWayland(rx.Component):
    library = "react-icons/si"
    tag = "SiWayland"


class SiWaze(rx.Component):
    library = "react-icons/si"
    tag = "SiWaze"


class SiWearos(rx.Component):
    library = "react-icons/si"
    tag = "SiWearos"


class SiWeasyl(rx.Component):
    library = "react-icons/si"
    tag = "SiWeasyl"


class SiWeb3Dotjs(rx.Component):
    library = "react-icons/si"
    tag = "SiWeb3Dotjs"


class SiWebassembly(rx.Component):
    library = "react-icons/si"
    tag = "SiWebassembly"


class SiWebauthn(rx.Component):
    library = "react-icons/si"
    tag = "SiWebauthn"


class SiWebcomponentsdotorg(rx.Component):
    library = "react-icons/si"
    tag = "SiWebcomponentsdotorg"


class SiWebdriverio(rx.Component):
    library = "react-icons/si"
    tag = "SiWebdriverio"


class SiWebflow(rx.Component):
    library = "react-icons/si"
    tag = "SiWebflow"


class SiWebgl(rx.Component):
    library = "react-icons/si"
    tag = "SiWebgl"


class SiWebhint(rx.Component):
    library = "react-icons/si"
    tag = "SiWebhint"


class SiWeblate(rx.Component):
    library = "react-icons/si"
    tag = "SiWeblate"


class SiWebmin(rx.Component):
    library = "react-icons/si"
    tag = "SiWebmin"


class SiWebmoney(rx.Component):
    library = "react-icons/si"
    tag = "SiWebmoney"


class SiWebpack(rx.Component):
    library = "react-icons/si"
    tag = "SiWebpack"


class SiWebrtc(rx.Component):
    library = "react-icons/si"
    tag = "SiWebrtc"


class SiWebstorm(rx.Component):
    library = "react-icons/si"
    tag = "SiWebstorm"


class SiWebtoon(rx.Component):
    library = "react-icons/si"
    tag = "SiWebtoon"


class SiWechat(rx.Component):
    library = "react-icons/si"
    tag = "SiWechat"


class SiWegame(rx.Component):
    library = "react-icons/si"
    tag = "SiWegame"


class SiWeightsandbiases(rx.Component):
    library = "react-icons/si"
    tag = "SiWeightsandbiases"


class SiWelcometothejungle(rx.Component):
    library = "react-icons/si"
    tag = "SiWelcometothejungle"


class SiWemo(rx.Component):
    library = "react-icons/si"
    tag = "SiWemo"


class SiWesterndigital(rx.Component):
    library = "react-icons/si"
    tag = "SiWesterndigital"


class SiWetransfer(rx.Component):
    library = "react-icons/si"
    tag = "SiWetransfer"


class SiWhatsapp(rx.Component):
    library = "react-icons/si"
    tag = "SiWhatsapp"


class SiWheniwork(rx.Component):
    library = "react-icons/si"
    tag = "SiWheniwork"


class SiWhitesource(rx.Component):
    library = "react-icons/si"
    tag = "SiWhitesource"


class SiWii(rx.Component):
    library = "react-icons/si"
    tag = "SiWii"


class SiWiiu(rx.Component):
    library = "react-icons/si"
    tag = "SiWiiu"


class SiWikidata(rx.Component):
    library = "react-icons/si"
    tag = "SiWikidata"


class SiWikidotjs(rx.Component):
    library = "react-icons/si"
    tag = "SiWikidotjs"


class SiWikimediacommons(rx.Component):
    library = "react-icons/si"
    tag = "SiWikimediacommons"


class SiWikipedia(rx.Component):
    library = "react-icons/si"
    tag = "SiWikipedia"


class SiWikiquote(rx.Component):
    library = "react-icons/si"
    tag = "SiWikiquote"


class SiWikivoyage(rx.Component):
    library = "react-icons/si"
    tag = "SiWikivoyage"


class SiWinamp(rx.Component):
    library = "react-icons/si"
    tag = "SiWinamp"


class SiWindicss(rx.Component):
    library = "react-icons/si"
    tag = "SiWindicss"


class SiWindows(rx.Component):
    library = "react-icons/si"
    tag = "SiWindows"


class SiWindows11(rx.Component):
    library = "react-icons/si"
    tag = "SiWindows11"


class SiWindows95(rx.Component):
    library = "react-icons/si"
    tag = "SiWindows95"


class SiWindowsterminal(rx.Component):
    library = "react-icons/si"
    tag = "SiWindowsterminal"


class SiWindowsxp(rx.Component):
    library = "react-icons/si"
    tag = "SiWindowsxp"


class SiWinmate(rx.Component):
    library = "react-icons/si"
    tag = "SiWinmate"


class SiWipro(rx.Component):
    library = "react-icons/si"
    tag = "SiWipro"


class SiWire(rx.Component):
    library = "react-icons/si"
    tag = "SiWire"


class SiWireguard(rx.Component):
    library = "react-icons/si"
    tag = "SiWireguard"


class SiWireshark(rx.Component):
    library = "react-icons/si"
    tag = "SiWireshark"


class SiWise(rx.Component):
    library = "react-icons/si"
    tag = "SiWise"


class SiWish(rx.Component):
    library = "react-icons/si"
    tag = "SiWish"


class SiWistia(rx.Component):
    library = "react-icons/si"
    tag = "SiWistia"


class SiWix(rx.Component):
    library = "react-icons/si"
    tag = "SiWix"


class SiWizzair(rx.Component):
    library = "react-icons/si"
    tag = "SiWizzair"


class SiWolfram(rx.Component):
    library = "react-icons/si"
    tag = "SiWolfram"


class SiWolframlanguage(rx.Component):
    library = "react-icons/si"
    tag = "SiWolframlanguage"


class SiWolframmathematica(rx.Component):
    library = "react-icons/si"
    tag = "SiWolframmathematica"


class SiWoo(rx.Component):
    library = "react-icons/si"
    tag = "SiWoo"


class SiWoocommerce(rx.Component):
    library = "react-icons/si"
    tag = "SiWoocommerce"


class SiWordpress(rx.Component):
    library = "react-icons/si"
    tag = "SiWordpress"


class SiWorkplace(rx.Component):
    library = "react-icons/si"
    tag = "SiWorkplace"


class SiWorldhealthorganization(rx.Component):
    library = "react-icons/si"
    tag = "SiWorldhealthorganization"


class SiWpengine(rx.Component):
    library = "react-icons/si"
    tag = "SiWpengine"


class SiWpexplorer(rx.Component):
    library = "react-icons/si"
    tag = "SiWpexplorer"


class SiWprocket(rx.Component):
    library = "react-icons/si"
    tag = "SiWprocket"


class SiWritedotas(rx.Component):
    library = "react-icons/si"
    tag = "SiWritedotas"


class SiWwe(rx.Component):
    library = "react-icons/si"
    tag = "SiWwe"


class SiWwise(rx.Component):
    library = "react-icons/si"
    tag = "SiWwise"


class SiXamarin(rx.Component):
    library = "react-icons/si"
    tag = "SiXamarin"


class SiXaml(rx.Component):
    library = "react-icons/si"
    tag = "SiXaml"


class SiXampp(rx.Component):
    library = "react-icons/si"
    tag = "SiXampp"


class SiXbox(rx.Component):
    library = "react-icons/si"
    tag = "SiXbox"


class SiXcode(rx.Component):
    library = "react-icons/si"
    tag = "SiXcode"


class SiXdadevelopers(rx.Component):
    library = "react-icons/si"
    tag = "SiXdadevelopers"


class SiXdotorg(rx.Component):
    library = "react-icons/si"
    tag = "SiXdotorg"


class SiXero(rx.Component):
    library = "react-icons/si"
    tag = "SiXero"


class SiXfce(rx.Component):
    library = "react-icons/si"
    tag = "SiXfce"


class SiXiaomi(rx.Component):
    library = "react-icons/si"
    tag = "SiXiaomi"


class SiXilinx(rx.Component):
    library = "react-icons/si"
    tag = "SiXilinx"


class SiXing(rx.Component):
    library = "react-icons/si"
    tag = "SiXing"


class SiXmpp(rx.Component):
    library = "react-icons/si"
    tag = "SiXmpp"


class SiXo(rx.Component):
    library = "react-icons/si"
    tag = "SiXo"


class SiXrp(rx.Component):
    library = "react-icons/si"
    tag = "SiXrp"


class SiXsplit(rx.Component):
    library = "react-icons/si"
    tag = "SiXsplit"


class SiXstate(rx.Component):
    library = "react-icons/si"
    tag = "SiXstate"


class SiYahoo(rx.Component):
    library = "react-icons/si"
    tag = "SiYahoo"


class SiYale(rx.Component):
    library = "react-icons/si"
    tag = "SiYale"


class SiYamahacorporation(rx.Component):
    library = "react-icons/si"
    tag = "SiYamahacorporation"


class SiYamahamotorcorporation(rx.Component):
    library = "react-icons/si"
    tag = "SiYamahamotorcorporation"


class SiYaml(rx.Component):
    library = "react-icons/si"
    tag = "SiYaml"


class SiYammer(rx.Component):
    library = "react-icons/si"
    tag = "SiYammer"


class SiYarn(rx.Component):
    library = "react-icons/si"
    tag = "SiYarn"


class SiYcombinator(rx.Component):
    library = "react-icons/si"
    tag = "SiYcombinator"


class SiYelp(rx.Component):
    library = "react-icons/si"
    tag = "SiYelp"


class SiYoast(rx.Component):
    library = "react-icons/si"
    tag = "SiYoast"


class SiYolo(rx.Component):
    library = "react-icons/si"
    tag = "SiYolo"


class SiYourtraveldottv(rx.Component):
    library = "react-icons/si"
    tag = "SiYourtraveldottv"


class SiYoutube(rx.Component):
    library = "react-icons/si"
    tag = "SiYoutube"


class SiYoutubegaming(rx.Component):
    library = "react-icons/si"
    tag = "SiYoutubegaming"


class SiYoutubemusic(rx.Component):
    library = "react-icons/si"
    tag = "SiYoutubemusic"


class SiYoutubestudio(rx.Component):
    library = "react-icons/si"
    tag = "SiYoutubestudio"


class SiYoutubetv(rx.Component):
    library = "react-icons/si"
    tag = "SiYoutubetv"


class SiYubico(rx.Component):
    library = "react-icons/si"
    tag = "SiYubico"


class SiZabka(rx.Component):
    library = "react-icons/si"
    tag = "SiZabka"


class SiZalando(rx.Component):
    library = "react-icons/si"
    tag = "SiZalando"


class SiZalo(rx.Component):
    library = "react-icons/si"
    tag = "SiZalo"


class SiZapier(rx.Component):
    library = "react-icons/si"
    tag = "SiZapier"


class SiZara(rx.Component):
    library = "react-icons/si"
    tag = "SiZara"


class SiZazzle(rx.Component):
    library = "react-icons/si"
    tag = "SiZazzle"


class SiZcash(rx.Component):
    library = "react-icons/si"
    tag = "SiZcash"


class SiZdf(rx.Component):
    library = "react-icons/si"
    tag = "SiZdf"


class SiZebratechnologies(rx.Component):
    library = "react-icons/si"
    tag = "SiZebratechnologies"


class SiZelle(rx.Component):
    library = "react-icons/si"
    tag = "SiZelle"


class SiZend(rx.Component):
    library = "react-icons/si"
    tag = "SiZend"


class SiZendesk(rx.Component):
    library = "react-icons/si"
    tag = "SiZendesk"


class SiZendframework(rx.Component):
    library = "react-icons/si"
    tag = "SiZendframework"


class SiZenn(rx.Component):
    library = "react-icons/si"
    tag = "SiZenn"


class SiZenodo(rx.Component):
    library = "react-icons/si"
    tag = "SiZenodo"


class SiZerodha(rx.Component):
    library = "react-icons/si"
    tag = "SiZerodha"


class SiZeromq(rx.Component):
    library = "react-icons/si"
    tag = "SiZeromq"


class SiZerply(rx.Component):
    library = "react-icons/si"
    tag = "SiZerply"


class SiZettlr(rx.Component):
    library = "react-icons/si"
    tag = "SiZettlr"


class SiZhihu(rx.Component):
    library = "react-icons/si"
    tag = "SiZhihu"


class SiZig(rx.Component):
    library = "react-icons/si"
    tag = "SiZig"


class SiZigbee(rx.Component):
    library = "react-icons/si"
    tag = "SiZigbee"


class SiZilch(rx.Component):
    library = "react-icons/si"
    tag = "SiZilch"


class SiZillow(rx.Component):
    library = "react-icons/si"
    tag = "SiZillow"


class SiZincsearch(rx.Component):
    library = "react-icons/si"
    tag = "SiZincsearch"


class SiZingat(rx.Component):
    library = "react-icons/si"
    tag = "SiZingat"


class SiZoho(rx.Component):
    library = "react-icons/si"
    tag = "SiZoho"


class SiZoiper(rx.Component):
    library = "react-icons/si"
    tag = "SiZoiper"


class SiZomato(rx.Component):
    library = "react-icons/si"
    tag = "SiZomato"


class SiZoom(rx.Component):
    library = "react-icons/si"
    tag = "SiZoom"


class SiZorin(rx.Component):
    library = "react-icons/si"
    tag = "SiZorin"


class SiZotero(rx.Component):
    library = "react-icons/si"
    tag = "SiZotero"


class SiZulip(rx.Component):
    library = "react-icons/si"
    tag = "SiZulip"


class SiZwave(rx.Component):
    library = "react-icons/si"
    tag = "SiZwave"


class SiZyte(rx.Component):
    library = "react-icons/si"
    tag = "SiZyte"


